/****************************************************************************
** Meta object code from reading C++ file 'spellcheckdialog.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../ktexteditor-5.116.0/src/spellcheck/spellcheckdialog.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'spellcheckdialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KateSpellCheckDialog_t {
    QByteArrayData data[19];
    char stringdata0[256];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KateSpellCheckDialog_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KateSpellCheckDialog_t qt_meta_stringdata_KateSpellCheckDialog = {
    {
QT_MOC_LITERAL(0, 0, 20), // "KateSpellCheckDialog"
QT_MOC_LITERAL(1, 21, 20), // "spellcheckFromCursor"
QT_MOC_LITERAL(2, 42, 0), // ""
QT_MOC_LITERAL(3, 43, 19), // "spellcheckSelection"
QT_MOC_LITERAL(4, 63, 10), // "spellcheck"
QT_MOC_LITERAL(5, 74, 19), // "KTextEditor::Cursor"
QT_MOC_LITERAL(6, 94, 4), // "from"
QT_MOC_LITERAL(7, 99, 2), // "to"
QT_MOC_LITERAL(8, 102, 11), // "misspelling"
QT_MOC_LITERAL(9, 114, 9), // "corrected"
QT_MOC_LITERAL(10, 124, 17), // "performSpellCheck"
QT_MOC_LITERAL(11, 142, 18), // "KTextEditor::Range"
QT_MOC_LITERAL(12, 161, 5), // "range"
QT_MOC_LITERAL(13, 167, 26), // "installNextSpellCheckRange"
QT_MOC_LITERAL(14, 194, 13), // "cancelClicked"
QT_MOC_LITERAL(15, 208, 15), // "objectDestroyed"
QT_MOC_LITERAL(16, 224, 6), // "object"
QT_MOC_LITERAL(17, 231, 15), // "languageChanged"
QT_MOC_LITERAL(18, 247, 8) // "language"

    },
    "KateSpellCheckDialog\0spellcheckFromCursor\0"
    "\0spellcheckSelection\0spellcheck\0"
    "KTextEditor::Cursor\0from\0to\0misspelling\0"
    "corrected\0performSpellCheck\0"
    "KTextEditor::Range\0range\0"
    "installNextSpellCheckRange\0cancelClicked\0"
    "objectDestroyed\0object\0languageChanged\0"
    "language"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KateSpellCheckDialog[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      12,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   74,    2, 0x08 /* Private */,
       3,    0,   75,    2, 0x08 /* Private */,
       4,    0,   76,    2, 0x08 /* Private */,
       4,    2,   77,    2, 0x08 /* Private */,
       4,    1,   82,    2, 0x28 /* Private | MethodCloned */,
       8,    2,   85,    2, 0x08 /* Private */,
       9,    3,   90,    2, 0x08 /* Private */,
      10,    1,   97,    2, 0x08 /* Private */,
      13,    0,  100,    2, 0x08 /* Private */,
      14,    0,  101,    2, 0x08 /* Private */,
      15,    1,  102,    2, 0x08 /* Private */,
      17,    1,  105,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 5, 0x80000000 | 5,    6,    7,
    QMetaType::Void, 0x80000000 | 5,    6,
    QMetaType::Void, QMetaType::QString, QMetaType::Int,    2,    2,
    QMetaType::Void, QMetaType::QString, QMetaType::Int, QMetaType::QString,    2,    2,    2,
    QMetaType::Void, 0x80000000 | 11,   12,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QObjectStar,   16,
    QMetaType::Void, QMetaType::QString,   18,

       0        // eod
};

void KateSpellCheckDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<KateSpellCheckDialog *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->spellcheckFromCursor(); break;
        case 1: _t->spellcheckSelection(); break;
        case 2: _t->spellcheck(); break;
        case 3: _t->spellcheck((*reinterpret_cast< const KTextEditor::Cursor(*)>(_a[1])),(*reinterpret_cast< const KTextEditor::Cursor(*)>(_a[2]))); break;
        case 4: _t->spellcheck((*reinterpret_cast< const KTextEditor::Cursor(*)>(_a[1]))); break;
        case 5: _t->misspelling((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 6: _t->corrected((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 7: _t->performSpellCheck((*reinterpret_cast< KTextEditor::Range(*)>(_a[1]))); break;
        case 8: _t->installNextSpellCheckRange(); break;
        case 9: _t->cancelClicked(); break;
        case 10: _t->objectDestroyed((*reinterpret_cast< QObject*(*)>(_a[1]))); break;
        case 11: _t->languageChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Cursor >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Cursor >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Range >(); break;
            }
            break;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject KateSpellCheckDialog::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_KateSpellCheckDialog.data,
    qt_meta_data_KateSpellCheckDialog,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *KateSpellCheckDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateSpellCheckDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KateSpellCheckDialog.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KateSpellCheckDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
