/****************************************************************************
** Meta object code from reading C++ file 'kateundomanager.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../ktexteditor-5.116.0/src/undo/kateundomanager.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kateundomanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KateUndoManager_t {
    QByteArrayData data[43];
    char stringdata0[488];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KateUndoManager_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KateUndoManager_t qt_meta_stringdata_KateUndoManager = {
    {
QT_MOC_LITERAL(0, 0, 15), // "KateUndoManager"
QT_MOC_LITERAL(1, 16, 11), // "undoChanged"
QT_MOC_LITERAL(2, 28, 0), // ""
QT_MOC_LITERAL(3, 29, 9), // "undoStart"
QT_MOC_LITERAL(4, 39, 22), // "KTextEditor::Document*"
QT_MOC_LITERAL(5, 62, 7), // "undoEnd"
QT_MOC_LITERAL(6, 70, 9), // "redoStart"
QT_MOC_LITERAL(7, 80, 7), // "redoEnd"
QT_MOC_LITERAL(8, 88, 15), // "isActiveChanged"
QT_MOC_LITERAL(9, 104, 7), // "enabled"
QT_MOC_LITERAL(10, 112, 4), // "undo"
QT_MOC_LITERAL(11, 117, 4), // "redo"
QT_MOC_LITERAL(12, 122, 9), // "clearUndo"
QT_MOC_LITERAL(13, 132, 9), // "clearRedo"
QT_MOC_LITERAL(14, 142, 9), // "editStart"
QT_MOC_LITERAL(15, 152, 7), // "editEnd"
QT_MOC_LITERAL(16, 160, 9), // "startUndo"
QT_MOC_LITERAL(17, 170, 7), // "endUndo"
QT_MOC_LITERAL(18, 178, 16), // "inputMethodStart"
QT_MOC_LITERAL(19, 195, 14), // "inputMethodEnd"
QT_MOC_LITERAL(20, 210, 16), // "slotTextInserted"
QT_MOC_LITERAL(21, 227, 4), // "line"
QT_MOC_LITERAL(22, 232, 3), // "col"
QT_MOC_LITERAL(23, 236, 1), // "s"
QT_MOC_LITERAL(24, 238, 15), // "slotTextRemoved"
QT_MOC_LITERAL(25, 254, 23), // "slotMarkLineAutoWrapped"
QT_MOC_LITERAL(26, 278, 11), // "autowrapped"
QT_MOC_LITERAL(27, 290, 15), // "slotLineWrapped"
QT_MOC_LITERAL(28, 306, 6), // "length"
QT_MOC_LITERAL(29, 313, 7), // "newLine"
QT_MOC_LITERAL(30, 321, 17), // "slotLineUnWrapped"
QT_MOC_LITERAL(31, 339, 11), // "lineRemoved"
QT_MOC_LITERAL(32, 351, 16), // "slotLineInserted"
QT_MOC_LITERAL(33, 368, 15), // "slotLineRemoved"
QT_MOC_LITERAL(34, 384, 11), // "addUndoItem"
QT_MOC_LITERAL(35, 396, 9), // "KateUndo*"
QT_MOC_LITERAL(36, 406, 9), // "setActive"
QT_MOC_LITERAL(37, 416, 6), // "active"
QT_MOC_LITERAL(38, 423, 14), // "updateModified"
QT_MOC_LITERAL(39, 438, 10), // "undoCancel"
QT_MOC_LITERAL(40, 449, 11), // "viewCreated"
QT_MOC_LITERAL(41, 461, 18), // "KTextEditor::View*"
QT_MOC_LITERAL(42, 480, 7) // "newView"

    },
    "KateUndoManager\0undoChanged\0\0undoStart\0"
    "KTextEditor::Document*\0undoEnd\0redoStart\0"
    "redoEnd\0isActiveChanged\0enabled\0undo\0"
    "redo\0clearUndo\0clearRedo\0editStart\0"
    "editEnd\0startUndo\0endUndo\0inputMethodStart\0"
    "inputMethodEnd\0slotTextInserted\0line\0"
    "col\0s\0slotTextRemoved\0slotMarkLineAutoWrapped\0"
    "autowrapped\0slotLineWrapped\0length\0"
    "newLine\0slotLineUnWrapped\0lineRemoved\0"
    "slotLineInserted\0slotLineRemoved\0"
    "addUndoItem\0KateUndo*\0setActive\0active\0"
    "updateModified\0undoCancel\0viewCreated\0"
    "KTextEditor::View*\0newView"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KateUndoManager[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      28,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       6,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  154,    2, 0x06 /* Public */,
       3,    1,  155,    2, 0x06 /* Public */,
       5,    1,  158,    2, 0x06 /* Public */,
       6,    1,  161,    2, 0x06 /* Public */,
       7,    1,  164,    2, 0x06 /* Public */,
       8,    1,  167,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      10,    0,  170,    2, 0x0a /* Public */,
      11,    0,  171,    2, 0x0a /* Public */,
      12,    0,  172,    2, 0x0a /* Public */,
      13,    0,  173,    2, 0x0a /* Public */,
      14,    0,  174,    2, 0x0a /* Public */,
      15,    0,  175,    2, 0x0a /* Public */,
      16,    0,  176,    2, 0x0a /* Public */,
      17,    0,  177,    2, 0x0a /* Public */,
      18,    0,  178,    2, 0x0a /* Public */,
      19,    0,  179,    2, 0x0a /* Public */,
      20,    3,  180,    2, 0x0a /* Public */,
      24,    3,  187,    2, 0x0a /* Public */,
      25,    2,  194,    2, 0x0a /* Public */,
      27,    4,  199,    2, 0x0a /* Public */,
      30,    4,  208,    2, 0x0a /* Public */,
      32,    2,  217,    2, 0x0a /* Public */,
      33,    2,  222,    2, 0x0a /* Public */,
      34,    1,  227,    2, 0x08 /* Private */,
      36,    1,  230,    2, 0x08 /* Private */,
      38,    0,  233,    2, 0x08 /* Private */,
      39,    0,  234,    2, 0x08 /* Private */,
      40,    2,  235,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 4,    2,
    QMetaType::Void, 0x80000000 | 4,    2,
    QMetaType::Void, 0x80000000 | 4,    2,
    QMetaType::Void, 0x80000000 | 4,    2,
    QMetaType::Void, QMetaType::Bool,    9,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, QMetaType::Int, QMetaType::QString,   21,   22,   23,
    QMetaType::Void, QMetaType::Int, QMetaType::Int, QMetaType::QString,   21,   22,   23,
    QMetaType::Void, QMetaType::Int, QMetaType::Bool,   21,   26,
    QMetaType::Void, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::Bool,   21,   22,   28,   29,
    QMetaType::Void, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::Bool,   21,   22,   28,   31,
    QMetaType::Void, QMetaType::Int, QMetaType::QString,   21,   23,
    QMetaType::Void, QMetaType::Int, QMetaType::QString,   21,   23,
    QMetaType::Void, 0x80000000 | 35,   10,
    QMetaType::Void, QMetaType::Bool,   37,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 4, 0x80000000 | 41,    2,   42,

       0        // eod
};

void KateUndoManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<KateUndoManager *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->undoChanged(); break;
        case 1: _t->undoStart((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1]))); break;
        case 2: _t->undoEnd((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1]))); break;
        case 3: _t->redoStart((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1]))); break;
        case 4: _t->redoEnd((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1]))); break;
        case 5: _t->isActiveChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 6: _t->undo(); break;
        case 7: _t->redo(); break;
        case 8: _t->clearUndo(); break;
        case 9: _t->clearRedo(); break;
        case 10: _t->editStart(); break;
        case 11: _t->editEnd(); break;
        case 12: _t->startUndo(); break;
        case 13: _t->endUndo(); break;
        case 14: _t->inputMethodStart(); break;
        case 15: _t->inputMethodEnd(); break;
        case 16: _t->slotTextInserted((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 17: _t->slotTextRemoved((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 18: _t->slotMarkLineAutoWrapped((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 19: _t->slotLineWrapped((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< bool(*)>(_a[4]))); break;
        case 20: _t->slotLineUnWrapped((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< bool(*)>(_a[4]))); break;
        case 21: _t->slotLineInserted((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 22: _t->slotLineRemoved((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 23: _t->addUndoItem((*reinterpret_cast< KateUndo*(*)>(_a[1]))); break;
        case 24: _t->setActive((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 25: _t->updateModified(); break;
        case 26: _t->undoCancel(); break;
        case 27: _t->viewCreated((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1])),(*reinterpret_cast< KTextEditor::View*(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (KateUndoManager::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KateUndoManager::undoChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (KateUndoManager::*)(KTextEditor::Document * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KateUndoManager::undoStart)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (KateUndoManager::*)(KTextEditor::Document * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KateUndoManager::undoEnd)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (KateUndoManager::*)(KTextEditor::Document * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KateUndoManager::redoStart)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (KateUndoManager::*)(KTextEditor::Document * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KateUndoManager::redoEnd)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (KateUndoManager::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KateUndoManager::isActiveChanged)) {
                *result = 5;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject KateUndoManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_KateUndoManager.data,
    qt_meta_data_KateUndoManager,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *KateUndoManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateUndoManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KateUndoManager.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KateUndoManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 28)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 28;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 28)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 28;
    }
    return _id;
}

// SIGNAL 0
void KateUndoManager::undoChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KateUndoManager::undoStart(KTextEditor::Document * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void KateUndoManager::undoEnd(KTextEditor::Document * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void KateUndoManager::redoStart(KTextEditor::Document * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void KateUndoManager::redoEnd(KTextEditor::Document * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void KateUndoManager::isActiveChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
