/****************************************************************************
** Meta object code from reading C++ file 'kateview.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../ktexteditor-5.116.0/src/view/kateview.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kateview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KTextEditor__ViewPrivate_t {
    QByteArrayData data[192];
    char stringdata0[2858];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KTextEditor__ViewPrivate_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KTextEditor__ViewPrivate_t qt_meta_stringdata_KTextEditor__ViewPrivate = {
    {
QT_MOC_LITERAL(0, 0, 24), // "KTextEditor::ViewPrivate"
QT_MOC_LITERAL(1, 25, 18), // "completionExecuted"
QT_MOC_LITERAL(2, 44, 0), // ""
QT_MOC_LITERAL(3, 45, 18), // "KTextEditor::View*"
QT_MOC_LITERAL(4, 64, 4), // "view"
QT_MOC_LITERAL(5, 69, 19), // "KTextEditor::Cursor"
QT_MOC_LITERAL(6, 89, 8), // "position"
QT_MOC_LITERAL(7, 98, 33), // "KTextEditor::CodeCompletionMo..."
QT_MOC_LITERAL(8, 132, 5), // "model"
QT_MOC_LITERAL(9, 138, 11), // "QModelIndex"
QT_MOC_LITERAL(10, 150, 17), // "completionAborted"
QT_MOC_LITERAL(11, 168, 32), // "annotationContextMenuAboutToShow"
QT_MOC_LITERAL(12, 201, 6), // "QMenu*"
QT_MOC_LITERAL(13, 208, 4), // "menu"
QT_MOC_LITERAL(14, 213, 4), // "line"
QT_MOC_LITERAL(15, 218, 19), // "annotationActivated"
QT_MOC_LITERAL(16, 238, 33), // "annotationBorderVisibilityCha..."
QT_MOC_LITERAL(17, 272, 5), // "View*"
QT_MOC_LITERAL(18, 278, 7), // "visible"
QT_MOC_LITERAL(19, 286, 12), // "navigateLeft"
QT_MOC_LITERAL(20, 299, 13), // "navigateRight"
QT_MOC_LITERAL(21, 313, 10), // "navigateUp"
QT_MOC_LITERAL(22, 324, 12), // "navigateDown"
QT_MOC_LITERAL(23, 337, 14), // "navigateAccept"
QT_MOC_LITERAL(24, 352, 12), // "navigateBack"
QT_MOC_LITERAL(25, 365, 13), // "dropEventPass"
QT_MOC_LITERAL(26, 379, 11), // "QDropEvent*"
QT_MOC_LITERAL(27, 391, 19), // "displayRangeChanged"
QT_MOC_LITERAL(28, 411, 25), // "KTextEditor::ViewPrivate*"
QT_MOC_LITERAL(29, 437, 19), // "delayedUpdateOfView"
QT_MOC_LITERAL(30, 457, 17), // "caretChangedRange"
QT_MOC_LITERAL(31, 475, 5), // "paste"
QT_MOC_LITERAL(32, 481, 14), // "const QString*"
QT_MOC_LITERAL(33, 496, 11), // "textToPaste"
QT_MOC_LITERAL(34, 508, 3), // "cut"
QT_MOC_LITERAL(35, 512, 4), // "copy"
QT_MOC_LITERAL(36, 517, 14), // "pasteSelection"
QT_MOC_LITERAL(37, 532, 17), // "swapWithClipboard"
QT_MOC_LITERAL(38, 550, 13), // "applyWordWrap"
QT_MOC_LITERAL(39, 564, 22), // "aboutToShowContextMenu"
QT_MOC_LITERAL(40, 587, 22), // "aboutToHideContextMenu"
QT_MOC_LITERAL(41, 610, 21), // "userInvokedCompletion"
QT_MOC_LITERAL(42, 632, 16), // "inlineNotesReset"
QT_MOC_LITERAL(43, 649, 22), // "inlineNotesLineChanged"
QT_MOC_LITERAL(44, 672, 12), // "setSelection"
QT_MOC_LITERAL(45, 685, 18), // "KTextEditor::Range"
QT_MOC_LITERAL(46, 704, 9), // "selection"
QT_MOC_LITERAL(47, 714, 15), // "removeSelection"
QT_MOC_LITERAL(48, 730, 19), // "removeSelectionText"
QT_MOC_LITERAL(49, 750, 17), // "setBlockSelection"
QT_MOC_LITERAL(50, 768, 2), // "on"
QT_MOC_LITERAL(51, 771, 20), // "toggleBlockSelection"
QT_MOC_LITERAL(52, 792, 14), // "clearSelection"
QT_MOC_LITERAL(53, 807, 6), // "redraw"
QT_MOC_LITERAL(54, 814, 25), // "finishedChangingSelection"
QT_MOC_LITERAL(55, 840, 18), // "removeSelectedText"
QT_MOC_LITERAL(56, 859, 9), // "selectAll"
QT_MOC_LITERAL(57, 869, 6), // "indent"
QT_MOC_LITERAL(58, 876, 8), // "unIndent"
QT_MOC_LITERAL(59, 885, 11), // "cleanIndent"
QT_MOC_LITERAL(60, 897, 12), // "formatIndent"
QT_MOC_LITERAL(61, 910, 5), // "align"
QT_MOC_LITERAL(62, 916, 7), // "alignOn"
QT_MOC_LITERAL(63, 924, 7), // "comment"
QT_MOC_LITERAL(64, 932, 9), // "uncomment"
QT_MOC_LITERAL(65, 942, 13), // "toggleComment"
QT_MOC_LITERAL(66, 956, 8), // "killLine"
QT_MOC_LITERAL(67, 965, 27), // "goToPreviousEditingPosition"
QT_MOC_LITERAL(68, 993, 23), // "goToNextEditingPosition"
QT_MOC_LITERAL(69, 1017, 9), // "uppercase"
QT_MOC_LITERAL(70, 1027, 9), // "lowercase"
QT_MOC_LITERAL(71, 1037, 10), // "capitalize"
QT_MOC_LITERAL(72, 1048, 9), // "joinLines"
QT_MOC_LITERAL(73, 1058, 9), // "keyReturn"
QT_MOC_LITERAL(74, 1068, 12), // "smartNewline"
QT_MOC_LITERAL(75, 1081, 15), // "noIndentNewline"
QT_MOC_LITERAL(76, 1097, 12), // "newLineAbove"
QT_MOC_LITERAL(77, 1110, 12), // "newLineBelow"
QT_MOC_LITERAL(78, 1123, 9), // "backspace"
QT_MOC_LITERAL(79, 1133, 14), // "deleteWordLeft"
QT_MOC_LITERAL(80, 1148, 9), // "keyDelete"
QT_MOC_LITERAL(81, 1158, 15), // "deleteWordRight"
QT_MOC_LITERAL(82, 1174, 9), // "transpose"
QT_MOC_LITERAL(83, 1184, 13), // "transposeWord"
QT_MOC_LITERAL(84, 1198, 10), // "cursorLeft"
QT_MOC_LITERAL(85, 1209, 15), // "shiftCursorLeft"
QT_MOC_LITERAL(86, 1225, 11), // "cursorRight"
QT_MOC_LITERAL(87, 1237, 16), // "shiftCursorRight"
QT_MOC_LITERAL(88, 1254, 8), // "wordLeft"
QT_MOC_LITERAL(89, 1263, 13), // "shiftWordLeft"
QT_MOC_LITERAL(90, 1277, 9), // "wordRight"
QT_MOC_LITERAL(91, 1287, 14), // "shiftWordRight"
QT_MOC_LITERAL(92, 1302, 4), // "home"
QT_MOC_LITERAL(93, 1307, 9), // "shiftHome"
QT_MOC_LITERAL(94, 1317, 3), // "end"
QT_MOC_LITERAL(95, 1321, 8), // "shiftEnd"
QT_MOC_LITERAL(96, 1330, 2), // "up"
QT_MOC_LITERAL(97, 1333, 7), // "shiftUp"
QT_MOC_LITERAL(98, 1341, 4), // "down"
QT_MOC_LITERAL(99, 1346, 9), // "shiftDown"
QT_MOC_LITERAL(100, 1356, 8), // "scrollUp"
QT_MOC_LITERAL(101, 1365, 10), // "scrollDown"
QT_MOC_LITERAL(102, 1376, 9), // "topOfView"
QT_MOC_LITERAL(103, 1386, 14), // "shiftTopOfView"
QT_MOC_LITERAL(104, 1401, 12), // "bottomOfView"
QT_MOC_LITERAL(105, 1414, 17), // "shiftBottomOfView"
QT_MOC_LITERAL(106, 1432, 6), // "pageUp"
QT_MOC_LITERAL(107, 1439, 11), // "shiftPageUp"
QT_MOC_LITERAL(108, 1451, 8), // "pageDown"
QT_MOC_LITERAL(109, 1460, 13), // "shiftPageDown"
QT_MOC_LITERAL(110, 1474, 3), // "top"
QT_MOC_LITERAL(111, 1478, 8), // "shiftTop"
QT_MOC_LITERAL(112, 1487, 6), // "bottom"
QT_MOC_LITERAL(113, 1494, 11), // "shiftBottom"
QT_MOC_LITERAL(114, 1506, 17), // "toMatchingBracket"
QT_MOC_LITERAL(115, 1524, 22), // "shiftToMatchingBracket"
QT_MOC_LITERAL(116, 1547, 18), // "toPrevModifiedLine"
QT_MOC_LITERAL(117, 1566, 18), // "toNextModifiedLine"
QT_MOC_LITERAL(118, 1585, 9), // "insertTab"
QT_MOC_LITERAL(119, 1595, 8), // "gotoLine"
QT_MOC_LITERAL(120, 1604, 6), // "setEol"
QT_MOC_LITERAL(121, 1611, 3), // "eol"
QT_MOC_LITERAL(122, 1615, 9), // "setAddBom"
QT_MOC_LITERAL(123, 1625, 7), // "enabled"
QT_MOC_LITERAL(124, 1633, 4), // "find"
QT_MOC_LITERAL(125, 1638, 20), // "findSelectedForwards"
QT_MOC_LITERAL(126, 1659, 21), // "findSelectedBackwards"
QT_MOC_LITERAL(127, 1681, 26), // "findNextOccurunceAndSelect"
QT_MOC_LITERAL(128, 1708, 26), // "findAllOccuruncesAndSelect"
QT_MOC_LITERAL(129, 1735, 29), // "skipCurrentOccurunceSelection"
QT_MOC_LITERAL(130, 1765, 7), // "replace"
QT_MOC_LITERAL(131, 1773, 8), // "findNext"
QT_MOC_LITERAL(132, 1782, 12), // "findPrevious"
QT_MOC_LITERAL(133, 1795, 21), // "showSearchWrappedHint"
QT_MOC_LITERAL(134, 1817, 15), // "isReverseSearch"
QT_MOC_LITERAL(135, 1833, 31), // "createMultiCursorsFromSelection"
QT_MOC_LITERAL(136, 1865, 27), // "removeCursorsFromEmptyLines"
QT_MOC_LITERAL(137, 1893, 19), // "setFoldingMarkersOn"
QT_MOC_LITERAL(138, 1913, 6), // "enable"
QT_MOC_LITERAL(139, 1920, 13), // "setIconBorder"
QT_MOC_LITERAL(140, 1934, 16), // "setLineNumbersOn"
QT_MOC_LITERAL(141, 1951, 17), // "setScrollBarMarks"
QT_MOC_LITERAL(142, 1969, 19), // "setScrollBarMiniMap"
QT_MOC_LITERAL(143, 1989, 22), // "setScrollBarMiniMapAll"
QT_MOC_LITERAL(144, 2012, 24), // "setScrollBarMiniMapWidth"
QT_MOC_LITERAL(145, 2037, 5), // "width"
QT_MOC_LITERAL(146, 2043, 20), // "toggleFoldingMarkers"
QT_MOC_LITERAL(147, 2064, 16), // "toggleIconBorder"
QT_MOC_LITERAL(148, 2081, 19), // "toggleLineNumbersOn"
QT_MOC_LITERAL(149, 2101, 20), // "toggleScrollBarMarks"
QT_MOC_LITERAL(150, 2122, 22), // "toggleScrollBarMiniMap"
QT_MOC_LITERAL(151, 2145, 25), // "toggleScrollBarMiniMapAll"
QT_MOC_LITERAL(152, 2171, 17), // "toggleDynWordWrap"
QT_MOC_LITERAL(153, 2189, 20), // "setDynWrapIndicators"
QT_MOC_LITERAL(154, 2210, 4), // "mode"
QT_MOC_LITERAL(155, 2215, 20), // "slotSelectionChanged"
QT_MOC_LITERAL(156, 2236, 15), // "toggleInputMode"
QT_MOC_LITERAL(157, 2252, 14), // "cycleInputMode"
QT_MOC_LITERAL(158, 2267, 14), // "slotUpdateUndo"
QT_MOC_LITERAL(159, 2282, 12), // "toggleInsert"
QT_MOC_LITERAL(160, 2295, 10), // "reloadFile"
QT_MOC_LITERAL(161, 2306, 14), // "toggleWWMarker"
QT_MOC_LITERAL(162, 2321, 14), // "toggleNPSpaces"
QT_MOC_LITERAL(163, 2336, 15), // "toggleWordCount"
QT_MOC_LITERAL(164, 2352, 15), // "toggleWriteLock"
QT_MOC_LITERAL(165, 2368, 15), // "switchToCmdLine"
QT_MOC_LITERAL(166, 2384, 20), // "slotReadWriteChanged"
QT_MOC_LITERAL(167, 2405, 21), // "toggleCamelCaseCursor"
QT_MOC_LITERAL(168, 2427, 20), // "slotDocumentReloaded"
QT_MOC_LITERAL(169, 2448, 25), // "slotDocumentAboutToReload"
QT_MOC_LITERAL(170, 2474, 12), // "slotGotFocus"
QT_MOC_LITERAL(171, 2487, 13), // "slotLostFocus"
QT_MOC_LITERAL(172, 2501, 16), // "slotSaveCanceled"
QT_MOC_LITERAL(173, 2518, 5), // "error"
QT_MOC_LITERAL(174, 2524, 16), // "slotConfigDialog"
QT_MOC_LITERAL(175, 2541, 21), // "exportHtmlToClipboard"
QT_MOC_LITERAL(176, 2563, 16), // "exportHtmlToFile"
QT_MOC_LITERAL(177, 2580, 21), // "slotFoldToplevelNodes"
QT_MOC_LITERAL(178, 2602, 23), // "slotExpandToplevelNodes"
QT_MOC_LITERAL(179, 2626, 17), // "slotToggleFolding"
QT_MOC_LITERAL(180, 2644, 25), // "slotToggleFoldingsInRange"
QT_MOC_LITERAL(181, 2670, 13), // "slotHlChanged"
QT_MOC_LITERAL(182, 2684, 19), // "updateFoldingConfig"
QT_MOC_LITERAL(183, 2704, 24), // "toggleOnTheFlySpellCheck"
QT_MOC_LITERAL(184, 2729, 1), // "b"
QT_MOC_LITERAL(185, 2731, 16), // "changeDictionary"
QT_MOC_LITERAL(186, 2748, 31), // "reflectOnTheFlySpellCheckStatus"
QT_MOC_LITERAL(187, 2780, 16), // "saveFoldingState"
QT_MOC_LITERAL(188, 2797, 17), // "applyFoldingState"
QT_MOC_LITERAL(189, 2815, 23), // "slotDelayedUpdateOfView"
QT_MOC_LITERAL(190, 2839, 5), // "print"
QT_MOC_LITERAL(191, 2845, 12) // "printPreview"

    },
    "KTextEditor::ViewPrivate\0completionExecuted\0"
    "\0KTextEditor::View*\0view\0KTextEditor::Cursor\0"
    "position\0KTextEditor::CodeCompletionModel*\0"
    "model\0QModelIndex\0completionAborted\0"
    "annotationContextMenuAboutToShow\0"
    "QMenu*\0menu\0line\0annotationActivated\0"
    "annotationBorderVisibilityChanged\0"
    "View*\0visible\0navigateLeft\0navigateRight\0"
    "navigateUp\0navigateDown\0navigateAccept\0"
    "navigateBack\0dropEventPass\0QDropEvent*\0"
    "displayRangeChanged\0KTextEditor::ViewPrivate*\0"
    "delayedUpdateOfView\0caretChangedRange\0"
    "paste\0const QString*\0textToPaste\0cut\0"
    "copy\0pasteSelection\0swapWithClipboard\0"
    "applyWordWrap\0aboutToShowContextMenu\0"
    "aboutToHideContextMenu\0userInvokedCompletion\0"
    "inlineNotesReset\0inlineNotesLineChanged\0"
    "setSelection\0KTextEditor::Range\0"
    "selection\0removeSelection\0removeSelectionText\0"
    "setBlockSelection\0on\0toggleBlockSelection\0"
    "clearSelection\0redraw\0finishedChangingSelection\0"
    "removeSelectedText\0selectAll\0indent\0"
    "unIndent\0cleanIndent\0formatIndent\0"
    "align\0alignOn\0comment\0uncomment\0"
    "toggleComment\0killLine\0"
    "goToPreviousEditingPosition\0"
    "goToNextEditingPosition\0uppercase\0"
    "lowercase\0capitalize\0joinLines\0keyReturn\0"
    "smartNewline\0noIndentNewline\0newLineAbove\0"
    "newLineBelow\0backspace\0deleteWordLeft\0"
    "keyDelete\0deleteWordRight\0transpose\0"
    "transposeWord\0cursorLeft\0shiftCursorLeft\0"
    "cursorRight\0shiftCursorRight\0wordLeft\0"
    "shiftWordLeft\0wordRight\0shiftWordRight\0"
    "home\0shiftHome\0end\0shiftEnd\0up\0shiftUp\0"
    "down\0shiftDown\0scrollUp\0scrollDown\0"
    "topOfView\0shiftTopOfView\0bottomOfView\0"
    "shiftBottomOfView\0pageUp\0shiftPageUp\0"
    "pageDown\0shiftPageDown\0top\0shiftTop\0"
    "bottom\0shiftBottom\0toMatchingBracket\0"
    "shiftToMatchingBracket\0toPrevModifiedLine\0"
    "toNextModifiedLine\0insertTab\0gotoLine\0"
    "setEol\0eol\0setAddBom\0enabled\0find\0"
    "findSelectedForwards\0findSelectedBackwards\0"
    "findNextOccurunceAndSelect\0"
    "findAllOccuruncesAndSelect\0"
    "skipCurrentOccurunceSelection\0replace\0"
    "findNext\0findPrevious\0showSearchWrappedHint\0"
    "isReverseSearch\0createMultiCursorsFromSelection\0"
    "removeCursorsFromEmptyLines\0"
    "setFoldingMarkersOn\0enable\0setIconBorder\0"
    "setLineNumbersOn\0setScrollBarMarks\0"
    "setScrollBarMiniMap\0setScrollBarMiniMapAll\0"
    "setScrollBarMiniMapWidth\0width\0"
    "toggleFoldingMarkers\0toggleIconBorder\0"
    "toggleLineNumbersOn\0toggleScrollBarMarks\0"
    "toggleScrollBarMiniMap\0toggleScrollBarMiniMapAll\0"
    "toggleDynWordWrap\0setDynWrapIndicators\0"
    "mode\0slotSelectionChanged\0toggleInputMode\0"
    "cycleInputMode\0slotUpdateUndo\0"
    "toggleInsert\0reloadFile\0toggleWWMarker\0"
    "toggleNPSpaces\0toggleWordCount\0"
    "toggleWriteLock\0switchToCmdLine\0"
    "slotReadWriteChanged\0toggleCamelCaseCursor\0"
    "slotDocumentReloaded\0slotDocumentAboutToReload\0"
    "slotGotFocus\0slotLostFocus\0slotSaveCanceled\0"
    "error\0slotConfigDialog\0exportHtmlToClipboard\0"
    "exportHtmlToFile\0slotFoldToplevelNodes\0"
    "slotExpandToplevelNodes\0slotToggleFolding\0"
    "slotToggleFoldingsInRange\0slotHlChanged\0"
    "updateFoldingConfig\0toggleOnTheFlySpellCheck\0"
    "b\0changeDictionary\0reflectOnTheFlySpellCheckStatus\0"
    "saveFoldingState\0applyFoldingState\0"
    "slotDelayedUpdateOfView\0print\0"
    "printPreview"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KTextEditor__ViewPrivate[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
     164,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      15,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    4,  834,    2, 0x06 /* Public */,
      10,    1,  843,    2, 0x06 /* Public */,
      11,    3,  846,    2, 0x06 /* Public */,
      15,    2,  853,    2, 0x06 /* Public */,
      16,    2,  858,    2, 0x06 /* Public */,
      19,    0,  863,    2, 0x06 /* Public */,
      20,    0,  864,    2, 0x06 /* Public */,
      21,    0,  865,    2, 0x06 /* Public */,
      22,    0,  866,    2, 0x06 /* Public */,
      23,    0,  867,    2, 0x06 /* Public */,
      24,    0,  868,    2, 0x06 /* Public */,
      25,    1,  869,    2, 0x06 /* Public */,
      27,    1,  872,    2, 0x06 /* Public */,
      29,    0,  875,    2, 0x06 /* Public */,
      30,    1,  876,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      31,    1,  879,    2, 0x0a /* Public */,
      31,    0,  882,    2, 0x2a /* Public | MethodCloned */,
      34,    0,  883,    2, 0x0a /* Public */,
      35,    0,  884,    2, 0x0a /* Public */,
      36,    0,  885,    2, 0x08 /* Private */,
      37,    0,  886,    2, 0x08 /* Private */,
      38,    0,  887,    2, 0x08 /* Private */,
      39,    0,  888,    2, 0x08 /* Private */,
      40,    0,  889,    2, 0x08 /* Private */,
      41,    0,  890,    2, 0x0a /* Public */,
      42,    0,  891,    2, 0x08 /* Private */,
      43,    1,  892,    2, 0x08 /* Private */,
      44,    1,  895,    2, 0x0a /* Public */,
      47,    0,  898,    2, 0x0a /* Public */,
      48,    0,  899,    2, 0x0a /* Public */,
      49,    1,  900,    2, 0x0a /* Public */,
      51,    0,  903,    2, 0x0a /* Public */,
      52,    0,  904,    2, 0x0a /* Public */,
      52,    2,  905,    2, 0x0a /* Public */,
      52,    1,  910,    2, 0x2a /* Public | MethodCloned */,
      55,    0,  913,    2, 0x0a /* Public */,
      56,    0,  914,    2, 0x0a /* Public */,
      57,    0,  915,    2, 0x0a /* Public */,
      58,    0,  916,    2, 0x0a /* Public */,
      59,    0,  917,    2, 0x0a /* Public */,
      60,    0,  918,    2, 0x0a /* Public */,
      61,    0,  919,    2, 0x0a /* Public */,
      62,    0,  920,    2, 0x0a /* Public */,
      63,    0,  921,    2, 0x0a /* Public */,
      64,    0,  922,    2, 0x0a /* Public */,
      65,    0,  923,    2, 0x0a /* Public */,
      66,    0,  924,    2, 0x0a /* Public */,
      67,    0,  925,    2, 0x0a /* Public */,
      68,    0,  926,    2, 0x0a /* Public */,
      69,    0,  927,    2, 0x0a /* Public */,
      70,    0,  928,    2, 0x0a /* Public */,
      71,    0,  929,    2, 0x0a /* Public */,
      72,    0,  930,    2, 0x0a /* Public */,
      73,    0,  931,    2, 0x0a /* Public */,
      74,    0,  932,    2, 0x0a /* Public */,
      75,    0,  933,    2, 0x0a /* Public */,
      76,    0,  934,    2, 0x0a /* Public */,
      77,    0,  935,    2, 0x0a /* Public */,
      78,    0,  936,    2, 0x0a /* Public */,
      79,    0,  937,    2, 0x0a /* Public */,
      80,    0,  938,    2, 0x0a /* Public */,
      81,    0,  939,    2, 0x0a /* Public */,
      82,    0,  940,    2, 0x0a /* Public */,
      83,    0,  941,    2, 0x0a /* Public */,
      84,    0,  942,    2, 0x0a /* Public */,
      85,    0,  943,    2, 0x0a /* Public */,
      86,    0,  944,    2, 0x0a /* Public */,
      87,    0,  945,    2, 0x0a /* Public */,
      88,    0,  946,    2, 0x0a /* Public */,
      89,    0,  947,    2, 0x0a /* Public */,
      90,    0,  948,    2, 0x0a /* Public */,
      91,    0,  949,    2, 0x0a /* Public */,
      92,    0,  950,    2, 0x0a /* Public */,
      93,    0,  951,    2, 0x0a /* Public */,
      94,    0,  952,    2, 0x0a /* Public */,
      95,    0,  953,    2, 0x0a /* Public */,
      96,    0,  954,    2, 0x0a /* Public */,
      97,    0,  955,    2, 0x0a /* Public */,
      98,    0,  956,    2, 0x0a /* Public */,
      99,    0,  957,    2, 0x0a /* Public */,
     100,    0,  958,    2, 0x0a /* Public */,
     101,    0,  959,    2, 0x0a /* Public */,
     102,    0,  960,    2, 0x0a /* Public */,
     103,    0,  961,    2, 0x0a /* Public */,
     104,    0,  962,    2, 0x0a /* Public */,
     105,    0,  963,    2, 0x0a /* Public */,
     106,    0,  964,    2, 0x0a /* Public */,
     107,    0,  965,    2, 0x0a /* Public */,
     108,    0,  966,    2, 0x0a /* Public */,
     109,    0,  967,    2, 0x0a /* Public */,
     110,    0,  968,    2, 0x0a /* Public */,
     111,    0,  969,    2, 0x0a /* Public */,
     112,    0,  970,    2, 0x0a /* Public */,
     113,    0,  971,    2, 0x0a /* Public */,
     114,    0,  972,    2, 0x0a /* Public */,
     115,    0,  973,    2, 0x0a /* Public */,
     116,    0,  974,    2, 0x0a /* Public */,
     117,    0,  975,    2, 0x0a /* Public */,
     118,    0,  976,    2, 0x0a /* Public */,
     119,    0,  977,    2, 0x0a /* Public */,
     120,    1,  978,    2, 0x0a /* Public */,
     122,    1,  981,    2, 0x0a /* Public */,
     124,    0,  984,    2, 0x0a /* Public */,
     125,    0,  985,    2, 0x0a /* Public */,
     126,    0,  986,    2, 0x0a /* Public */,
     127,    0,  987,    2, 0x0a /* Public */,
     128,    0,  988,    2, 0x0a /* Public */,
     129,    0,  989,    2, 0x0a /* Public */,
     130,    0,  990,    2, 0x0a /* Public */,
     131,    0,  991,    2, 0x0a /* Public */,
     132,    0,  992,    2, 0x0a /* Public */,
     133,    1,  993,    2, 0x0a /* Public */,
     135,    0,  996,    2, 0x0a /* Public */,
     136,    0,  997,    2, 0x0a /* Public */,
     137,    1,  998,    2, 0x0a /* Public */,
     139,    1, 1001,    2, 0x0a /* Public */,
     140,    1, 1004,    2, 0x0a /* Public */,
     141,    1, 1007,    2, 0x0a /* Public */,
     142,    1, 1010,    2, 0x0a /* Public */,
     143,    1, 1013,    2, 0x0a /* Public */,
     144,    1, 1016,    2, 0x0a /* Public */,
     146,    0, 1019,    2, 0x0a /* Public */,
     147,    0, 1020,    2, 0x0a /* Public */,
     148,    0, 1021,    2, 0x0a /* Public */,
     149,    0, 1022,    2, 0x0a /* Public */,
     150,    0, 1023,    2, 0x0a /* Public */,
     151,    0, 1024,    2, 0x0a /* Public */,
     152,    0, 1025,    2, 0x0a /* Public */,
     153,    1, 1026,    2, 0x0a /* Public */,
     155,    0, 1029,    2, 0x08 /* Private */,
     156,    0, 1030,    2, 0x08 /* Private */,
     157,    0, 1031,    2, 0x08 /* Private */,
     158,    0, 1032,    2, 0x0a /* Public */,
     159,    0, 1033,    2, 0x0a /* Public */,
     160,    0, 1034,    2, 0x0a /* Public */,
     161,    0, 1035,    2, 0x0a /* Public */,
     162,    0, 1036,    2, 0x0a /* Public */,
     163,    1, 1037,    2, 0x0a /* Public */,
     164,    0, 1040,    2, 0x0a /* Public */,
     165,    0, 1041,    2, 0x0a /* Public */,
     166,    0, 1042,    2, 0x0a /* Public */,
     167,    0, 1043,    2, 0x0a /* Public */,
     168,    0, 1044,    2, 0x08 /* Private */,
     169,    0, 1045,    2, 0x08 /* Private */,
     170,    0, 1046,    2, 0x08 /* Private */,
     171,    0, 1047,    2, 0x08 /* Private */,
     172,    1, 1048,    2, 0x08 /* Private */,
     174,    0, 1051,    2, 0x08 /* Private */,
     175,    0, 1052,    2, 0x08 /* Private */,
     176,    0, 1053,    2, 0x08 /* Private */,
     177,    0, 1054,    2, 0x0a /* Public */,
     178,    0, 1055,    2, 0x0a /* Public */,
     179,    0, 1056,    2, 0x0a /* Public */,
     180,    0, 1057,    2, 0x0a /* Public */,
     181,    0, 1058,    2, 0x08 /* Private */,
     182,    0, 1059,    2, 0x08 /* Private */,
     183,    1, 1060,    2, 0x09 /* Protected */,
     185,    0, 1063,    2, 0x0a /* Public */,
     186,    1, 1064,    2, 0x0a /* Public */,
     187,    0, 1067,    2, 0x08 /* Private */,
     188,    0, 1068,    2, 0x08 /* Private */,
     189,    0, 1069,    2, 0x08 /* Private */,
     190,    0, 1070,    2, 0x0a /* Public */,
     191,    0, 1071,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 5, 0x80000000 | 7, 0x80000000 | 9,    4,    6,    8,    2,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 12, QMetaType::Int,    4,   13,   14,
    QMetaType::Void, 0x80000000 | 3, QMetaType::Int,    4,   14,
    QMetaType::Void, 0x80000000 | 17, QMetaType::Bool,    4,   18,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 26,    2,
    QMetaType::Void, 0x80000000 | 28,    4,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 3,    2,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 32,   33,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   14,
    QMetaType::Bool, 0x80000000 | 45,   46,
    QMetaType::Bool,
    QMetaType::Bool,
    QMetaType::Bool, QMetaType::Bool,   50,
    QMetaType::Bool,
    QMetaType::Bool,
    QMetaType::Bool, QMetaType::Bool, QMetaType::Bool,   53,   54,
    QMetaType::Bool, QMetaType::Bool,   53,
    QMetaType::Bool,
    QMetaType::Bool,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,  121,
    QMetaType::Void, QMetaType::Bool,  123,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,  134,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,  138,
    QMetaType::Void, QMetaType::Bool,  138,
    QMetaType::Void, QMetaType::Bool,  138,
    QMetaType::Void, QMetaType::Bool,  138,
    QMetaType::Void, QMetaType::Bool,  138,
    QMetaType::Void, QMetaType::Bool,  138,
    QMetaType::Void, QMetaType::Int,  145,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,  154,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   50,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,  173,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,  184,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,  123,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Bool,
    QMetaType::Void,

       0        // eod
};

void KTextEditor::ViewPrivate::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<ViewPrivate *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->completionExecuted((*reinterpret_cast< KTextEditor::View*(*)>(_a[1])),(*reinterpret_cast< const KTextEditor::Cursor(*)>(_a[2])),(*reinterpret_cast< KTextEditor::CodeCompletionModel*(*)>(_a[3])),(*reinterpret_cast< const QModelIndex(*)>(_a[4]))); break;
        case 1: _t->completionAborted((*reinterpret_cast< KTextEditor::View*(*)>(_a[1]))); break;
        case 2: _t->annotationContextMenuAboutToShow((*reinterpret_cast< KTextEditor::View*(*)>(_a[1])),(*reinterpret_cast< QMenu*(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 3: _t->annotationActivated((*reinterpret_cast< KTextEditor::View*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 4: _t->annotationBorderVisibilityChanged((*reinterpret_cast< View*(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 5: _t->navigateLeft(); break;
        case 6: _t->navigateRight(); break;
        case 7: _t->navigateUp(); break;
        case 8: _t->navigateDown(); break;
        case 9: _t->navigateAccept(); break;
        case 10: _t->navigateBack(); break;
        case 11: _t->dropEventPass((*reinterpret_cast< QDropEvent*(*)>(_a[1]))); break;
        case 12: _t->displayRangeChanged((*reinterpret_cast< KTextEditor::ViewPrivate*(*)>(_a[1]))); break;
        case 13: _t->delayedUpdateOfView(); break;
        case 14: _t->caretChangedRange((*reinterpret_cast< KTextEditor::View*(*)>(_a[1]))); break;
        case 15: _t->paste((*reinterpret_cast< const QString*(*)>(_a[1]))); break;
        case 16: _t->paste(); break;
        case 17: _t->cut(); break;
        case 18: _t->copy(); break;
        case 19: _t->pasteSelection(); break;
        case 20: _t->swapWithClipboard(); break;
        case 21: _t->applyWordWrap(); break;
        case 22: _t->aboutToShowContextMenu(); break;
        case 23: _t->aboutToHideContextMenu(); break;
        case 24: _t->userInvokedCompletion(); break;
        case 25: _t->inlineNotesReset(); break;
        case 26: _t->inlineNotesLineChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 27: { bool _r = _t->setSelection((*reinterpret_cast< const KTextEditor::Range(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 28: { bool _r = _t->removeSelection();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 29: { bool _r = _t->removeSelectionText();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 30: { bool _r = _t->setBlockSelection((*reinterpret_cast< bool(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 31: { bool _r = _t->toggleBlockSelection();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 32: { bool _r = _t->clearSelection();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 33: { bool _r = _t->clearSelection((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 34: { bool _r = _t->clearSelection((*reinterpret_cast< bool(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 35: { bool _r = _t->removeSelectedText();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 36: { bool _r = _t->selectAll();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 37: _t->indent(); break;
        case 38: _t->unIndent(); break;
        case 39: _t->cleanIndent(); break;
        case 40: _t->formatIndent(); break;
        case 41: _t->align(); break;
        case 42: _t->alignOn(); break;
        case 43: _t->comment(); break;
        case 44: _t->uncomment(); break;
        case 45: _t->toggleComment(); break;
        case 46: _t->killLine(); break;
        case 47: _t->goToPreviousEditingPosition(); break;
        case 48: _t->goToNextEditingPosition(); break;
        case 49: _t->uppercase(); break;
        case 50: _t->lowercase(); break;
        case 51: _t->capitalize(); break;
        case 52: _t->joinLines(); break;
        case 53: _t->keyReturn(); break;
        case 54: _t->smartNewline(); break;
        case 55: _t->noIndentNewline(); break;
        case 56: _t->newLineAbove(); break;
        case 57: _t->newLineBelow(); break;
        case 58: _t->backspace(); break;
        case 59: _t->deleteWordLeft(); break;
        case 60: _t->keyDelete(); break;
        case 61: _t->deleteWordRight(); break;
        case 62: _t->transpose(); break;
        case 63: _t->transposeWord(); break;
        case 64: _t->cursorLeft(); break;
        case 65: _t->shiftCursorLeft(); break;
        case 66: _t->cursorRight(); break;
        case 67: _t->shiftCursorRight(); break;
        case 68: _t->wordLeft(); break;
        case 69: _t->shiftWordLeft(); break;
        case 70: _t->wordRight(); break;
        case 71: _t->shiftWordRight(); break;
        case 72: _t->home(); break;
        case 73: _t->shiftHome(); break;
        case 74: _t->end(); break;
        case 75: _t->shiftEnd(); break;
        case 76: _t->up(); break;
        case 77: _t->shiftUp(); break;
        case 78: _t->down(); break;
        case 79: _t->shiftDown(); break;
        case 80: _t->scrollUp(); break;
        case 81: _t->scrollDown(); break;
        case 82: _t->topOfView(); break;
        case 83: _t->shiftTopOfView(); break;
        case 84: _t->bottomOfView(); break;
        case 85: _t->shiftBottomOfView(); break;
        case 86: _t->pageUp(); break;
        case 87: _t->shiftPageUp(); break;
        case 88: _t->pageDown(); break;
        case 89: _t->shiftPageDown(); break;
        case 90: _t->top(); break;
        case 91: _t->shiftTop(); break;
        case 92: _t->bottom(); break;
        case 93: _t->shiftBottom(); break;
        case 94: _t->toMatchingBracket(); break;
        case 95: _t->shiftToMatchingBracket(); break;
        case 96: _t->toPrevModifiedLine(); break;
        case 97: _t->toNextModifiedLine(); break;
        case 98: _t->insertTab(); break;
        case 99: _t->gotoLine(); break;
        case 100: _t->setEol((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 101: _t->setAddBom((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 102: _t->find(); break;
        case 103: _t->findSelectedForwards(); break;
        case 104: _t->findSelectedBackwards(); break;
        case 105: _t->findNextOccurunceAndSelect(); break;
        case 106: _t->findAllOccuruncesAndSelect(); break;
        case 107: _t->skipCurrentOccurunceSelection(); break;
        case 108: _t->replace(); break;
        case 109: _t->findNext(); break;
        case 110: _t->findPrevious(); break;
        case 111: _t->showSearchWrappedHint((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 112: _t->createMultiCursorsFromSelection(); break;
        case 113: _t->removeCursorsFromEmptyLines(); break;
        case 114: _t->setFoldingMarkersOn((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 115: _t->setIconBorder((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 116: _t->setLineNumbersOn((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 117: _t->setScrollBarMarks((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 118: _t->setScrollBarMiniMap((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 119: _t->setScrollBarMiniMapAll((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 120: _t->setScrollBarMiniMapWidth((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 121: _t->toggleFoldingMarkers(); break;
        case 122: _t->toggleIconBorder(); break;
        case 123: _t->toggleLineNumbersOn(); break;
        case 124: _t->toggleScrollBarMarks(); break;
        case 125: _t->toggleScrollBarMiniMap(); break;
        case 126: _t->toggleScrollBarMiniMapAll(); break;
        case 127: _t->toggleDynWordWrap(); break;
        case 128: _t->setDynWrapIndicators((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 129: _t->slotSelectionChanged(); break;
        case 130: _t->toggleInputMode(); break;
        case 131: _t->cycleInputMode(); break;
        case 132: _t->slotUpdateUndo(); break;
        case 133: _t->toggleInsert(); break;
        case 134: _t->reloadFile(); break;
        case 135: _t->toggleWWMarker(); break;
        case 136: _t->toggleNPSpaces(); break;
        case 137: _t->toggleWordCount((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 138: _t->toggleWriteLock(); break;
        case 139: _t->switchToCmdLine(); break;
        case 140: _t->slotReadWriteChanged(); break;
        case 141: _t->toggleCamelCaseCursor(); break;
        case 142: _t->slotDocumentReloaded(); break;
        case 143: _t->slotDocumentAboutToReload(); break;
        case 144: _t->slotGotFocus(); break;
        case 145: _t->slotLostFocus(); break;
        case 146: _t->slotSaveCanceled((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 147: _t->slotConfigDialog(); break;
        case 148: _t->exportHtmlToClipboard(); break;
        case 149: _t->exportHtmlToFile(); break;
        case 150: _t->slotFoldToplevelNodes(); break;
        case 151: _t->slotExpandToplevelNodes(); break;
        case 152: _t->slotToggleFolding(); break;
        case 153: _t->slotToggleFoldingsInRange(); break;
        case 154: _t->slotHlChanged(); break;
        case 155: _t->updateFoldingConfig(); break;
        case 156: _t->toggleOnTheFlySpellCheck((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 157: _t->changeDictionary(); break;
        case 158: _t->reflectOnTheFlySpellCheckStatus((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 159: _t->saveFoldingState(); break;
        case 160: _t->applyFoldingState(); break;
        case 161: _t->slotDelayedUpdateOfView(); break;
        case 162: { bool _r = _t->print();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 163: _t->printPreview(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 2:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::CodeCompletionModel* >(); break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Cursor >(); break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::View* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::View* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::View* >(); break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QMenu* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::View* >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< View* >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::ViewPrivate* >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::View* >(); break;
            }
            break;
        case 27:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Range >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (ViewPrivate::*)(KTextEditor::View * , const KTextEditor::Cursor & , KTextEditor::CodeCompletionModel * , const QModelIndex & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ViewPrivate::completionExecuted)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (ViewPrivate::*)(KTextEditor::View * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ViewPrivate::completionAborted)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (ViewPrivate::*)(KTextEditor::View * , QMenu * , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ViewPrivate::annotationContextMenuAboutToShow)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (ViewPrivate::*)(KTextEditor::View * , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ViewPrivate::annotationActivated)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (ViewPrivate::*)(View * , bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ViewPrivate::annotationBorderVisibilityChanged)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (ViewPrivate::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ViewPrivate::navigateLeft)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (ViewPrivate::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ViewPrivate::navigateRight)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (ViewPrivate::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ViewPrivate::navigateUp)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (ViewPrivate::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ViewPrivate::navigateDown)) {
                *result = 8;
                return;
            }
        }
        {
            using _t = void (ViewPrivate::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ViewPrivate::navigateAccept)) {
                *result = 9;
                return;
            }
        }
        {
            using _t = void (ViewPrivate::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ViewPrivate::navigateBack)) {
                *result = 10;
                return;
            }
        }
        {
            using _t = void (ViewPrivate::*)(QDropEvent * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ViewPrivate::dropEventPass)) {
                *result = 11;
                return;
            }
        }
        {
            using _t = void (ViewPrivate::*)(KTextEditor::ViewPrivate * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ViewPrivate::displayRangeChanged)) {
                *result = 12;
                return;
            }
        }
        {
            using _t = void (ViewPrivate::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ViewPrivate::delayedUpdateOfView)) {
                *result = 13;
                return;
            }
        }
        {
            using _t = void (ViewPrivate::*)(KTextEditor::View * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ViewPrivate::caretChangedRange)) {
                *result = 14;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject KTextEditor::ViewPrivate::staticMetaObject = { {
    QMetaObject::SuperData::link<KTextEditor::View::staticMetaObject>(),
    qt_meta_stringdata_KTextEditor__ViewPrivate.data,
    qt_meta_data_KTextEditor__ViewPrivate,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *KTextEditor::ViewPrivate::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KTextEditor::ViewPrivate::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KTextEditor__ViewPrivate.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "KTextEditor::TextHintInterface"))
        return static_cast< KTextEditor::TextHintInterface*>(this);
    if (!strcmp(_clname, "KTextEditor::CodeCompletionInterfaceV2"))
        return static_cast< KTextEditor::CodeCompletionInterfaceV2*>(this);
    if (!strcmp(_clname, "KTextEditor::ConfigInterface"))
        return static_cast< KTextEditor::ConfigInterface*>(this);
    if (!strcmp(_clname, "KTextEditor::InlineNoteInterface"))
        return static_cast< KTextEditor::InlineNoteInterface*>(this);
    if (!strcmp(_clname, "KTextEditor::AnnotationViewInterfaceV2"))
        return static_cast< KTextEditor::AnnotationViewInterfaceV2*>(this);
    if (!strcmp(_clname, "org.kde.KTextEditor.TextHintInterface"))
        return static_cast< KTextEditor::TextHintInterface*>(this);
    if (!strcmp(_clname, "org.kde.KTextEditor.ConfigInterface"))
        return static_cast< KTextEditor::ConfigInterface*>(this);
    if (!strcmp(_clname, "org.kde.KTextEditor.CodeCompletionInterface"))
        return static_cast< KTextEditor::CodeCompletionInterface*>(this);
    if (!strcmp(_clname, "org.kde.KTextEditor.CodeCompletionInterfaceV2"))
        return static_cast< KTextEditor::CodeCompletionInterfaceV2*>(this);
    if (!strcmp(_clname, "org.kde.KTextEditor.AnnotationViewInterface"))
        return static_cast< KTextEditor::AnnotationViewInterface*>(this);
    if (!strcmp(_clname, "org.kde.KTextEditor.AnnotationViewInterfaceV2"))
        return static_cast< KTextEditor::AnnotationViewInterfaceV2*>(this);
    if (!strcmp(_clname, "org.kde.KTextEditor.InlineNoteInterface"))
        return static_cast< KTextEditor::InlineNoteInterface*>(this);
    return KTextEditor::View::qt_metacast(_clname);
}

int KTextEditor::ViewPrivate::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KTextEditor::View::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 164)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 164;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 164)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 164;
    }
    return _id;
}

// SIGNAL 0
void KTextEditor::ViewPrivate::completionExecuted(KTextEditor::View * _t1, const KTextEditor::Cursor & _t2, KTextEditor::CodeCompletionModel * _t3, const QModelIndex & _t4)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t4))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KTextEditor::ViewPrivate::completionAborted(KTextEditor::View * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void KTextEditor::ViewPrivate::annotationContextMenuAboutToShow(KTextEditor::View * _t1, QMenu * _t2, int _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void KTextEditor::ViewPrivate::annotationActivated(KTextEditor::View * _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void KTextEditor::ViewPrivate::annotationBorderVisibilityChanged(View * _t1, bool _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void KTextEditor::ViewPrivate::navigateLeft()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void KTextEditor::ViewPrivate::navigateRight()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void KTextEditor::ViewPrivate::navigateUp()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void KTextEditor::ViewPrivate::navigateDown()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void KTextEditor::ViewPrivate::navigateAccept()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void KTextEditor::ViewPrivate::navigateBack()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void KTextEditor::ViewPrivate::dropEventPass(QDropEvent * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 11, _a);
}

// SIGNAL 12
void KTextEditor::ViewPrivate::displayRangeChanged(KTextEditor::ViewPrivate * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 12, _a);
}

// SIGNAL 13
void KTextEditor::ViewPrivate::delayedUpdateOfView()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void KTextEditor::ViewPrivate::caretChangedRange(KTextEditor::View * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 14, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
