/****************************************************************************
** Meta object code from reading C++ file 'spellcheckbar.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../ktexteditor-5.116.0/src/spellcheck/spellcheckbar.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'spellcheckbar.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_SpellCheckBar_t {
    QByteArrayData data[33];
    char stringdata0[365];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_SpellCheckBar_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_SpellCheckBar_t qt_meta_stringdata_SpellCheckBar = {
    {
QT_MOC_LITERAL(0, 0, 13), // "SpellCheckBar"
QT_MOC_LITERAL(1, 14, 4), // "done"
QT_MOC_LITERAL(2, 19, 0), // ""
QT_MOC_LITERAL(3, 20, 9), // "newBuffer"
QT_MOC_LITERAL(4, 30, 11), // "misspelling"
QT_MOC_LITERAL(5, 42, 4), // "word"
QT_MOC_LITERAL(6, 47, 5), // "start"
QT_MOC_LITERAL(7, 53, 7), // "replace"
QT_MOC_LITERAL(8, 61, 7), // "oldWord"
QT_MOC_LITERAL(9, 69, 7), // "newWord"
QT_MOC_LITERAL(10, 77, 4), // "stop"
QT_MOC_LITERAL(11, 82, 6), // "cancel"
QT_MOC_LITERAL(12, 89, 11), // "autoCorrect"
QT_MOC_LITERAL(13, 101, 11), // "currentWord"
QT_MOC_LITERAL(14, 113, 11), // "replaceWord"
QT_MOC_LITERAL(15, 125, 16), // "spellCheckStatus"
QT_MOC_LITERAL(16, 142, 15), // "languageChanged"
QT_MOC_LITERAL(17, 158, 8), // "language"
QT_MOC_LITERAL(18, 167, 9), // "setBuffer"
QT_MOC_LITERAL(19, 177, 15), // "slotMisspelling"
QT_MOC_LITERAL(20, 193, 8), // "slotDone"
QT_MOC_LITERAL(21, 202, 10), // "slotCancel"
QT_MOC_LITERAL(22, 213, 11), // "slotAddWord"
QT_MOC_LITERAL(23, 225, 15), // "slotReplaceWord"
QT_MOC_LITERAL(24, 241, 14), // "slotReplaceAll"
QT_MOC_LITERAL(25, 256, 8), // "slotSkip"
QT_MOC_LITERAL(26, 265, 11), // "slotSkipAll"
QT_MOC_LITERAL(27, 277, 11), // "slotSuggest"
QT_MOC_LITERAL(28, 289, 18), // "slotChangeLanguage"
QT_MOC_LITERAL(29, 308, 15), // "slotAutocorrect"
QT_MOC_LITERAL(30, 324, 13), // "setGuiEnabled"
QT_MOC_LITERAL(31, 338, 1), // "b"
QT_MOC_LITERAL(32, 340, 24) // "setProgressDialogVisible"

    },
    "SpellCheckBar\0done\0\0newBuffer\0misspelling\0"
    "word\0start\0replace\0oldWord\0newWord\0"
    "stop\0cancel\0autoCorrect\0currentWord\0"
    "replaceWord\0spellCheckStatus\0"
    "languageChanged\0language\0setBuffer\0"
    "slotMisspelling\0slotDone\0slotCancel\0"
    "slotAddWord\0slotReplaceWord\0slotReplaceAll\0"
    "slotSkip\0slotSkipAll\0slotSuggest\0"
    "slotChangeLanguage\0slotAutocorrect\0"
    "setGuiEnabled\0b\0setProgressDialogVisible"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_SpellCheckBar[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      22,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       8,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  124,    2, 0x06 /* Public */,
       4,    2,  127,    2, 0x06 /* Public */,
       7,    3,  132,    2, 0x06 /* Public */,
      10,    0,  139,    2, 0x06 /* Public */,
      11,    0,  140,    2, 0x06 /* Public */,
      12,    2,  141,    2, 0x06 /* Public */,
      15,    1,  146,    2, 0x06 /* Public */,
      16,    1,  149,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      18,    1,  152,    2, 0x0a /* Public */,
      19,    2,  155,    2, 0x08 /* Private */,
      20,    0,  160,    2, 0x08 /* Private */,
      21,    0,  161,    2, 0x08 /* Private */,
      22,    0,  162,    2, 0x08 /* Private */,
      23,    0,  163,    2, 0x08 /* Private */,
      24,    0,  164,    2, 0x08 /* Private */,
      25,    0,  165,    2, 0x08 /* Private */,
      26,    0,  166,    2, 0x08 /* Private */,
      27,    0,  167,    2, 0x08 /* Private */,
      28,    1,  168,    2, 0x08 /* Private */,
      29,    0,  171,    2, 0x08 /* Private */,
      30,    1,  172,    2, 0x08 /* Private */,
      32,    1,  175,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, QMetaType::QString, QMetaType::Int,    5,    6,
    QMetaType::Void, QMetaType::QString, QMetaType::Int, QMetaType::QString,    8,    6,    9,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,   13,   14,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QString,   17,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QString, QMetaType::Int,    5,    6,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   31,
    QMetaType::Void, QMetaType::Bool,   31,

       0        // eod
};

void SpellCheckBar::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<SpellCheckBar *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->done((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->misspelling((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 2: _t->replace((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 3: _t->stop(); break;
        case 4: _t->cancel(); break;
        case 5: _t->autoCorrect((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 6: _t->spellCheckStatus((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 7: _t->languageChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 8: _t->setBuffer((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 9: _t->slotMisspelling((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 10: _t->slotDone(); break;
        case 11: _t->slotCancel(); break;
        case 12: _t->slotAddWord(); break;
        case 13: _t->slotReplaceWord(); break;
        case 14: _t->slotReplaceAll(); break;
        case 15: _t->slotSkip(); break;
        case 16: _t->slotSkipAll(); break;
        case 17: _t->slotSuggest(); break;
        case 18: _t->slotChangeLanguage((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 19: _t->slotAutocorrect(); break;
        case 20: _t->setGuiEnabled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 21: _t->setProgressDialogVisible((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (SpellCheckBar::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SpellCheckBar::done)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (SpellCheckBar::*)(const QString & , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SpellCheckBar::misspelling)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (SpellCheckBar::*)(const QString & , int , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SpellCheckBar::replace)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (SpellCheckBar::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SpellCheckBar::stop)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (SpellCheckBar::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SpellCheckBar::cancel)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (SpellCheckBar::*)(const QString & , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SpellCheckBar::autoCorrect)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (SpellCheckBar::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SpellCheckBar::spellCheckStatus)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (SpellCheckBar::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SpellCheckBar::languageChanged)) {
                *result = 7;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject SpellCheckBar::staticMetaObject = { {
    QMetaObject::SuperData::link<KateViewBarWidget::staticMetaObject>(),
    qt_meta_stringdata_SpellCheckBar.data,
    qt_meta_data_SpellCheckBar,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *SpellCheckBar::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SpellCheckBar::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_SpellCheckBar.stringdata0))
        return static_cast<void*>(this);
    return KateViewBarWidget::qt_metacast(_clname);
}

int SpellCheckBar::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KateViewBarWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 22)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 22;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 22)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 22;
    }
    return _id;
}

// SIGNAL 0
void SpellCheckBar::done(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void SpellCheckBar::misspelling(const QString & _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void SpellCheckBar::replace(const QString & _t1, int _t2, const QString & _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void SpellCheckBar::stop()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void SpellCheckBar::cancel()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void SpellCheckBar::autoCorrect(const QString & _t1, const QString & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void SpellCheckBar::spellCheckStatus(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void SpellCheckBar::languageChanged(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
