/****************************************************************************
** Meta object code from reading C++ file 'wordcounter.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../ktexteditor-5.116.0/src/view/wordcounter.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'wordcounter.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_WordCounter_t {
    QByteArrayData data[19];
    char stringdata0[247];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_WordCounter_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_WordCounter_t qt_meta_stringdata_WordCounter = {
    {
QT_MOC_LITERAL(0, 0, 11), // "WordCounter"
QT_MOC_LITERAL(1, 12, 7), // "changed"
QT_MOC_LITERAL(2, 20, 0), // ""
QT_MOC_LITERAL(3, 21, 15), // "wordsInDocument"
QT_MOC_LITERAL(4, 37, 16), // "wordsInSelection"
QT_MOC_LITERAL(5, 54, 15), // "charsInDocument"
QT_MOC_LITERAL(6, 70, 16), // "charsInSelection"
QT_MOC_LITERAL(7, 87, 12), // "textInserted"
QT_MOC_LITERAL(8, 100, 22), // "KTextEditor::Document*"
QT_MOC_LITERAL(9, 123, 8), // "document"
QT_MOC_LITERAL(10, 132, 18), // "KTextEditor::Range"
QT_MOC_LITERAL(11, 151, 5), // "range"
QT_MOC_LITERAL(12, 157, 11), // "textRemoved"
QT_MOC_LITERAL(13, 169, 7), // "oldText"
QT_MOC_LITERAL(14, 177, 11), // "recalculate"
QT_MOC_LITERAL(15, 189, 16), // "selectionChanged"
QT_MOC_LITERAL(16, 206, 18), // "KTextEditor::View*"
QT_MOC_LITERAL(17, 225, 4), // "view"
QT_MOC_LITERAL(18, 230, 16) // "recalculateLines"

    },
    "WordCounter\0changed\0\0wordsInDocument\0"
    "wordsInSelection\0charsInDocument\0"
    "charsInSelection\0textInserted\0"
    "KTextEditor::Document*\0document\0"
    "KTextEditor::Range\0range\0textRemoved\0"
    "oldText\0recalculate\0selectionChanged\0"
    "KTextEditor::View*\0view\0recalculateLines"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_WordCounter[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       6,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    4,   44,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       7,    2,   53,    2, 0x08 /* Private */,
      12,    3,   58,    2, 0x08 /* Private */,
      14,    1,   65,    2, 0x08 /* Private */,
      15,    1,   68,    2, 0x08 /* Private */,
      18,    0,   71,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::Int,    3,    4,    5,    6,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 8, 0x80000000 | 10,    9,   11,
    QMetaType::Void, 0x80000000 | 8, 0x80000000 | 10, QMetaType::QString,    9,   11,   13,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, 0x80000000 | 16,   17,
    QMetaType::Void,

       0        // eod
};

void WordCounter::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<WordCounter *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->changed((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4]))); break;
        case 1: _t->textInserted((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1])),(*reinterpret_cast< KTextEditor::Range(*)>(_a[2]))); break;
        case 2: _t->textRemoved((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1])),(*reinterpret_cast< KTextEditor::Range(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 3: _t->recalculate((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1]))); break;
        case 4: _t->selectionChanged((*reinterpret_cast< KTextEditor::View*(*)>(_a[1]))); break;
        case 5: _t->recalculateLines(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (WordCounter::*)(int , int , int , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&WordCounter::changed)) {
                *result = 0;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject WordCounter::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_WordCounter.data,
    qt_meta_data_WordCounter,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *WordCounter::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *WordCounter::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_WordCounter.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int WordCounter::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void WordCounter::changed(int _t1, int _t2, int _t3, int _t4)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t4))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
