#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'filetypeconfigwidget.ui'
**
** Created by: Qt User Interface Compiler version 5.15.17
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FILETYPECONFIGWIDGET_H
#define UI_FILETYPECONFIGWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "variablelineedit.h"

QT_BEGIN_NAMESPACE

class Ui_FileTypeConfigWidget
{
public:
    QVBoxLayout *vboxLayout;
    QHBoxLayout *hboxLayout;
    QLabel *lblFiletype;
    QComboBox *cmbFiletypes;
    QPushButton *btnNew;
    QPushButton *btnDelete;
    QSpacerItem *spacerItem;
    QGroupBox *gbProperties;
    QFormLayout *formLayout;
    QLabel *lblName;
    QLineEdit *edtName;
    QLabel *lblSection;
    QLineEdit *edtSection;
    QLabel *lblVariables;
    VariableLineEdit *edtVariables;
    QLabel *lblHl;
    QComboBox *cmbHl;
    QLabel *lblIndenter;
    QComboBox *cmbIndenter;
    QLabel *lblExtensions;
    QLineEdit *edtFileExtensions;
    QLabel *lblMimeTypes;
    QHBoxLayout *hboxLayout1;
    QLineEdit *edtMimeTypes;
    QToolButton *btnMimeTypes;
    QLabel *lblPriority;
    QSpinBox *sbPriority;
    QSpacerItem *spacerItem1;

    void setupUi(QWidget *FileTypeConfigWidget)
    {
        if (FileTypeConfigWidget->objectName().isEmpty())
            FileTypeConfigWidget->setObjectName(QString::fromUtf8("FileTypeConfigWidget"));
        vboxLayout = new QVBoxLayout(FileTypeConfigWidget);
        vboxLayout->setContentsMargins(0, 0, 0, 0);
        vboxLayout->setObjectName(QString::fromUtf8("vboxLayout"));
        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName(QString::fromUtf8("hboxLayout"));
        lblFiletype = new QLabel(FileTypeConfigWidget);
        lblFiletype->setObjectName(QString::fromUtf8("lblFiletype"));

        hboxLayout->addWidget(lblFiletype);

        cmbFiletypes = new QComboBox(FileTypeConfigWidget);
        cmbFiletypes->setObjectName(QString::fromUtf8("cmbFiletypes"));

        hboxLayout->addWidget(cmbFiletypes);

        btnNew = new QPushButton(FileTypeConfigWidget);
        btnNew->setObjectName(QString::fromUtf8("btnNew"));

        hboxLayout->addWidget(btnNew);

        btnDelete = new QPushButton(FileTypeConfigWidget);
        btnDelete->setObjectName(QString::fromUtf8("btnDelete"));

        hboxLayout->addWidget(btnDelete);

        spacerItem = new QSpacerItem(1, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout->addItem(spacerItem);


        vboxLayout->addLayout(hboxLayout);

        gbProperties = new QGroupBox(FileTypeConfigWidget);
        gbProperties->setObjectName(QString::fromUtf8("gbProperties"));
        formLayout = new QFormLayout(gbProperties);
        formLayout->setObjectName(QString::fromUtf8("formLayout"));
        lblName = new QLabel(gbProperties);
        lblName->setObjectName(QString::fromUtf8("lblName"));

        formLayout->setWidget(0, QFormLayout::LabelRole, lblName);

        edtName = new QLineEdit(gbProperties);
        edtName->setObjectName(QString::fromUtf8("edtName"));

        formLayout->setWidget(0, QFormLayout::FieldRole, edtName);

        lblSection = new QLabel(gbProperties);
        lblSection->setObjectName(QString::fromUtf8("lblSection"));

        formLayout->setWidget(1, QFormLayout::LabelRole, lblSection);

        edtSection = new QLineEdit(gbProperties);
        edtSection->setObjectName(QString::fromUtf8("edtSection"));

        formLayout->setWidget(1, QFormLayout::FieldRole, edtSection);

        lblVariables = new QLabel(gbProperties);
        lblVariables->setObjectName(QString::fromUtf8("lblVariables"));

        formLayout->setWidget(2, QFormLayout::LabelRole, lblVariables);

        edtVariables = new VariableLineEdit(gbProperties);
        edtVariables->setObjectName(QString::fromUtf8("edtVariables"));

        formLayout->setWidget(2, QFormLayout::FieldRole, edtVariables);

        lblHl = new QLabel(gbProperties);
        lblHl->setObjectName(QString::fromUtf8("lblHl"));

        formLayout->setWidget(3, QFormLayout::LabelRole, lblHl);

        cmbHl = new QComboBox(gbProperties);
        cmbHl->setObjectName(QString::fromUtf8("cmbHl"));

        formLayout->setWidget(3, QFormLayout::FieldRole, cmbHl);

        lblIndenter = new QLabel(gbProperties);
        lblIndenter->setObjectName(QString::fromUtf8("lblIndenter"));

        formLayout->setWidget(4, QFormLayout::LabelRole, lblIndenter);

        cmbIndenter = new QComboBox(gbProperties);
        cmbIndenter->setObjectName(QString::fromUtf8("cmbIndenter"));

        formLayout->setWidget(4, QFormLayout::FieldRole, cmbIndenter);

        lblExtensions = new QLabel(gbProperties);
        lblExtensions->setObjectName(QString::fromUtf8("lblExtensions"));

        formLayout->setWidget(5, QFormLayout::LabelRole, lblExtensions);

        edtFileExtensions = new QLineEdit(gbProperties);
        edtFileExtensions->setObjectName(QString::fromUtf8("edtFileExtensions"));

        formLayout->setWidget(5, QFormLayout::FieldRole, edtFileExtensions);

        lblMimeTypes = new QLabel(gbProperties);
        lblMimeTypes->setObjectName(QString::fromUtf8("lblMimeTypes"));

        formLayout->setWidget(6, QFormLayout::LabelRole, lblMimeTypes);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setContentsMargins(0, 0, 0, 0);
        hboxLayout1->setObjectName(QString::fromUtf8("hboxLayout1"));
        edtMimeTypes = new QLineEdit(gbProperties);
        edtMimeTypes->setObjectName(QString::fromUtf8("edtMimeTypes"));

        hboxLayout1->addWidget(edtMimeTypes);

        btnMimeTypes = new QToolButton(gbProperties);
        btnMimeTypes->setObjectName(QString::fromUtf8("btnMimeTypes"));

        hboxLayout1->addWidget(btnMimeTypes);


        formLayout->setLayout(6, QFormLayout::FieldRole, hboxLayout1);

        lblPriority = new QLabel(gbProperties);
        lblPriority->setObjectName(QString::fromUtf8("lblPriority"));

        formLayout->setWidget(7, QFormLayout::LabelRole, lblPriority);

        sbPriority = new QSpinBox(gbProperties);
        sbPriority->setObjectName(QString::fromUtf8("sbPriority"));
        sbPriority->setMinimum(-99);

        formLayout->setWidget(7, QFormLayout::FieldRole, sbPriority);


        vboxLayout->addWidget(gbProperties);

        spacerItem1 = new QSpacerItem(0, 1, QSizePolicy::Minimum, QSizePolicy::Expanding);

        vboxLayout->addItem(spacerItem1);

#if QT_CONFIG(shortcut)
        lblFiletype->setBuddy(cmbFiletypes);
        lblName->setBuddy(edtName);
        lblSection->setBuddy(edtSection);
        lblVariables->setBuddy(edtVariables);
        lblHl->setBuddy(cmbHl);
        lblIndenter->setBuddy(cmbIndenter);
        lblExtensions->setBuddy(edtFileExtensions);
        lblMimeTypes->setBuddy(edtMimeTypes);
        lblPriority->setBuddy(sbPriority);
#endif // QT_CONFIG(shortcut)

        retranslateUi(FileTypeConfigWidget);

        QMetaObject::connectSlotsByName(FileTypeConfigWidget);
    } // setupUi

    void retranslateUi(QWidget *FileTypeConfigWidget)
    {
        lblFiletype->setText(tr2i18n("&Filetype:", nullptr));
#if QT_CONFIG(whatsthis)
        cmbFiletypes->setWhatsThis(tr2i18n("Select the filetype you want to change.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(whatsthis)
        btnNew->setWhatsThis(tr2i18n("Create a new file type.", nullptr));
#endif // QT_CONFIG(whatsthis)
        btnNew->setText(tr2i18n("&New", nullptr));
#if QT_CONFIG(whatsthis)
        btnDelete->setWhatsThis(tr2i18n("Delete the current file type.", nullptr));
#endif // QT_CONFIG(whatsthis)
        btnDelete->setText(tr2i18n("&Delete", nullptr));
        gbProperties->setTitle(tr2i18n("Properties", nullptr));
        lblName->setText(tr2i18n("&Name:", nullptr));
#if QT_CONFIG(whatsthis)
        edtName->setWhatsThis(tr2i18n("The name of the filetype will be the text of the corresponding menu item.", nullptr));
#endif // QT_CONFIG(whatsthis)
        lblSection->setText(tr2i18n("&Section:", nullptr));
#if QT_CONFIG(whatsthis)
        edtSection->setWhatsThis(tr2i18n("The section name is used to organize the file types in menus.", nullptr));
#endif // QT_CONFIG(whatsthis)
        lblVariables->setText(tr2i18n("&Variables:", nullptr));
#if QT_CONFIG(whatsthis)
        edtVariables->setWhatsThis(tr2i18n("<p>This string allows to configure Kate's settings for the files selected by this mimetype using Kate variables. Almost any configuration option can be set, such as highlight, indent-mode, encoding, etc.</p><p>For a full list of known variables, see the manual.</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
        lblHl->setText(tr2i18n("&Highlighting:", nullptr));
        lblIndenter->setText(tr2i18n("&Indentation mode:", nullptr));
        lblExtensions->setText(tr2i18n("File e&xtensions:", nullptr));
#if QT_CONFIG(whatsthis)
        edtFileExtensions->setWhatsThis(tr2i18n("The wildcards mask allows to select files by filename. A typical mask uses an asterisk and the file extension, for example <code>*.txt; *.text</code>. The string is a semicolon-separated list of masks.", nullptr));
#endif // QT_CONFIG(whatsthis)
        lblMimeTypes->setText(tr2i18n("MIME &types:", nullptr));
#if QT_CONFIG(whatsthis)
        edtMimeTypes->setWhatsThis(tr2i18n("The mime type mask allows to select files by mimetype. The string is a semicolon-separated list of mimetypes, for example <code>text/plain; text/english</code>.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(whatsthis)
        btnMimeTypes->setWhatsThis(tr2i18n("Displays a wizard that helps you easily select mimetypes.", nullptr));
#endif // QT_CONFIG(whatsthis)
        lblPriority->setText(tr2i18n("P&riority:", nullptr));
#if QT_CONFIG(whatsthis)
        sbPriority->setWhatsThis(tr2i18n("Sets priority for this file type. If more than one file type selects the same file, the one with the highest priority will be used.", nullptr));
#endif // QT_CONFIG(whatsthis)
        (void)FileTypeConfigWidget;
    } // retranslateUi

};

namespace Ui {
    class FileTypeConfigWidget: public Ui_FileTypeConfigWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // FILETYPECONFIGWIDGET_H

