#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'navigationconfigwidget.ui'
**
** Created by: Qt User Interface Compiler version 5.15.17
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_NAVIGATIONCONFIGWIDGET_H
#define UI_NAVIGATIONCONFIGWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_NavigationConfigWidget
{
public:
    QVBoxLayout *vboxLayout;
    QGroupBox *gbCursorMovement;
    QVBoxLayout *vboxLayout1;
    QCheckBox *chkSmartHome;
    QCheckBox *chkPagingMovesCursor;
    QCheckBox *chkCamelCursor;
    QHBoxLayout *hboxLayout;
    QLabel *lblAutoCenterCursor;
    QSpinBox *sbAutoCenterCursor;
    QSpacerItem *spacerItem;
    QGroupBox *cbNavigationMisc;
    QVBoxLayout *vboxLayout2;
    QHBoxLayout *horizontalLayout;
    QLabel *lblTextSelectionMode;
    QComboBox *cbTextSelectionMode;
    QSpacerItem *horizontalSpacer;
    QCheckBox *chkScrollPastEnd;
    QCheckBox *chkBackspaceRemoveComposed;
    QGroupBox *gbMulticursor;
    QFormLayout *formLayout;
    QLabel *lblMulticursormodifiers;
    QComboBox *cmbMultiCursorModifier;
    QSpacerItem *spacerItem1;

    void setupUi(QWidget *NavigationConfigWidget)
    {
        if (NavigationConfigWidget->objectName().isEmpty())
            NavigationConfigWidget->setObjectName(QString::fromUtf8("NavigationConfigWidget"));
        NavigationConfigWidget->resize(455, 440);
        vboxLayout = new QVBoxLayout(NavigationConfigWidget);
        vboxLayout->setObjectName(QString::fromUtf8("vboxLayout"));
        vboxLayout->setContentsMargins(0, 0, 0, 0);
        gbCursorMovement = new QGroupBox(NavigationConfigWidget);
        gbCursorMovement->setObjectName(QString::fromUtf8("gbCursorMovement"));
        vboxLayout1 = new QVBoxLayout(gbCursorMovement);
        vboxLayout1->setObjectName(QString::fromUtf8("vboxLayout1"));
        chkSmartHome = new QCheckBox(gbCursorMovement);
        chkSmartHome->setObjectName(QString::fromUtf8("chkSmartHome"));

        vboxLayout1->addWidget(chkSmartHome);

        chkPagingMovesCursor = new QCheckBox(gbCursorMovement);
        chkPagingMovesCursor->setObjectName(QString::fromUtf8("chkPagingMovesCursor"));

        vboxLayout1->addWidget(chkPagingMovesCursor);

        chkCamelCursor = new QCheckBox(gbCursorMovement);
        chkCamelCursor->setObjectName(QString::fromUtf8("chkCamelCursor"));

        vboxLayout1->addWidget(chkCamelCursor);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName(QString::fromUtf8("hboxLayout"));
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        lblAutoCenterCursor = new QLabel(gbCursorMovement);
        lblAutoCenterCursor->setObjectName(QString::fromUtf8("lblAutoCenterCursor"));

        hboxLayout->addWidget(lblAutoCenterCursor);

        sbAutoCenterCursor = new QSpinBox(gbCursorMovement);
        sbAutoCenterCursor->setObjectName(QString::fromUtf8("sbAutoCenterCursor"));

        hboxLayout->addWidget(sbAutoCenterCursor);

        spacerItem = new QSpacerItem(1, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout->addItem(spacerItem);


        vboxLayout1->addLayout(hboxLayout);


        vboxLayout->addWidget(gbCursorMovement);

        cbNavigationMisc = new QGroupBox(NavigationConfigWidget);
        cbNavigationMisc->setObjectName(QString::fromUtf8("cbNavigationMisc"));
        vboxLayout2 = new QVBoxLayout(cbNavigationMisc);
        vboxLayout2->setObjectName(QString::fromUtf8("vboxLayout2"));
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        lblTextSelectionMode = new QLabel(cbNavigationMisc);
        lblTextSelectionMode->setObjectName(QString::fromUtf8("lblTextSelectionMode"));

        horizontalLayout->addWidget(lblTextSelectionMode);

        cbTextSelectionMode = new QComboBox(cbNavigationMisc);
        cbTextSelectionMode->addItem(QString());
        cbTextSelectionMode->addItem(QString());
        cbTextSelectionMode->setObjectName(QString::fromUtf8("cbTextSelectionMode"));

        horizontalLayout->addWidget(cbTextSelectionMode);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        vboxLayout2->addLayout(horizontalLayout);

        chkScrollPastEnd = new QCheckBox(cbNavigationMisc);
        chkScrollPastEnd->setObjectName(QString::fromUtf8("chkScrollPastEnd"));

        vboxLayout2->addWidget(chkScrollPastEnd);

        chkBackspaceRemoveComposed = new QCheckBox(cbNavigationMisc);
        chkBackspaceRemoveComposed->setObjectName(QString::fromUtf8("chkBackspaceRemoveComposed"));

        vboxLayout2->addWidget(chkBackspaceRemoveComposed);


        vboxLayout->addWidget(cbNavigationMisc);

        gbMulticursor = new QGroupBox(NavigationConfigWidget);
        gbMulticursor->setObjectName(QString::fromUtf8("gbMulticursor"));
        formLayout = new QFormLayout(gbMulticursor);
        formLayout->setObjectName(QString::fromUtf8("formLayout"));
        lblMulticursormodifiers = new QLabel(gbMulticursor);
        lblMulticursormodifiers->setObjectName(QString::fromUtf8("lblMulticursormodifiers"));

        formLayout->setWidget(0, QFormLayout::LabelRole, lblMulticursormodifiers);

        cmbMultiCursorModifier = new QComboBox(gbMulticursor);
        cmbMultiCursorModifier->setObjectName(QString::fromUtf8("cmbMultiCursorModifier"));

        formLayout->setWidget(0, QFormLayout::FieldRole, cmbMultiCursorModifier);


        vboxLayout->addWidget(gbMulticursor);

        spacerItem1 = new QSpacerItem(0, 1, QSizePolicy::Minimum, QSizePolicy::Expanding);

        vboxLayout->addItem(spacerItem1);

#if QT_CONFIG(shortcut)
        lblAutoCenterCursor->setBuddy(sbAutoCenterCursor);
        lblTextSelectionMode->setBuddy(cbTextSelectionMode);
#endif // QT_CONFIG(shortcut)

        retranslateUi(NavigationConfigWidget);

        QMetaObject::connectSlotsByName(NavigationConfigWidget);
    } // setupUi

    void retranslateUi(QWidget *NavigationConfigWidget)
    {
        gbCursorMovement->setTitle(tr2i18n("Text Cursor Movement", nullptr));
#if QT_CONFIG(whatsthis)
        chkSmartHome->setWhatsThis(tr2i18n("When selected, pressing the home key will cause the cursor to skip whitespace and go to the start of a line's text. The same applies for the end key.", nullptr));
#endif // QT_CONFIG(whatsthis)
        chkSmartHome->setText(tr2i18n("Smart ho&me and smart end", nullptr));
#if QT_CONFIG(whatsthis)
        chkPagingMovesCursor->setWhatsThis(tr2i18n("Selects whether the PageUp and PageDown keys should alter the vertical position of the cursor relative to the top of the view.", nullptr));
#endif // QT_CONFIG(whatsthis)
        chkPagingMovesCursor->setText(tr2i18n("&PageUp/PageDown moves cursor", nullptr));
#if QT_CONFIG(whatsthis)
        chkCamelCursor->setWhatsThis(tr2i18n("Selects whether cursor jumps full words or breaks at camel case humps.", nullptr));
#endif // QT_CONFIG(whatsthis)
        chkCamelCursor->setText(tr2i18n("Enable camel case cursor movement", nullptr));
        lblAutoCenterCursor->setText(tr2i18n("&Autocenter cursor:", nullptr));
#if QT_CONFIG(whatsthis)
        sbAutoCenterCursor->setWhatsThis(tr2i18n("Sets the number of lines to maintain visible above and below the cursor when possible.", nullptr));
#endif // QT_CONFIG(whatsthis)
        sbAutoCenterCursor->setSpecialValueText(tr2i18n("Disabled", nullptr));
        sbAutoCenterCursor->setSuffix(tr2i18n(" lines", nullptr));
        cbNavigationMisc->setTitle(tr2i18n("Misc", nullptr));
        lblTextSelectionMode->setText(tr2i18n("Text selection mode:", nullptr));
        cbTextSelectionMode->setItemText(0, tr2i18n("Normal", nullptr));
        cbTextSelectionMode->setItemText(1, tr2i18n("Persistent", nullptr));

        chkScrollPastEnd->setText(tr2i18n("Allow scrolling past the end of the document", nullptr));
#if QT_CONFIG(whatsthis)
        chkBackspaceRemoveComposed->setWhatsThis(tr2i18n("When selected, composed characters are removed with their diacritics instead of only removing the base character. This is useful for Indic locales.", nullptr));
#endif // QT_CONFIG(whatsthis)
        chkBackspaceRemoveComposed->setText(tr2i18n("Backspace key removes character\342\200\231s base with its diacritics", nullptr));
        gbMulticursor->setTitle(tr2i18n("Multicursor", nullptr));
        lblMulticursormodifiers->setText(tr2i18n("Multiple Cursor Modifiers", nullptr));
        (void)NavigationConfigWidget;
    } // retranslateUi

};

namespace Ui {
    class NavigationConfigWidget: public Ui_NavigationConfigWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // NAVIGATIONCONFIGWIDGET_H

