/****************************************************************************
** Meta object code from reading C++ file 'kateviewhelpers.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../ktexteditor-5.116.0/src/view/kateviewhelpers.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kateviewhelpers.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KateScrollBar_t {
    QByteArrayData data[8];
    char stringdata0[95];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KateScrollBar_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KateScrollBar_t qt_meta_stringdata_KateScrollBar = {
    {
QT_MOC_LITERAL(0, 0, 13), // "KateScrollBar"
QT_MOC_LITERAL(1, 14, 14), // "sliderMMBMoved"
QT_MOC_LITERAL(2, 29, 0), // ""
QT_MOC_LITERAL(3, 30, 5), // "value"
QT_MOC_LITERAL(4, 36, 16), // "sliderMaybeMoved"
QT_MOC_LITERAL(5, 53, 12), // "marksChanged"
QT_MOC_LITERAL(6, 66, 12), // "updatePixmap"
QT_MOC_LITERAL(7, 79, 15) // "showTextPreview"

    },
    "KateScrollBar\0sliderMMBMoved\0\0value\0"
    "sliderMaybeMoved\0marksChanged\0"
    "updatePixmap\0showTextPreview"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KateScrollBar[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       5,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   39,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       4,    1,   42,    2, 0x09 /* Protected */,
       5,    0,   45,    2, 0x09 /* Protected */,
       6,    0,   46,    2, 0x0a /* Public */,
       7,    0,   47,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::Int,    3,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void KateScrollBar::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<KateScrollBar *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->sliderMMBMoved((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 1: _t->sliderMaybeMoved((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->marksChanged(); break;
        case 3: _t->updatePixmap(); break;
        case 4: _t->showTextPreview(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (KateScrollBar::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KateScrollBar::sliderMMBMoved)) {
                *result = 0;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject KateScrollBar::staticMetaObject = { {
    QMetaObject::SuperData::link<QScrollBar::staticMetaObject>(),
    qt_meta_stringdata_KateScrollBar.data,
    qt_meta_data_KateScrollBar,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *KateScrollBar::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateScrollBar::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KateScrollBar.stringdata0))
        return static_cast<void*>(this);
    return QScrollBar::qt_metacast(_clname);
}

int KateScrollBar::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QScrollBar::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void KateScrollBar::sliderMMBMoved(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
struct qt_meta_stringdata_KateIconBorder_t {
    QByteArrayData data[13];
    char stringdata0[247];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KateIconBorder_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KateIconBorder_t qt_meta_stringdata_KateIconBorder = {
    {
QT_MOC_LITERAL(0, 0, 14), // "KateIconBorder"
QT_MOC_LITERAL(1, 15, 27), // "updateAnnotationBorderWidth"
QT_MOC_LITERAL(2, 43, 0), // ""
QT_MOC_LITERAL(3, 44, 20), // "updateAnnotationLine"
QT_MOC_LITERAL(4, 65, 4), // "line"
QT_MOC_LITERAL(5, 70, 22), // "annotationModelChanged"
QT_MOC_LITERAL(6, 93, 29), // "KTextEditor::AnnotationModel*"
QT_MOC_LITERAL(7, 123, 8), // "oldmodel"
QT_MOC_LITERAL(8, 132, 8), // "newmodel"
QT_MOC_LITERAL(9, 141, 19), // "displayRangeChanged"
QT_MOC_LITERAL(10, 161, 16), // "highlightFolding"
QT_MOC_LITERAL(11, 178, 37), // "handleDestroyedAnnotationItem..."
QT_MOC_LITERAL(12, 216, 30) // "delayedUpdateOfSizeWithRepaint"

    },
    "KateIconBorder\0updateAnnotationBorderWidth\0"
    "\0updateAnnotationLine\0line\0"
    "annotationModelChanged\0"
    "KTextEditor::AnnotationModel*\0oldmodel\0"
    "newmodel\0displayRangeChanged\0"
    "highlightFolding\0handleDestroyedAnnotationItemDelegate\0"
    "delayedUpdateOfSizeWithRepaint"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KateIconBorder[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       7,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   49,    2, 0x0a /* Public */,
       3,    1,   50,    2, 0x0a /* Public */,
       5,    2,   53,    2, 0x0a /* Public */,
       9,    0,   58,    2, 0x0a /* Public */,
      10,    0,   59,    2, 0x08 /* Private */,
      11,    0,   60,    2, 0x08 /* Private */,
      12,    0,   61,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    4,
    QMetaType::Void, 0x80000000 | 6, 0x80000000 | 6,    7,    8,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void KateIconBorder::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<KateIconBorder *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->updateAnnotationBorderWidth(); break;
        case 1: _t->updateAnnotationLine((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->annotationModelChanged((*reinterpret_cast< KTextEditor::AnnotationModel*(*)>(_a[1])),(*reinterpret_cast< KTextEditor::AnnotationModel*(*)>(_a[2]))); break;
        case 3: _t->displayRangeChanged(); break;
        case 4: _t->highlightFolding(); break;
        case 5: _t->handleDestroyedAnnotationItemDelegate(); break;
        case 6: _t->delayedUpdateOfSizeWithRepaint(); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject KateIconBorder::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_meta_stringdata_KateIconBorder.data,
    qt_meta_data_KateIconBorder,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *KateIconBorder::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateIconBorder::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KateIconBorder.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int KateIconBorder::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 7;
    }
    return _id;
}
struct qt_meta_stringdata_KateViewEncodingAction_t {
    QByteArrayData data[12];
    char stringdata0[136];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KateViewEncodingAction_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KateViewEncodingAction_t qt_meta_stringdata_KateViewEncodingAction = {
    {
QT_MOC_LITERAL(0, 0, 22), // "KateViewEncodingAction"
QT_MOC_LITERAL(1, 23, 13), // "codecSelected"
QT_MOC_LITERAL(2, 37, 0), // ""
QT_MOC_LITERAL(3, 38, 11), // "QTextCodec*"
QT_MOC_LITERAL(4, 50, 5), // "codec"
QT_MOC_LITERAL(5, 56, 21), // "_k_subActionTriggered"
QT_MOC_LITERAL(6, 78, 8), // "QAction*"
QT_MOC_LITERAL(7, 87, 11), // "setEncoding"
QT_MOC_LITERAL(8, 99, 1), // "e"
QT_MOC_LITERAL(9, 101, 15), // "slotAboutToShow"
QT_MOC_LITERAL(10, 117, 9), // "codecName"
QT_MOC_LITERAL(11, 127, 8) // "codecMib"

    },
    "KateViewEncodingAction\0codecSelected\0"
    "\0QTextCodec*\0codec\0_k_subActionTriggered\0"
    "QAction*\0setEncoding\0e\0slotAboutToShow\0"
    "codecName\0codecMib"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KateViewEncodingAction[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       4,   14, // methods
       2,   44, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   34,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       5,    1,   37,    2, 0x08 /* Private */,
       7,    1,   40,    2, 0x08 /* Private */,
       9,    0,   43,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 6,    2,
    QMetaType::Void, QMetaType::QString,    8,
    QMetaType::Void,

 // properties: name, type, flags
      10, QMetaType::QString, 0x00095003,
      11, QMetaType::Int, 0x00095001,

       0        // eod
};

void KateViewEncodingAction::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<KateViewEncodingAction *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->codecSelected((*reinterpret_cast< QTextCodec*(*)>(_a[1]))); break;
        case 1: _t->d->_k_subActionTriggered((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        case 2: _t->setEncoding((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->slotAboutToShow(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAction* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (KateViewEncodingAction::*)(QTextCodec * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KateViewEncodingAction::codecSelected)) {
                *result = 0;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<KateViewEncodingAction *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QString*>(_v) = _t->currentCodecName(); break;
        case 1: *reinterpret_cast< int*>(_v) = _t->currentCodecMib(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<KateViewEncodingAction *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setCurrentCodec(*reinterpret_cast< QString*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject KateViewEncodingAction::staticMetaObject = { {
    QMetaObject::SuperData::link<KSelectAction::staticMetaObject>(),
    qt_meta_stringdata_KateViewEncodingAction.data,
    qt_meta_data_KateViewEncodingAction,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *KateViewEncodingAction::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateViewEncodingAction::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KateViewEncodingAction.stringdata0))
        return static_cast<void*>(this);
    return KSelectAction::qt_metacast(_clname);
}

int KateViewEncodingAction::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KSelectAction::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 2;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void KateViewEncodingAction::codecSelected(QTextCodec * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
struct qt_meta_stringdata_KateViewBarWidget_t {
    QByteArrayData data[3];
    char stringdata0[26];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KateViewBarWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KateViewBarWidget_t qt_meta_stringdata_KateViewBarWidget = {
    {
QT_MOC_LITERAL(0, 0, 17), // "KateViewBarWidget"
QT_MOC_LITERAL(1, 18, 6), // "hideMe"
QT_MOC_LITERAL(2, 25, 0) // ""

    },
    "KateViewBarWidget\0hideMe\0"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KateViewBarWidget[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   19,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void,

       0        // eod
};

void KateViewBarWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<KateViewBarWidget *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->hideMe(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (KateViewBarWidget::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KateViewBarWidget::hideMe)) {
                *result = 0;
                return;
            }
        }
    }
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject KateViewBarWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_meta_stringdata_KateViewBarWidget.data,
    qt_meta_data_KateViewBarWidget,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *KateViewBarWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateViewBarWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KateViewBarWidget.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int KateViewBarWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void KateViewBarWidget::hideMe()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
struct qt_meta_stringdata_KateViewBar_t {
    QByteArrayData data[3];
    char stringdata0[34];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KateViewBar_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KateViewBar_t qt_meta_stringdata_KateViewBar = {
    {
QT_MOC_LITERAL(0, 0, 11), // "KateViewBar"
QT_MOC_LITERAL(1, 12, 20), // "hideCurrentBarWidget"
QT_MOC_LITERAL(2, 33, 0) // ""

    },
    "KateViewBar\0hideCurrentBarWidget\0"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KateViewBar[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   19,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void,

       0        // eod
};

void KateViewBar::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<KateViewBar *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->hideCurrentBarWidget(); break;
        default: ;
        }
    }
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject KateViewBar::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_meta_stringdata_KateViewBar.data,
    qt_meta_data_KateViewBar,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *KateViewBar::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateViewBar::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KateViewBar.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int KateViewBar::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}
struct qt_meta_stringdata_KateCommandLineBar_t {
    QByteArrayData data[3];
    char stringdata0[33];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KateCommandLineBar_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KateCommandLineBar_t qt_meta_stringdata_KateCommandLineBar = {
    {
QT_MOC_LITERAL(0, 0, 18), // "KateCommandLineBar"
QT_MOC_LITERAL(1, 19, 12), // "showHelpPage"
QT_MOC_LITERAL(2, 32, 0) // ""

    },
    "KateCommandLineBar\0showHelpPage\0"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KateCommandLineBar[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   19,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void,

       0        // eod
};

void KateCommandLineBar::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<KateCommandLineBar *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->showHelpPage(); break;
        default: ;
        }
    }
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject KateCommandLineBar::staticMetaObject = { {
    QMetaObject::SuperData::link<KateViewBarWidget::staticMetaObject>(),
    qt_meta_stringdata_KateCommandLineBar.data,
    qt_meta_data_KateCommandLineBar,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *KateCommandLineBar::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateCommandLineBar::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KateCommandLineBar.stringdata0))
        return static_cast<void*>(this);
    return KateViewBarWidget::qt_metacast(_clname);
}

int KateCommandLineBar::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KateViewBarWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}
struct qt_meta_stringdata_KateCmdLineEdit_t {
    QByteArrayData data[6];
    char stringdata0[66];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KateCmdLineEdit_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KateCmdLineEdit_t qt_meta_stringdata_KateCmdLineEdit = {
    {
QT_MOC_LITERAL(0, 0, 15), // "KateCmdLineEdit"
QT_MOC_LITERAL(1, 16, 13), // "hideRequested"
QT_MOC_LITERAL(2, 30, 0), // ""
QT_MOC_LITERAL(3, 31, 17), // "slotReturnPressed"
QT_MOC_LITERAL(4, 49, 3), // "cmd"
QT_MOC_LITERAL(5, 53, 12) // "hideLineEdit"

    },
    "KateCmdLineEdit\0hideRequested\0\0"
    "slotReturnPressed\0cmd\0hideLineEdit"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KateCmdLineEdit[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       3,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   29,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    1,   30,    2, 0x0a /* Public */,
       5,    0,   33,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    4,
    QMetaType::Void,

       0        // eod
};

void KateCmdLineEdit::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<KateCmdLineEdit *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->hideRequested(); break;
        case 1: _t->slotReturnPressed((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->hideLineEdit(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (KateCmdLineEdit::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KateCmdLineEdit::hideRequested)) {
                *result = 0;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject KateCmdLineEdit::staticMetaObject = { {
    QMetaObject::SuperData::link<KLineEdit::staticMetaObject>(),
    qt_meta_stringdata_KateCmdLineEdit.data,
    qt_meta_data_KateCmdLineEdit,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *KateCmdLineEdit::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateCmdLineEdit::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KateCmdLineEdit.stringdata0))
        return static_cast<void*>(this);
    return KLineEdit::qt_metacast(_clname);
}

int KateCmdLineEdit::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KLineEdit::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void KateCmdLineEdit::hideRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
struct qt_meta_stringdata_KateViewSchemaAction_t {
    QByteArrayData data[4];
    char stringdata0[48];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KateViewSchemaAction_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KateViewSchemaAction_t qt_meta_stringdata_KateViewSchemaAction = {
    {
QT_MOC_LITERAL(0, 0, 20), // "KateViewSchemaAction"
QT_MOC_LITERAL(1, 21, 15), // "slotAboutToShow"
QT_MOC_LITERAL(2, 37, 0), // ""
QT_MOC_LITERAL(3, 38, 9) // "setSchema"

    },
    "KateViewSchemaAction\0slotAboutToShow\0"
    "\0setSchema"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KateViewSchemaAction[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   24,    2, 0x0a /* Public */,
       3,    0,   25,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void KateViewSchemaAction::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<KateViewSchemaAction *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->slotAboutToShow(); break;
        case 1: _t->setSchema(); break;
        default: ;
        }
    }
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject KateViewSchemaAction::staticMetaObject = { {
    QMetaObject::SuperData::link<KActionMenu::staticMetaObject>(),
    qt_meta_stringdata_KateViewSchemaAction.data,
    qt_meta_data_KateViewSchemaAction,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *KateViewSchemaAction::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateViewSchemaAction::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KateViewSchemaAction.stringdata0))
        return static_cast<void*>(this);
    return KActionMenu::qt_metacast(_clname);
}

int KateViewSchemaAction::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KActionMenu::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 2;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
