/****************************************************************************
** Meta object code from reading C++ file 'katescriptview.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../ktexteditor-5.116.0/src/script/katescriptview.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'katescriptview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KateScriptView_t {
    QByteArrayData data[39];
    char stringdata0[428];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KateScriptView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KateScriptView_t qt_meta_stringdata_KateScriptView = {
    {
QT_MOC_LITERAL(0, 0, 14), // "KateScriptView"
QT_MOC_LITERAL(1, 15, 4), // "copy"
QT_MOC_LITERAL(2, 20, 0), // ""
QT_MOC_LITERAL(3, 21, 3), // "cut"
QT_MOC_LITERAL(4, 25, 5), // "paste"
QT_MOC_LITERAL(5, 31, 14), // "cursorPosition"
QT_MOC_LITERAL(6, 46, 8), // "QJSValue"
QT_MOC_LITERAL(7, 55, 15), // "cursorPositions"
QT_MOC_LITERAL(8, 71, 17), // "setCursorPosition"
QT_MOC_LITERAL(9, 89, 4), // "line"
QT_MOC_LITERAL(10, 94, 6), // "column"
QT_MOC_LITERAL(11, 101, 6), // "cursor"
QT_MOC_LITERAL(12, 108, 18), // "setCursorPositions"
QT_MOC_LITERAL(13, 127, 7), // "cursors"
QT_MOC_LITERAL(14, 135, 21), // "virtualCursorPosition"
QT_MOC_LITERAL(15, 157, 24), // "setVirtualCursorPosition"
QT_MOC_LITERAL(16, 182, 12), // "selectedText"
QT_MOC_LITERAL(17, 195, 12), // "hasSelection"
QT_MOC_LITERAL(18, 208, 9), // "selection"
QT_MOC_LITERAL(19, 218, 10), // "selections"
QT_MOC_LITERAL(20, 229, 12), // "setSelection"
QT_MOC_LITERAL(21, 242, 5), // "range"
QT_MOC_LITERAL(22, 248, 13), // "setSelections"
QT_MOC_LITERAL(23, 262, 6), // "ranges"
QT_MOC_LITERAL(24, 269, 18), // "removeSelectedText"
QT_MOC_LITERAL(25, 288, 9), // "selectAll"
QT_MOC_LITERAL(26, 298, 14), // "clearSelection"
QT_MOC_LITERAL(27, 313, 17), // "setBlockSelection"
QT_MOC_LITERAL(28, 331, 2), // "on"
QT_MOC_LITERAL(29, 334, 14), // "blockSelection"
QT_MOC_LITERAL(30, 349, 5), // "align"
QT_MOC_LITERAL(31, 355, 7), // "alignOn"
QT_MOC_LITERAL(32, 363, 7), // "jsrange"
QT_MOC_LITERAL(33, 371, 7), // "pattern"
QT_MOC_LITERAL(34, 379, 10), // "searchText"
QT_MOC_LITERAL(35, 390, 9), // "backwards"
QT_MOC_LITERAL(36, 400, 14), // "executeCommand"
QT_MOC_LITERAL(37, 415, 7), // "command"
QT_MOC_LITERAL(38, 423, 4) // "args"

    },
    "KateScriptView\0copy\0\0cut\0paste\0"
    "cursorPosition\0QJSValue\0cursorPositions\0"
    "setCursorPosition\0line\0column\0cursor\0"
    "setCursorPositions\0cursors\0"
    "virtualCursorPosition\0setVirtualCursorPosition\0"
    "selectedText\0hasSelection\0selection\0"
    "selections\0setSelection\0range\0"
    "setSelections\0ranges\0removeSelectedText\0"
    "selectAll\0clearSelection\0setBlockSelection\0"
    "on\0blockSelection\0align\0alignOn\0jsrange\0"
    "pattern\0searchText\0backwards\0"
    "executeCommand\0command\0args"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KateScriptView[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      30,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // methods: name, argc, parameters, tag, flags
       1,    0,  164,    2, 0x02 /* Public */,
       3,    0,  165,    2, 0x02 /* Public */,
       4,    0,  166,    2, 0x02 /* Public */,
       5,    0,  167,    2, 0x02 /* Public */,
       7,    0,  168,    2, 0x02 /* Public */,
       8,    2,  169,    2, 0x02 /* Public */,
       8,    1,  174,    2, 0x02 /* Public */,
      12,    1,  177,    2, 0x02 /* Public */,
      14,    0,  180,    2, 0x02 /* Public */,
      15,    2,  181,    2, 0x02 /* Public */,
      15,    1,  186,    2, 0x02 /* Public */,
      16,    0,  189,    2, 0x02 /* Public */,
      17,    0,  190,    2, 0x02 /* Public */,
      18,    0,  191,    2, 0x02 /* Public */,
      19,    0,  192,    2, 0x02 /* Public */,
      20,    1,  193,    2, 0x02 /* Public */,
      22,    1,  196,    2, 0x02 /* Public */,
      24,    0,  199,    2, 0x02 /* Public */,
      25,    0,  200,    2, 0x02 /* Public */,
      26,    0,  201,    2, 0x02 /* Public */,
      27,    1,  202,    2, 0x02 /* Public */,
      29,    0,  205,    2, 0x02 /* Public */,
      30,    1,  206,    2, 0x02 /* Public */,
      31,    2,  209,    2, 0x02 /* Public */,
      31,    1,  214,    2, 0x22 /* Public | MethodCloned */,
      34,    3,  217,    2, 0x02 /* Public */,
      34,    2,  224,    2, 0x22 /* Public | MethodCloned */,
      36,    3,  229,    2, 0x02 /* Public */,
      36,    2,  236,    2, 0x22 /* Public | MethodCloned */,
      36,    1,  241,    2, 0x22 /* Public | MethodCloned */,

 // methods: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    0x80000000 | 6,
    0x80000000 | 6,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,    9,   10,
    QMetaType::Void, 0x80000000 | 6,   11,
    QMetaType::Void, 0x80000000 | 6,   13,
    0x80000000 | 6,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,    9,   10,
    QMetaType::Void, 0x80000000 | 6,   11,
    QMetaType::QString,
    QMetaType::Bool,
    0x80000000 | 6,
    0x80000000 | 6,
    QMetaType::Void, 0x80000000 | 6,   21,
    QMetaType::Void, 0x80000000 | 6,   23,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   28,
    QMetaType::Bool,
    QMetaType::Void, 0x80000000 | 6,   21,
    QMetaType::Void, 0x80000000 | 6, 0x80000000 | 6,   32,   33,
    QMetaType::Void, 0x80000000 | 6,   32,
    0x80000000 | 6, 0x80000000 | 6, QMetaType::QString, QMetaType::Bool,   21,   33,   35,
    0x80000000 | 6, 0x80000000 | 6, QMetaType::QString,   21,   33,
    0x80000000 | 6, QMetaType::QString, QMetaType::QString, 0x80000000 | 6,   37,   38,   32,
    0x80000000 | 6, QMetaType::QString, QMetaType::QString,   37,   38,
    0x80000000 | 6, QMetaType::QString,   37,

       0        // eod
};

void KateScriptView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<KateScriptView *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->copy(); break;
        case 1: _t->cut(); break;
        case 2: _t->paste(); break;
        case 3: { QJSValue _r = _t->cursorPosition();
            if (_a[0]) *reinterpret_cast< QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 4: { QJSValue _r = _t->cursorPositions();
            if (_a[0]) *reinterpret_cast< QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 5: _t->setCursorPosition((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 6: _t->setCursorPosition((*reinterpret_cast< const QJSValue(*)>(_a[1]))); break;
        case 7: _t->setCursorPositions((*reinterpret_cast< const QJSValue(*)>(_a[1]))); break;
        case 8: { QJSValue _r = _t->virtualCursorPosition();
            if (_a[0]) *reinterpret_cast< QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 9: _t->setVirtualCursorPosition((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 10: _t->setVirtualCursorPosition((*reinterpret_cast< const QJSValue(*)>(_a[1]))); break;
        case 11: { QString _r = _t->selectedText();
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 12: { bool _r = _t->hasSelection();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 13: { QJSValue _r = _t->selection();
            if (_a[0]) *reinterpret_cast< QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 14: { QJSValue _r = _t->selections();
            if (_a[0]) *reinterpret_cast< QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 15: _t->setSelection((*reinterpret_cast< const QJSValue(*)>(_a[1]))); break;
        case 16: _t->setSelections((*reinterpret_cast< const QJSValue(*)>(_a[1]))); break;
        case 17: _t->removeSelectedText(); break;
        case 18: _t->selectAll(); break;
        case 19: _t->clearSelection(); break;
        case 20: _t->setBlockSelection((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 21: { bool _r = _t->blockSelection();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 22: _t->align((*reinterpret_cast< const QJSValue(*)>(_a[1]))); break;
        case 23: _t->alignOn((*reinterpret_cast< const QJSValue(*)>(_a[1])),(*reinterpret_cast< const QJSValue(*)>(_a[2]))); break;
        case 24: _t->alignOn((*reinterpret_cast< const QJSValue(*)>(_a[1]))); break;
        case 25: { QJSValue _r = _t->searchText((*reinterpret_cast< const QJSValue(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 26: { QJSValue _r = _t->searchText((*reinterpret_cast< const QJSValue(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 27: { QJSValue _r = _t->executeCommand((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QJSValue(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 28: { QJSValue _r = _t->executeCommand((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 29: { QJSValue _r = _t->executeCommand((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QJSValue*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
            }
            break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
            }
            break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
            }
            break;
        case 22:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
            }
            break;
        case 23:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
            }
            break;
        case 24:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
            }
            break;
        case 25:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
            }
            break;
        case 26:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
            }
            break;
        case 27:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 2:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
            }
            break;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject KateScriptView::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_KateScriptView.data,
    qt_meta_data_KateScriptView,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *KateScriptView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateScriptView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KateScriptView.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KateScriptView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 30)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 30;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 30)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 30;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
