/****************************************************************************
** Meta object code from reading C++ file 'katescripthelpers.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../ktexteditor-5.116.0/src/script/katescripthelpers.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'katescripthelpers.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Kate__ScriptHelper_t {
    QByteArrayData data[17];
    char stringdata0[130];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Kate__ScriptHelper_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Kate__ScriptHelper_t qt_meta_stringdata_Kate__ScriptHelper = {
    {
QT_MOC_LITERAL(0, 0, 18), // "Kate::ScriptHelper"
QT_MOC_LITERAL(1, 19, 4), // "read"
QT_MOC_LITERAL(2, 24, 0), // ""
QT_MOC_LITERAL(3, 25, 4), // "file"
QT_MOC_LITERAL(4, 30, 7), // "require"
QT_MOC_LITERAL(5, 38, 5), // "debug"
QT_MOC_LITERAL(6, 44, 3), // "msg"
QT_MOC_LITERAL(7, 48, 5), // "_i18n"
QT_MOC_LITERAL(8, 54, 6), // "_i18nc"
QT_MOC_LITERAL(9, 61, 11), // "textContext"
QT_MOC_LITERAL(10, 73, 4), // "text"
QT_MOC_LITERAL(11, 78, 6), // "_i18np"
QT_MOC_LITERAL(12, 85, 10), // "trSingular"
QT_MOC_LITERAL(13, 96, 8), // "trPlural"
QT_MOC_LITERAL(14, 105, 6), // "number"
QT_MOC_LITERAL(15, 112, 7), // "_i18ncp"
QT_MOC_LITERAL(16, 120, 9) // "trContext"

    },
    "Kate::ScriptHelper\0read\0\0file\0require\0"
    "debug\0msg\0_i18n\0_i18nc\0textContext\0"
    "text\0_i18np\0trSingular\0trPlural\0number\0"
    "_i18ncp\0trContext"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Kate__ScriptHelper[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       8,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // methods: name, argc, parameters, tag, flags
       1,    1,   54,    2, 0x02 /* Public */,
       4,    1,   57,    2, 0x02 /* Public */,
       5,    1,   60,    2, 0x02 /* Public */,
       7,    1,   63,    2, 0x02 /* Public */,
       8,    2,   66,    2, 0x02 /* Public */,
      11,    3,   71,    2, 0x02 /* Public */,
      15,    4,   78,    2, 0x02 /* Public */,
      15,    3,   87,    2, 0x22 /* Public | MethodCloned */,

 // methods: parameters
    QMetaType::QString, QMetaType::QString,    3,
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, QMetaType::QString,    6,
    QMetaType::QString, QMetaType::QString,    6,
    QMetaType::QString, QMetaType::QString, QMetaType::QString,    9,   10,
    QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::Int,   12,   13,   14,
    QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::Int,   16,   12,   13,   14,
    QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::QString,   16,   12,   13,

       0        // eod
};

void Kate::ScriptHelper::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<ScriptHelper *>(_o);
        (void)_t;
        switch (_id) {
        case 0: { QString _r = _t->read((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 1: _t->require((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->debug((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: { QString _r = _t->_i18n((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 4: { QString _r = _t->_i18nc((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 5: { QString _r = _t->_i18np((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 6: { QString _r = _t->_i18ncp((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 7: { QString _r = _t->_i18ncp((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject Kate::ScriptHelper::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_Kate__ScriptHelper.data,
    qt_meta_data_Kate__ScriptHelper,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Kate::ScriptHelper::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kate::ScriptHelper::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Kate__ScriptHelper.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Kate::ScriptHelper::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 8;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
