/****************************************************************************
** Meta object code from reading C++ file 'variableeditor.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../ktexteditor-5.116.0/src/variableeditor/variableeditor.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'variableeditor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_VariableEditor_t {
    QByteArrayData data[6];
    char stringdata0[62];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_VariableEditor_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_VariableEditor_t qt_meta_stringdata_VariableEditor = {
    {
QT_MOC_LITERAL(0, 0, 14), // "VariableEditor"
QT_MOC_LITERAL(1, 15, 12), // "valueChanged"
QT_MOC_LITERAL(2, 28, 0), // ""
QT_MOC_LITERAL(3, 29, 11), // "itemEnabled"
QT_MOC_LITERAL(4, 41, 7), // "enabled"
QT_MOC_LITERAL(5, 49, 12) // "activateItem"

    },
    "VariableEditor\0valueChanged\0\0itemEnabled\0"
    "enabled\0activateItem"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_VariableEditor[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       3,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   29,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    1,   30,    2, 0x09 /* Protected */,
       5,    0,   33,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::Bool,    4,
    QMetaType::Void,

       0        // eod
};

void VariableEditor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<VariableEditor *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->valueChanged(); break;
        case 1: _t->itemEnabled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 2: _t->activateItem(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (VariableEditor::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&VariableEditor::valueChanged)) {
                *result = 0;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject VariableEditor::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_meta_stringdata_VariableEditor.data,
    qt_meta_data_VariableEditor,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *VariableEditor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *VariableEditor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_VariableEditor.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int VariableEditor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void VariableEditor::valueChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
struct qt_meta_stringdata_VariableIntEditor_t {
    QByteArrayData data[4];
    char stringdata0[41];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_VariableIntEditor_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_VariableIntEditor_t qt_meta_stringdata_VariableIntEditor = {
    {
QT_MOC_LITERAL(0, 0, 17), // "VariableIntEditor"
QT_MOC_LITERAL(1, 18, 12), // "setItemValue"
QT_MOC_LITERAL(2, 31, 0), // ""
QT_MOC_LITERAL(3, 32, 8) // "newValue"

    },
    "VariableIntEditor\0setItemValue\0\0"
    "newValue"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_VariableIntEditor[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   19,    2, 0x09 /* Protected */,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,    3,

       0        // eod
};

void VariableIntEditor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<VariableIntEditor *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->setItemValue((*reinterpret_cast< int(*)>(_a[1]))); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject VariableIntEditor::staticMetaObject = { {
    QMetaObject::SuperData::link<VariableEditor::staticMetaObject>(),
    qt_meta_stringdata_VariableIntEditor.data,
    qt_meta_data_VariableIntEditor,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *VariableIntEditor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *VariableIntEditor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_VariableIntEditor.stringdata0))
        return static_cast<void*>(this);
    return VariableEditor::qt_metacast(_clname);
}

int VariableIntEditor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = VariableEditor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}
struct qt_meta_stringdata_VariableBoolEditor_t {
    QByteArrayData data[4];
    char stringdata0[41];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_VariableBoolEditor_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_VariableBoolEditor_t qt_meta_stringdata_VariableBoolEditor = {
    {
QT_MOC_LITERAL(0, 0, 18), // "VariableBoolEditor"
QT_MOC_LITERAL(1, 19, 12), // "setItemValue"
QT_MOC_LITERAL(2, 32, 0), // ""
QT_MOC_LITERAL(3, 33, 7) // "enabled"

    },
    "VariableBoolEditor\0setItemValue\0\0"
    "enabled"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_VariableBoolEditor[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   19,    2, 0x09 /* Protected */,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,    3,

       0        // eod
};

void VariableBoolEditor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<VariableBoolEditor *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->setItemValue((*reinterpret_cast< int(*)>(_a[1]))); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject VariableBoolEditor::staticMetaObject = { {
    QMetaObject::SuperData::link<VariableEditor::staticMetaObject>(),
    qt_meta_stringdata_VariableBoolEditor.data,
    qt_meta_data_VariableBoolEditor,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *VariableBoolEditor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *VariableBoolEditor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_VariableBoolEditor.stringdata0))
        return static_cast<void*>(this);
    return VariableEditor::qt_metacast(_clname);
}

int VariableBoolEditor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = VariableEditor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}
struct qt_meta_stringdata_VariableStringListEditor_t {
    QByteArrayData data[4];
    char stringdata0[48];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_VariableStringListEditor_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_VariableStringListEditor_t qt_meta_stringdata_VariableStringListEditor = {
    {
QT_MOC_LITERAL(0, 0, 24), // "VariableStringListEditor"
QT_MOC_LITERAL(1, 25, 12), // "setItemValue"
QT_MOC_LITERAL(2, 38, 0), // ""
QT_MOC_LITERAL(3, 39, 8) // "newValue"

    },
    "VariableStringListEditor\0setItemValue\0"
    "\0newValue"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_VariableStringListEditor[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   19,    2, 0x09 /* Protected */,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    3,

       0        // eod
};

void VariableStringListEditor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<VariableStringListEditor *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->setItemValue((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject VariableStringListEditor::staticMetaObject = { {
    QMetaObject::SuperData::link<VariableEditor::staticMetaObject>(),
    qt_meta_stringdata_VariableStringListEditor.data,
    qt_meta_data_VariableStringListEditor,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *VariableStringListEditor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *VariableStringListEditor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_VariableStringListEditor.stringdata0))
        return static_cast<void*>(this);
    return VariableEditor::qt_metacast(_clname);
}

int VariableStringListEditor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = VariableEditor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}
struct qt_meta_stringdata_VariableColorEditor_t {
    QByteArrayData data[4];
    char stringdata0[43];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_VariableColorEditor_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_VariableColorEditor_t qt_meta_stringdata_VariableColorEditor = {
    {
QT_MOC_LITERAL(0, 0, 19), // "VariableColorEditor"
QT_MOC_LITERAL(1, 20, 12), // "setItemValue"
QT_MOC_LITERAL(2, 33, 0), // ""
QT_MOC_LITERAL(3, 34, 8) // "newValue"

    },
    "VariableColorEditor\0setItemValue\0\0"
    "newValue"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_VariableColorEditor[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   19,    2, 0x09 /* Protected */,

 // slots: parameters
    QMetaType::Void, QMetaType::QColor,    3,

       0        // eod
};

void VariableColorEditor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<VariableColorEditor *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->setItemValue((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject VariableColorEditor::staticMetaObject = { {
    QMetaObject::SuperData::link<VariableEditor::staticMetaObject>(),
    qt_meta_stringdata_VariableColorEditor.data,
    qt_meta_data_VariableColorEditor,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *VariableColorEditor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *VariableColorEditor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_VariableColorEditor.stringdata0))
        return static_cast<void*>(this);
    return VariableEditor::qt_metacast(_clname);
}

int VariableColorEditor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = VariableEditor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}
struct qt_meta_stringdata_VariableFontEditor_t {
    QByteArrayData data[4];
    char stringdata0[42];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_VariableFontEditor_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_VariableFontEditor_t qt_meta_stringdata_VariableFontEditor = {
    {
QT_MOC_LITERAL(0, 0, 18), // "VariableFontEditor"
QT_MOC_LITERAL(1, 19, 12), // "setItemValue"
QT_MOC_LITERAL(2, 32, 0), // ""
QT_MOC_LITERAL(3, 33, 8) // "newValue"

    },
    "VariableFontEditor\0setItemValue\0\0"
    "newValue"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_VariableFontEditor[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   19,    2, 0x09 /* Protected */,

 // slots: parameters
    QMetaType::Void, QMetaType::QFont,    3,

       0        // eod
};

void VariableFontEditor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<VariableFontEditor *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->setItemValue((*reinterpret_cast< const QFont(*)>(_a[1]))); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject VariableFontEditor::staticMetaObject = { {
    QMetaObject::SuperData::link<VariableEditor::staticMetaObject>(),
    qt_meta_stringdata_VariableFontEditor.data,
    qt_meta_data_VariableFontEditor,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *VariableFontEditor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *VariableFontEditor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_VariableFontEditor.stringdata0))
        return static_cast<void*>(this);
    return VariableEditor::qt_metacast(_clname);
}

int VariableFontEditor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = VariableEditor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}
struct qt_meta_stringdata_VariableStringEditor_t {
    QByteArrayData data[4];
    char stringdata0[44];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_VariableStringEditor_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_VariableStringEditor_t qt_meta_stringdata_VariableStringEditor = {
    {
QT_MOC_LITERAL(0, 0, 20), // "VariableStringEditor"
QT_MOC_LITERAL(1, 21, 12), // "setItemValue"
QT_MOC_LITERAL(2, 34, 0), // ""
QT_MOC_LITERAL(3, 35, 8) // "newValue"

    },
    "VariableStringEditor\0setItemValue\0\0"
    "newValue"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_VariableStringEditor[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   19,    2, 0x09 /* Protected */,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    3,

       0        // eod
};

void VariableStringEditor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<VariableStringEditor *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->setItemValue((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject VariableStringEditor::staticMetaObject = { {
    QMetaObject::SuperData::link<VariableEditor::staticMetaObject>(),
    qt_meta_stringdata_VariableStringEditor.data,
    qt_meta_data_VariableStringEditor,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *VariableStringEditor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *VariableStringEditor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_VariableStringEditor.stringdata0))
        return static_cast<void*>(this);
    return VariableEditor::qt_metacast(_clname);
}

int VariableStringEditor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = VariableEditor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}
struct qt_meta_stringdata_VariableSpellCheckEditor_t {
    QByteArrayData data[4];
    char stringdata0[48];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_VariableSpellCheckEditor_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_VariableSpellCheckEditor_t qt_meta_stringdata_VariableSpellCheckEditor = {
    {
QT_MOC_LITERAL(0, 0, 24), // "VariableSpellCheckEditor"
QT_MOC_LITERAL(1, 25, 12), // "setItemValue"
QT_MOC_LITERAL(2, 38, 0), // ""
QT_MOC_LITERAL(3, 39, 8) // "newValue"

    },
    "VariableSpellCheckEditor\0setItemValue\0"
    "\0newValue"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_VariableSpellCheckEditor[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   19,    2, 0x09 /* Protected */,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    3,

       0        // eod
};

void VariableSpellCheckEditor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<VariableSpellCheckEditor *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->setItemValue((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject VariableSpellCheckEditor::staticMetaObject = { {
    QMetaObject::SuperData::link<VariableEditor::staticMetaObject>(),
    qt_meta_stringdata_VariableSpellCheckEditor.data,
    qt_meta_data_VariableSpellCheckEditor,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *VariableSpellCheckEditor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *VariableSpellCheckEditor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_VariableSpellCheckEditor.stringdata0))
        return static_cast<void*>(this);
    return VariableEditor::qt_metacast(_clname);
}

int VariableSpellCheckEditor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = VariableEditor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}
struct qt_meta_stringdata_VariableRemoveSpacesEditor_t {
    QByteArrayData data[4];
    char stringdata0[49];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_VariableRemoveSpacesEditor_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_VariableRemoveSpacesEditor_t qt_meta_stringdata_VariableRemoveSpacesEditor = {
    {
QT_MOC_LITERAL(0, 0, 26), // "VariableRemoveSpacesEditor"
QT_MOC_LITERAL(1, 27, 12), // "setItemValue"
QT_MOC_LITERAL(2, 40, 0), // ""
QT_MOC_LITERAL(3, 41, 7) // "enabled"

    },
    "VariableRemoveSpacesEditor\0setItemValue\0"
    "\0enabled"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_VariableRemoveSpacesEditor[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   19,    2, 0x09 /* Protected */,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,    3,

       0        // eod
};

void VariableRemoveSpacesEditor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<VariableRemoveSpacesEditor *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->setItemValue((*reinterpret_cast< int(*)>(_a[1]))); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject VariableRemoveSpacesEditor::staticMetaObject = { {
    QMetaObject::SuperData::link<VariableEditor::staticMetaObject>(),
    qt_meta_stringdata_VariableRemoveSpacesEditor.data,
    qt_meta_data_VariableRemoveSpacesEditor,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *VariableRemoveSpacesEditor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *VariableRemoveSpacesEditor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_VariableRemoveSpacesEditor.stringdata0))
        return static_cast<void*>(this);
    return VariableEditor::qt_metacast(_clname);
}

int VariableRemoveSpacesEditor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = VariableEditor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
