/****************************************************************************
** Meta object code from reading C++ file 'katesearchbar.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../ktexteditor-5.116.0/src/search/katesearchbar.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'katesearchbar.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KateSearchBar_t {
    QByteArrayData data[38];
    char stringdata0[627];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KateSearchBar_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KateSearchBar_t qt_meta_stringdata_KateSearchBar = {
    {
QT_MOC_LITERAL(0, 0, 13), // "KateSearchBar"
QT_MOC_LITERAL(1, 14, 24), // "findOrReplaceAllFinished"
QT_MOC_LITERAL(2, 39, 0), // ""
QT_MOC_LITERAL(3, 40, 16), // "setSearchPattern"
QT_MOC_LITERAL(4, 57, 13), // "searchPattern"
QT_MOC_LITERAL(5, 71, 21), // "setReplacementPattern"
QT_MOC_LITERAL(6, 93, 18), // "replacementPattern"
QT_MOC_LITERAL(7, 112, 13), // "setSearchMode"
QT_MOC_LITERAL(8, 126, 10), // "SearchMode"
QT_MOC_LITERAL(9, 137, 4), // "mode"
QT_MOC_LITERAL(10, 142, 16), // "setSelectionOnly"
QT_MOC_LITERAL(11, 159, 13), // "selectionOnly"
QT_MOC_LITERAL(12, 173, 12), // "setMatchCase"
QT_MOC_LITERAL(13, 186, 9), // "matchCase"
QT_MOC_LITERAL(14, 196, 8), // "findNext"
QT_MOC_LITERAL(15, 205, 12), // "findPrevious"
QT_MOC_LITERAL(16, 218, 7), // "findAll"
QT_MOC_LITERAL(17, 226, 11), // "replaceNext"
QT_MOC_LITERAL(18, 238, 10), // "replaceAll"
QT_MOC_LITERAL(19, 249, 14), // "enterPowerMode"
QT_MOC_LITERAL(20, 264, 20), // "enterIncrementalMode"
QT_MOC_LITERAL(21, 285, 15), // "clearHighlights"
QT_MOC_LITERAL(22, 301, 21), // "updateHighlightColors"
QT_MOC_LITERAL(23, 323, 20), // "slotReadWriteChanged"
QT_MOC_LITERAL(24, 344, 19), // "onIncPatternChanged"
QT_MOC_LITERAL(25, 364, 7), // "pattern"
QT_MOC_LITERAL(26, 372, 18), // "onMatchCaseToggled"
QT_MOC_LITERAL(27, 391, 15), // "onReturnPressed"
QT_MOC_LITERAL(28, 407, 19), // "updateSelectionOnly"
QT_MOC_LITERAL(29, 427, 19), // "updateIncInitCursor"
QT_MOC_LITERAL(30, 447, 21), // "onPowerPatternChanged"
QT_MOC_LITERAL(31, 469, 18), // "onPowerModeChanged"
QT_MOC_LITERAL(32, 488, 5), // "index"
QT_MOC_LITERAL(33, 494, 32), // "onPowerPatternContextMenuRequest"
QT_MOC_LITERAL(34, 527, 35), // "onPowerReplacmentContextMenuR..."
QT_MOC_LITERAL(35, 563, 26), // "onPowerCancelFindOrReplace"
QT_MOC_LITERAL(36, 590, 16), // "findOrReplaceAll"
QT_MOC_LITERAL(37, 607, 19) // "endFindOrReplaceAll"

    },
    "KateSearchBar\0findOrReplaceAllFinished\0"
    "\0setSearchPattern\0searchPattern\0"
    "setReplacementPattern\0replacementPattern\0"
    "setSearchMode\0SearchMode\0mode\0"
    "setSelectionOnly\0selectionOnly\0"
    "setMatchCase\0matchCase\0findNext\0"
    "findPrevious\0findAll\0replaceNext\0"
    "replaceAll\0enterPowerMode\0"
    "enterIncrementalMode\0clearHighlights\0"
    "updateHighlightColors\0slotReadWriteChanged\0"
    "onIncPatternChanged\0pattern\0"
    "onMatchCaseToggled\0onReturnPressed\0"
    "updateSelectionOnly\0updateIncInitCursor\0"
    "onPowerPatternChanged\0onPowerModeChanged\0"
    "index\0onPowerPatternContextMenuRequest\0"
    "onPowerReplacmentContextMenuRequest\0"
    "onPowerCancelFindOrReplace\0findOrReplaceAll\0"
    "endFindOrReplaceAll"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KateSearchBar[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      30,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  164,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    1,  165,    2, 0x0a /* Public */,
       5,    1,  168,    2, 0x0a /* Public */,
       7,    1,  171,    2, 0x0a /* Public */,
      10,    1,  174,    2, 0x0a /* Public */,
      12,    1,  177,    2, 0x0a /* Public */,
      14,    0,  180,    2, 0x0a /* Public */,
      15,    0,  181,    2, 0x0a /* Public */,
      16,    0,  182,    2, 0x0a /* Public */,
      17,    0,  183,    2, 0x0a /* Public */,
      18,    0,  184,    2, 0x0a /* Public */,
      19,    0,  185,    2, 0x0a /* Public */,
      20,    0,  186,    2, 0x0a /* Public */,
      21,    0,  187,    2, 0x0a /* Public */,
      22,    0,  188,    2, 0x0a /* Public */,
      23,    0,  189,    2, 0x0a /* Public */,
      24,    1,  190,    2, 0x08 /* Private */,
      26,    1,  193,    2, 0x08 /* Private */,
      27,    0,  196,    2, 0x08 /* Private */,
      28,    0,  197,    2, 0x08 /* Private */,
      29,    0,  198,    2, 0x08 /* Private */,
      30,    1,  199,    2, 0x08 /* Private */,
      31,    1,  202,    2, 0x08 /* Private */,
      33,    0,  205,    2, 0x08 /* Private */,
      33,    1,  206,    2, 0x08 /* Private */,
      34,    0,  209,    2, 0x08 /* Private */,
      34,    1,  210,    2, 0x08 /* Private */,
      35,    0,  213,    2, 0x08 /* Private */,
      36,    0,  214,    2, 0x08 /* Private */,
      37,    0,  215,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    4,
    QMetaType::Void, QMetaType::QString,    6,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, QMetaType::Bool,   11,
    QMetaType::Void, QMetaType::Bool,   13,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Bool,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   25,
    QMetaType::Void, QMetaType::Bool,   13,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   25,
    QMetaType::Void, QMetaType::Int,   32,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QPoint,    2,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QPoint,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void KateSearchBar::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<KateSearchBar *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->findOrReplaceAllFinished(); break;
        case 1: _t->setSearchPattern((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->setReplacementPattern((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->setSearchMode((*reinterpret_cast< SearchMode(*)>(_a[1]))); break;
        case 4: _t->setSelectionOnly((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 5: _t->setMatchCase((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 6: _t->findNext(); break;
        case 7: _t->findPrevious(); break;
        case 8: _t->findAll(); break;
        case 9: _t->replaceNext(); break;
        case 10: _t->replaceAll(); break;
        case 11: _t->enterPowerMode(); break;
        case 12: _t->enterIncrementalMode(); break;
        case 13: { bool _r = _t->clearHighlights();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 14: _t->updateHighlightColors(); break;
        case 15: _t->slotReadWriteChanged(); break;
        case 16: _t->onIncPatternChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 17: _t->onMatchCaseToggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 18: _t->onReturnPressed(); break;
        case 19: _t->updateSelectionOnly(); break;
        case 20: _t->updateIncInitCursor(); break;
        case 21: _t->onPowerPatternChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 22: _t->onPowerModeChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 23: _t->onPowerPatternContextMenuRequest(); break;
        case 24: _t->onPowerPatternContextMenuRequest((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
        case 25: _t->onPowerReplacmentContextMenuRequest(); break;
        case 26: _t->onPowerReplacmentContextMenuRequest((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
        case 27: _t->onPowerCancelFindOrReplace(); break;
        case 28: _t->findOrReplaceAll(); break;
        case 29: _t->endFindOrReplaceAll(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (KateSearchBar::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KateSearchBar::findOrReplaceAllFinished)) {
                *result = 0;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject KateSearchBar::staticMetaObject = { {
    QMetaObject::SuperData::link<KateViewBarWidget::staticMetaObject>(),
    qt_meta_stringdata_KateSearchBar.data,
    qt_meta_data_KateSearchBar,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *KateSearchBar::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateSearchBar::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KateSearchBar.stringdata0))
        return static_cast<void*>(this);
    return KateViewBarWidget::qt_metacast(_clname);
}

int KateSearchBar::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KateViewBarWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 30)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 30;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 30)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 30;
    }
    return _id;
}

// SIGNAL 0
void KateSearchBar::findOrReplaceAllFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
