/****************************************************************************
** Meta object code from reading C++ file 'codecompletionmodel.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../ktexteditor-5.116.0/src/include/ktexteditor/codecompletionmodel.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'codecompletionmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KTextEditor__CodeCompletionModel_t {
    QByteArrayData data[7];
    char stringdata0[114];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KTextEditor__CodeCompletionModel_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KTextEditor__CodeCompletionModel_t qt_meta_stringdata_KTextEditor__CodeCompletionModel = {
    {
QT_MOC_LITERAL(0, 0, 32), // "KTextEditor::CodeCompletionModel"
QT_MOC_LITERAL(1, 33, 12), // "waitForReset"
QT_MOC_LITERAL(2, 46, 0), // ""
QT_MOC_LITERAL(3, 47, 16), // "hasGroupsChanged"
QT_MOC_LITERAL(4, 64, 33), // "KTextEditor::CodeCompletionMo..."
QT_MOC_LITERAL(5, 98, 5), // "model"
QT_MOC_LITERAL(6, 104, 9) // "hasGroups"

    },
    "KTextEditor::CodeCompletionModel\0"
    "waitForReset\0\0hasGroupsChanged\0"
    "KTextEditor::CodeCompletionModel*\0"
    "model\0hasGroups"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KTextEditor__CodeCompletionModel[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   24,    2, 0x06 /* Public */,
       3,    2,   25,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 4, QMetaType::Bool,    5,    6,

       0        // eod
};

void KTextEditor::CodeCompletionModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<CodeCompletionModel *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->waitForReset(); break;
        case 1: _t->hasGroupsChanged((*reinterpret_cast< KTextEditor::CodeCompletionModel*(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::CodeCompletionModel* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (CodeCompletionModel::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CodeCompletionModel::waitForReset)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (CodeCompletionModel::*)(KTextEditor::CodeCompletionModel * , bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CodeCompletionModel::hasGroupsChanged)) {
                *result = 1;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject KTextEditor::CodeCompletionModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractItemModel::staticMetaObject>(),
    qt_meta_stringdata_KTextEditor__CodeCompletionModel.data,
    qt_meta_data_KTextEditor__CodeCompletionModel,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *KTextEditor::CodeCompletionModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KTextEditor::CodeCompletionModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KTextEditor__CodeCompletionModel.stringdata0))
        return static_cast<void*>(this);
    return QAbstractItemModel::qt_metacast(_clname);
}

int KTextEditor::CodeCompletionModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractItemModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void KTextEditor::CodeCompletionModel::waitForReset()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KTextEditor::CodeCompletionModel::hasGroupsChanged(KTextEditor::CodeCompletionModel * _t1, bool _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
