/****************************************************************************
** Meta object code from reading C++ file 'katescriptdocument.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../ktexteditor-5.116.0/src/script/katescriptdocument.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'katescriptdocument.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KateScriptDocument_t {
    QByteArrayData data[103];
    char stringdata0[1097];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KateScriptDocument_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KateScriptDocument_t qt_meta_stringdata_KateScriptDocument = {
    {
QT_MOC_LITERAL(0, 0, 18), // "KateScriptDocument"
QT_MOC_LITERAL(1, 19, 8), // "fileName"
QT_MOC_LITERAL(2, 28, 0), // ""
QT_MOC_LITERAL(3, 29, 3), // "url"
QT_MOC_LITERAL(4, 33, 8), // "mimeType"
QT_MOC_LITERAL(5, 42, 8), // "encoding"
QT_MOC_LITERAL(6, 51, 16), // "highlightingMode"
QT_MOC_LITERAL(7, 68, 25), // "embeddedHighlightingModes"
QT_MOC_LITERAL(8, 94, 18), // "highlightingModeAt"
QT_MOC_LITERAL(9, 113, 8), // "QJSValue"
QT_MOC_LITERAL(10, 122, 3), // "pos"
QT_MOC_LITERAL(11, 126, 10), // "isModified"
QT_MOC_LITERAL(12, 137, 4), // "text"
QT_MOC_LITERAL(13, 142, 8), // "fromLine"
QT_MOC_LITERAL(14, 151, 10), // "fromColumn"
QT_MOC_LITERAL(15, 162, 6), // "toLine"
QT_MOC_LITERAL(16, 169, 8), // "toColumn"
QT_MOC_LITERAL(17, 178, 6), // "jsfrom"
QT_MOC_LITERAL(18, 185, 4), // "jsto"
QT_MOC_LITERAL(19, 190, 7), // "jsrange"
QT_MOC_LITERAL(20, 198, 4), // "line"
QT_MOC_LITERAL(21, 203, 6), // "wordAt"
QT_MOC_LITERAL(22, 210, 6), // "column"
QT_MOC_LITERAL(23, 217, 8), // "jscursor"
QT_MOC_LITERAL(24, 226, 11), // "wordRangeAt"
QT_MOC_LITERAL(25, 238, 6), // "charAt"
QT_MOC_LITERAL(26, 245, 9), // "firstChar"
QT_MOC_LITERAL(27, 255, 8), // "lastChar"
QT_MOC_LITERAL(28, 264, 7), // "isSpace"
QT_MOC_LITERAL(29, 272, 9), // "matchesAt"
QT_MOC_LITERAL(30, 282, 1), // "s"
QT_MOC_LITERAL(31, 284, 6), // "cursor"
QT_MOC_LITERAL(32, 291, 7), // "setText"
QT_MOC_LITERAL(33, 299, 5), // "clear"
QT_MOC_LITERAL(34, 305, 8), // "truncate"
QT_MOC_LITERAL(35, 314, 10), // "insertText"
QT_MOC_LITERAL(36, 325, 10), // "removeText"
QT_MOC_LITERAL(37, 336, 5), // "range"
QT_MOC_LITERAL(38, 342, 10), // "insertLine"
QT_MOC_LITERAL(39, 353, 10), // "removeLine"
QT_MOC_LITERAL(40, 364, 8), // "wrapLine"
QT_MOC_LITERAL(41, 373, 9), // "joinLines"
QT_MOC_LITERAL(42, 383, 9), // "startLine"
QT_MOC_LITERAL(43, 393, 7), // "endLine"
QT_MOC_LITERAL(44, 401, 5), // "lines"
QT_MOC_LITERAL(45, 407, 14), // "isLineModified"
QT_MOC_LITERAL(46, 422, 11), // "isLineSaved"
QT_MOC_LITERAL(47, 434, 13), // "isLineTouched"
QT_MOC_LITERAL(48, 448, 15), // "findTouchedLine"
QT_MOC_LITERAL(49, 464, 4), // "down"
QT_MOC_LITERAL(50, 469, 6), // "length"
QT_MOC_LITERAL(51, 476, 10), // "lineLength"
QT_MOC_LITERAL(52, 487, 9), // "editBegin"
QT_MOC_LITERAL(53, 497, 7), // "editEnd"
QT_MOC_LITERAL(54, 505, 11), // "firstColumn"
QT_MOC_LITERAL(55, 517, 10), // "lastColumn"
QT_MOC_LITERAL(56, 528, 18), // "prevNonSpaceColumn"
QT_MOC_LITERAL(57, 547, 18), // "nextNonSpaceColumn"
QT_MOC_LITERAL(58, 566, 16), // "prevNonEmptyLine"
QT_MOC_LITERAL(59, 583, 16), // "nextNonEmptyLine"
QT_MOC_LITERAL(60, 600, 8), // "isInWord"
QT_MOC_LITERAL(61, 609, 9), // "character"
QT_MOC_LITERAL(62, 619, 9), // "attribute"
QT_MOC_LITERAL(63, 629, 10), // "canBreakAt"
QT_MOC_LITERAL(64, 640, 10), // "canComment"
QT_MOC_LITERAL(65, 651, 14), // "startAttribute"
QT_MOC_LITERAL(66, 666, 12), // "endAttribute"
QT_MOC_LITERAL(67, 679, 13), // "commentMarker"
QT_MOC_LITERAL(68, 693, 12), // "commentStart"
QT_MOC_LITERAL(69, 706, 10), // "commentEnd"
QT_MOC_LITERAL(70, 717, 13), // "documentRange"
QT_MOC_LITERAL(71, 731, 11), // "documentEnd"
QT_MOC_LITERAL(72, 743, 19), // "isValidTextPosition"
QT_MOC_LITERAL(73, 763, 11), // "isAttribute"
QT_MOC_LITERAL(74, 775, 4), // "attr"
QT_MOC_LITERAL(75, 780, 13), // "attributeName"
QT_MOC_LITERAL(76, 794, 15), // "isAttributeName"
QT_MOC_LITERAL(77, 810, 4), // "name"
QT_MOC_LITERAL(78, 815, 8), // "variable"
QT_MOC_LITERAL(79, 824, 11), // "setVariable"
QT_MOC_LITERAL(80, 836, 1), // "v"
QT_MOC_LITERAL(81, 838, 18), // "firstVirtualColumn"
QT_MOC_LITERAL(82, 857, 17), // "lastVirtualColumn"
QT_MOC_LITERAL(83, 875, 15), // "toVirtualColumn"
QT_MOC_LITERAL(84, 891, 15), // "toVirtualCursor"
QT_MOC_LITERAL(85, 907, 17), // "fromVirtualColumn"
QT_MOC_LITERAL(86, 925, 13), // "virtualColumn"
QT_MOC_LITERAL(87, 939, 17), // "fromVirtualCursor"
QT_MOC_LITERAL(88, 957, 6), // "anchor"
QT_MOC_LITERAL(89, 964, 5), // "rfind"
QT_MOC_LITERAL(90, 970, 11), // "defStyleNum"
QT_MOC_LITERAL(91, 982, 6), // "isCode"
QT_MOC_LITERAL(92, 989, 9), // "isComment"
QT_MOC_LITERAL(93, 999, 8), // "isString"
QT_MOC_LITERAL(94, 1008, 14), // "isRegionMarker"
QT_MOC_LITERAL(95, 1023, 6), // "isChar"
QT_MOC_LITERAL(96, 1030, 8), // "isOthers"
QT_MOC_LITERAL(97, 1039, 10), // "startsWith"
QT_MOC_LITERAL(98, 1050, 7), // "pattern"
QT_MOC_LITERAL(99, 1058, 15), // "skipWhiteSpaces"
QT_MOC_LITERAL(100, 1074, 8), // "endsWith"
QT_MOC_LITERAL(101, 1083, 6), // "indent"
QT_MOC_LITERAL(102, 1090, 6) // "change"

    },
    "KateScriptDocument\0fileName\0\0url\0"
    "mimeType\0encoding\0highlightingMode\0"
    "embeddedHighlightingModes\0highlightingModeAt\0"
    "QJSValue\0pos\0isModified\0text\0fromLine\0"
    "fromColumn\0toLine\0toColumn\0jsfrom\0"
    "jsto\0jsrange\0line\0wordAt\0column\0"
    "jscursor\0wordRangeAt\0charAt\0firstChar\0"
    "lastChar\0isSpace\0matchesAt\0s\0cursor\0"
    "setText\0clear\0truncate\0insertText\0"
    "removeText\0range\0insertLine\0removeLine\0"
    "wrapLine\0joinLines\0startLine\0endLine\0"
    "lines\0isLineModified\0isLineSaved\0"
    "isLineTouched\0findTouchedLine\0down\0"
    "length\0lineLength\0editBegin\0editEnd\0"
    "firstColumn\0lastColumn\0prevNonSpaceColumn\0"
    "nextNonSpaceColumn\0prevNonEmptyLine\0"
    "nextNonEmptyLine\0isInWord\0character\0"
    "attribute\0canBreakAt\0canComment\0"
    "startAttribute\0endAttribute\0commentMarker\0"
    "commentStart\0commentEnd\0documentRange\0"
    "documentEnd\0isValidTextPosition\0"
    "isAttribute\0attr\0attributeName\0"
    "isAttributeName\0name\0variable\0setVariable\0"
    "v\0firstVirtualColumn\0lastVirtualColumn\0"
    "toVirtualColumn\0toVirtualCursor\0"
    "fromVirtualColumn\0virtualColumn\0"
    "fromVirtualCursor\0anchor\0rfind\0"
    "defStyleNum\0isCode\0isComment\0isString\0"
    "isRegionMarker\0isChar\0isOthers\0"
    "startsWith\0pattern\0skipWhiteSpaces\0"
    "endsWith\0indent\0change"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KateScriptDocument[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
     109,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // methods: name, argc, parameters, tag, flags
       1,    0,  559,    2, 0x02 /* Public */,
       3,    0,  560,    2, 0x02 /* Public */,
       4,    0,  561,    2, 0x02 /* Public */,
       5,    0,  562,    2, 0x02 /* Public */,
       6,    0,  563,    2, 0x02 /* Public */,
       7,    0,  564,    2, 0x02 /* Public */,
       8,    1,  565,    2, 0x02 /* Public */,
      11,    0,  568,    2, 0x02 /* Public */,
      12,    0,  569,    2, 0x02 /* Public */,
      12,    4,  570,    2, 0x02 /* Public */,
      12,    2,  579,    2, 0x02 /* Public */,
      12,    1,  584,    2, 0x02 /* Public */,
      20,    1,  587,    2, 0x02 /* Public */,
      21,    2,  590,    2, 0x02 /* Public */,
      21,    1,  595,    2, 0x02 /* Public */,
      24,    2,  598,    2, 0x02 /* Public */,
      24,    1,  603,    2, 0x02 /* Public */,
      25,    2,  606,    2, 0x02 /* Public */,
      25,    1,  611,    2, 0x02 /* Public */,
      26,    1,  614,    2, 0x02 /* Public */,
      27,    1,  617,    2, 0x02 /* Public */,
      28,    2,  620,    2, 0x02 /* Public */,
      28,    1,  625,    2, 0x02 /* Public */,
      29,    3,  628,    2, 0x02 /* Public */,
      29,    2,  635,    2, 0x02 /* Public */,
      32,    1,  640,    2, 0x02 /* Public */,
      33,    0,  643,    2, 0x02 /* Public */,
      34,    2,  644,    2, 0x02 /* Public */,
      34,    1,  649,    2, 0x02 /* Public */,
      35,    3,  652,    2, 0x02 /* Public */,
      35,    2,  659,    2, 0x02 /* Public */,
      36,    4,  664,    2, 0x02 /* Public */,
      36,    1,  673,    2, 0x02 /* Public */,
      36,    2,  676,    2, 0x02 /* Public */,
      38,    2,  681,    2, 0x02 /* Public */,
      39,    1,  686,    2, 0x02 /* Public */,
      40,    2,  689,    2, 0x02 /* Public */,
      40,    1,  694,    2, 0x02 /* Public */,
      41,    2,  697,    2, 0x02 /* Public */,
      44,    0,  702,    2, 0x02 /* Public */,
      45,    1,  703,    2, 0x02 /* Public */,
      46,    1,  706,    2, 0x02 /* Public */,
      47,    1,  709,    2, 0x02 /* Public */,
      48,    2,  712,    2, 0x02 /* Public */,
      50,    0,  717,    2, 0x02 /* Public */,
      51,    1,  718,    2, 0x02 /* Public */,
      52,    0,  721,    2, 0x02 /* Public */,
      53,    0,  722,    2, 0x02 /* Public */,
      54,    1,  723,    2, 0x02 /* Public */,
      55,    1,  726,    2, 0x02 /* Public */,
      56,    2,  729,    2, 0x02 /* Public */,
      56,    1,  734,    2, 0x02 /* Public */,
      57,    2,  737,    2, 0x02 /* Public */,
      57,    1,  742,    2, 0x02 /* Public */,
      58,    1,  745,    2, 0x02 /* Public */,
      59,    1,  748,    2, 0x02 /* Public */,
      60,    2,  751,    2, 0x02 /* Public */,
      63,    2,  756,    2, 0x02 /* Public */,
      64,    2,  761,    2, 0x02 /* Public */,
      67,    1,  766,    2, 0x02 /* Public */,
      68,    1,  769,    2, 0x02 /* Public */,
      69,    1,  772,    2, 0x02 /* Public */,
      70,    0,  775,    2, 0x02 /* Public */,
      71,    0,  776,    2, 0x02 /* Public */,
      72,    2,  777,    2, 0x02 /* Public */,
      72,    1,  782,    2, 0x02 /* Public */,
      62,    2,  785,    2, 0x02 /* Public */,
      62,    1,  790,    2, 0x02 /* Public */,
      73,    3,  793,    2, 0x02 /* Public */,
      73,    2,  800,    2, 0x02 /* Public */,
      75,    2,  805,    2, 0x02 /* Public */,
      75,    1,  810,    2, 0x02 /* Public */,
      76,    3,  813,    2, 0x02 /* Public */,
      76,    2,  820,    2, 0x02 /* Public */,
      78,    1,  825,    2, 0x02 /* Public */,
      79,    2,  828,    2, 0x02 /* Public */,
      81,    1,  833,    2, 0x02 /* Public */,
      82,    1,  836,    2, 0x02 /* Public */,
      83,    2,  839,    2, 0x02 /* Public */,
      83,    1,  844,    2, 0x02 /* Public */,
      84,    2,  847,    2, 0x02 /* Public */,
      84,    1,  852,    2, 0x02 /* Public */,
      85,    2,  855,    2, 0x02 /* Public */,
      85,    1,  860,    2, 0x02 /* Public */,
      87,    2,  863,    2, 0x02 /* Public */,
      87,    1,  868,    2, 0x02 /* Public */,
      88,    3,  871,    2, 0x02 /* Public */,
      88,    2,  878,    2, 0x02 /* Public */,
      89,    4,  883,    2, 0x02 /* Public */,
      89,    3,  892,    2, 0x22 /* Public | MethodCloned */,
      89,    3,  899,    2, 0x02 /* Public */,
      89,    2,  906,    2, 0x22 /* Public | MethodCloned */,
      90,    2,  911,    2, 0x02 /* Public */,
      90,    1,  916,    2, 0x02 /* Public */,
      91,    2,  919,    2, 0x02 /* Public */,
      91,    1,  924,    2, 0x02 /* Public */,
      92,    2,  927,    2, 0x02 /* Public */,
      92,    1,  932,    2, 0x02 /* Public */,
      93,    2,  935,    2, 0x02 /* Public */,
      93,    1,  940,    2, 0x02 /* Public */,
      94,    2,  943,    2, 0x02 /* Public */,
      94,    1,  948,    2, 0x02 /* Public */,
      95,    2,  951,    2, 0x02 /* Public */,
      95,    1,  956,    2, 0x02 /* Public */,
      96,    2,  959,    2, 0x02 /* Public */,
      96,    1,  964,    2, 0x02 /* Public */,
      97,    3,  967,    2, 0x02 /* Public */,
     100,    3,  974,    2, 0x02 /* Public */,
     101,    2,  981,    2, 0x02 /* Public */,

 // methods: parameters
    QMetaType::QString,
    QMetaType::QString,
    QMetaType::QString,
    QMetaType::QString,
    QMetaType::QString,
    QMetaType::QStringList,
    QMetaType::QString, 0x80000000 | 9,   10,
    QMetaType::Bool,
    QMetaType::QString,
    QMetaType::QString, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::Int,   13,   14,   15,   16,
    QMetaType::QString, 0x80000000 | 9, 0x80000000 | 9,   17,   18,
    QMetaType::QString, 0x80000000 | 9,   19,
    QMetaType::QString, QMetaType::Int,   20,
    QMetaType::QString, QMetaType::Int, QMetaType::Int,   20,   22,
    QMetaType::QString, 0x80000000 | 9,   23,
    0x80000000 | 9, QMetaType::Int, QMetaType::Int,   20,   22,
    0x80000000 | 9, 0x80000000 | 9,   23,
    QMetaType::QString, QMetaType::Int, QMetaType::Int,   20,   22,
    QMetaType::QString, 0x80000000 | 9,   23,
    QMetaType::QString, QMetaType::Int,   20,
    QMetaType::QString, QMetaType::Int,   20,
    QMetaType::Bool, QMetaType::Int, QMetaType::Int,   20,   22,
    QMetaType::Bool, 0x80000000 | 9,   23,
    QMetaType::Bool, QMetaType::Int, QMetaType::Int, QMetaType::QString,   20,   22,   30,
    QMetaType::Bool, 0x80000000 | 9, QMetaType::QString,   31,   30,
    QMetaType::Bool, QMetaType::QString,   30,
    QMetaType::Bool,
    QMetaType::Bool, QMetaType::Int, QMetaType::Int,   20,   22,
    QMetaType::Bool, 0x80000000 | 9,   23,
    QMetaType::Bool, QMetaType::Int, QMetaType::Int, QMetaType::QString,   20,   22,   30,
    QMetaType::Bool, 0x80000000 | 9, QMetaType::QString,   23,   30,
    QMetaType::Bool, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::Int,   13,   14,   15,   16,
    QMetaType::Bool, 0x80000000 | 9,   37,
    QMetaType::Bool, 0x80000000 | 9, 0x80000000 | 9,   17,   18,
    QMetaType::Bool, QMetaType::Int, QMetaType::QString,   20,   30,
    QMetaType::Bool, QMetaType::Int,   20,
    QMetaType::Bool, QMetaType::Int, QMetaType::Int,   20,   22,
    QMetaType::Bool, 0x80000000 | 9,   31,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,   42,   43,
    QMetaType::Int,
    QMetaType::Bool, QMetaType::Int,   20,
    QMetaType::Bool, QMetaType::Int,   20,
    QMetaType::Bool, QMetaType::Int,   20,
    QMetaType::Int, QMetaType::Int, QMetaType::Bool,   42,   49,
    QMetaType::Int,
    QMetaType::Int, QMetaType::Int,   20,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Int, QMetaType::Int,   20,
    QMetaType::Int, QMetaType::Int,   20,
    QMetaType::Int, QMetaType::Int, QMetaType::Int,   20,   22,
    QMetaType::Int, 0x80000000 | 9,   23,
    QMetaType::Int, QMetaType::Int, QMetaType::Int,   20,   22,
    QMetaType::Int, 0x80000000 | 9,   23,
    QMetaType::Int, QMetaType::Int,   20,
    QMetaType::Int, QMetaType::Int,   20,
    QMetaType::Bool, QMetaType::QString, QMetaType::Int,   61,   62,
    QMetaType::Bool, QMetaType::QString, QMetaType::Int,   61,   62,
    QMetaType::Bool, QMetaType::Int, QMetaType::Int,   65,   66,
    QMetaType::QString, QMetaType::Int,   62,
    QMetaType::QString, QMetaType::Int,   62,
    QMetaType::QString, QMetaType::Int,   62,
    0x80000000 | 9,
    0x80000000 | 9,
    QMetaType::Bool, QMetaType::Int, QMetaType::Int,   20,   22,
    QMetaType::Bool, 0x80000000 | 9,   31,
    QMetaType::Int, QMetaType::Int, QMetaType::Int,   20,   22,
    QMetaType::Int, 0x80000000 | 9,   23,
    QMetaType::Bool, QMetaType::Int, QMetaType::Int, QMetaType::Int,   20,   22,   74,
    QMetaType::Bool, 0x80000000 | 9, QMetaType::Int,   23,   74,
    QMetaType::QString, QMetaType::Int, QMetaType::Int,   20,   22,
    QMetaType::QString, 0x80000000 | 9,   23,
    QMetaType::Bool, QMetaType::Int, QMetaType::Int, QMetaType::QString,   20,   22,   77,
    QMetaType::Bool, 0x80000000 | 9, QMetaType::QString,   31,   77,
    QMetaType::QString, QMetaType::QString,   30,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,   30,   80,
    QMetaType::Int, QMetaType::Int,   20,
    QMetaType::Int, QMetaType::Int,   20,
    QMetaType::Int, QMetaType::Int, QMetaType::Int,   20,   22,
    QMetaType::Int, 0x80000000 | 9,   31,
    0x80000000 | 9, QMetaType::Int, QMetaType::Int,   20,   22,
    0x80000000 | 9, 0x80000000 | 9,   23,
    QMetaType::Int, QMetaType::Int, QMetaType::Int,   20,   86,
    QMetaType::Int, 0x80000000 | 9,   23,
    0x80000000 | 9, QMetaType::Int, QMetaType::Int,   20,   22,
    0x80000000 | 9, 0x80000000 | 9,   23,
    0x80000000 | 9, QMetaType::Int, QMetaType::Int, QMetaType::QChar,   20,   22,   61,
    0x80000000 | 9, 0x80000000 | 9, QMetaType::QChar,   31,   61,
    0x80000000 | 9, QMetaType::Int, QMetaType::Int, QMetaType::QString, QMetaType::Int,   20,   22,   12,   62,
    0x80000000 | 9, QMetaType::Int, QMetaType::Int, QMetaType::QString,   20,   22,   12,
    0x80000000 | 9, 0x80000000 | 9, QMetaType::QString, QMetaType::Int,   31,   12,   62,
    0x80000000 | 9, 0x80000000 | 9, QMetaType::QString,   31,   12,
    QMetaType::Int, QMetaType::Int, QMetaType::Int,   20,   22,
    QMetaType::Int, 0x80000000 | 9,   31,
    QMetaType::Bool, QMetaType::Int, QMetaType::Int,   20,   22,
    QMetaType::Bool, 0x80000000 | 9,   31,
    QMetaType::Bool, QMetaType::Int, QMetaType::Int,   20,   22,
    QMetaType::Bool, 0x80000000 | 9,   31,
    QMetaType::Bool, QMetaType::Int, QMetaType::Int,   20,   22,
    QMetaType::Bool, 0x80000000 | 9,   31,
    QMetaType::Bool, QMetaType::Int, QMetaType::Int,   20,   22,
    QMetaType::Bool, 0x80000000 | 9,   31,
    QMetaType::Bool, QMetaType::Int, QMetaType::Int,   20,   22,
    QMetaType::Bool, 0x80000000 | 9,   31,
    QMetaType::Bool, QMetaType::Int, QMetaType::Int,   20,   22,
    QMetaType::Bool, 0x80000000 | 9,   31,
    QMetaType::Bool, QMetaType::Int, QMetaType::QString, QMetaType::Bool,   20,   98,   99,
    QMetaType::Bool, QMetaType::Int, QMetaType::QString, QMetaType::Bool,   20,   98,   99,
    QMetaType::Void, 0x80000000 | 9, QMetaType::Int,   19,  102,

       0        // eod
};

void KateScriptDocument::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<KateScriptDocument *>(_o);
        (void)_t;
        switch (_id) {
        case 0: { QString _r = _t->fileName();
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 1: { QString _r = _t->url();
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 2: { QString _r = _t->mimeType();
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 3: { QString _r = _t->encoding();
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 4: { QString _r = _t->highlightingMode();
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 5: { QStringList _r = _t->embeddedHighlightingModes();
            if (_a[0]) *reinterpret_cast< QStringList*>(_a[0]) = std::move(_r); }  break;
        case 6: { QString _r = _t->highlightingModeAt((*reinterpret_cast< const QJSValue(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 7: { bool _r = _t->isModified();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 8: { QString _r = _t->text();
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 9: { QString _r = _t->text((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 10: { QString _r = _t->text((*reinterpret_cast< const QJSValue(*)>(_a[1])),(*reinterpret_cast< const QJSValue(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 11: { QString _r = _t->text((*reinterpret_cast< const QJSValue(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 12: { QString _r = _t->line((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 13: { QString _r = _t->wordAt((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 14: { QString _r = _t->wordAt((*reinterpret_cast< const QJSValue(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 15: { QJSValue _r = _t->wordRangeAt((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 16: { QJSValue _r = _t->wordRangeAt((*reinterpret_cast< const QJSValue(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 17: { QString _r = _t->charAt((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 18: { QString _r = _t->charAt((*reinterpret_cast< const QJSValue(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 19: { QString _r = _t->firstChar((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 20: { QString _r = _t->lastChar((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 21: { bool _r = _t->isSpace((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 22: { bool _r = _t->isSpace((*reinterpret_cast< const QJSValue(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 23: { bool _r = _t->matchesAt((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 24: { bool _r = _t->matchesAt((*reinterpret_cast< const QJSValue(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 25: { bool _r = _t->setText((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 26: { bool _r = _t->clear();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 27: { bool _r = _t->truncate((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 28: { bool _r = _t->truncate((*reinterpret_cast< const QJSValue(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 29: { bool _r = _t->insertText((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 30: { bool _r = _t->insertText((*reinterpret_cast< const QJSValue(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 31: { bool _r = _t->removeText((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 32: { bool _r = _t->removeText((*reinterpret_cast< const QJSValue(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 33: { bool _r = _t->removeText((*reinterpret_cast< const QJSValue(*)>(_a[1])),(*reinterpret_cast< const QJSValue(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 34: { bool _r = _t->insertLine((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 35: { bool _r = _t->removeLine((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 36: { bool _r = _t->wrapLine((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 37: { bool _r = _t->wrapLine((*reinterpret_cast< const QJSValue(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 38: _t->joinLines((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 39: { int _r = _t->lines();
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 40: { bool _r = _t->isLineModified((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 41: { bool _r = _t->isLineSaved((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 42: { bool _r = _t->isLineTouched((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 43: { int _r = _t->findTouchedLine((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 44: { int _r = _t->length();
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 45: { int _r = _t->lineLength((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 46: _t->editBegin(); break;
        case 47: _t->editEnd(); break;
        case 48: { int _r = _t->firstColumn((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 49: { int _r = _t->lastColumn((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 50: { int _r = _t->prevNonSpaceColumn((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 51: { int _r = _t->prevNonSpaceColumn((*reinterpret_cast< const QJSValue(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 52: { int _r = _t->nextNonSpaceColumn((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 53: { int _r = _t->nextNonSpaceColumn((*reinterpret_cast< const QJSValue(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 54: { int _r = _t->prevNonEmptyLine((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 55: { int _r = _t->nextNonEmptyLine((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 56: { bool _r = _t->isInWord((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 57: { bool _r = _t->canBreakAt((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 58: { bool _r = _t->canComment((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 59: { QString _r = _t->commentMarker((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 60: { QString _r = _t->commentStart((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 61: { QString _r = _t->commentEnd((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 62: { QJSValue _r = _t->documentRange();
            if (_a[0]) *reinterpret_cast< QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 63: { QJSValue _r = _t->documentEnd();
            if (_a[0]) *reinterpret_cast< QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 64: { bool _r = _t->isValidTextPosition((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 65: { bool _r = _t->isValidTextPosition((*reinterpret_cast< const QJSValue(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 66: { int _r = _t->attribute((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 67: { int _r = _t->attribute((*reinterpret_cast< const QJSValue(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 68: { bool _r = _t->isAttribute((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 69: { bool _r = _t->isAttribute((*reinterpret_cast< const QJSValue(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 70: { QString _r = _t->attributeName((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 71: { QString _r = _t->attributeName((*reinterpret_cast< const QJSValue(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 72: { bool _r = _t->isAttributeName((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 73: { bool _r = _t->isAttributeName((*reinterpret_cast< const QJSValue(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 74: { QString _r = _t->variable((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 75: _t->setVariable((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 76: { int _r = _t->firstVirtualColumn((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 77: { int _r = _t->lastVirtualColumn((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 78: { int _r = _t->toVirtualColumn((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 79: { int _r = _t->toVirtualColumn((*reinterpret_cast< const QJSValue(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 80: { QJSValue _r = _t->toVirtualCursor((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 81: { QJSValue _r = _t->toVirtualCursor((*reinterpret_cast< const QJSValue(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 82: { int _r = _t->fromVirtualColumn((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 83: { int _r = _t->fromVirtualColumn((*reinterpret_cast< const QJSValue(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 84: { QJSValue _r = _t->fromVirtualCursor((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 85: { QJSValue _r = _t->fromVirtualCursor((*reinterpret_cast< const QJSValue(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 86: { QJSValue _r = _t->anchor((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< QChar(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 87: { QJSValue _r = _t->anchor((*reinterpret_cast< const QJSValue(*)>(_a[1])),(*reinterpret_cast< QChar(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 88: { QJSValue _r = _t->rfind((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])));
            if (_a[0]) *reinterpret_cast< QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 89: { QJSValue _r = _t->rfind((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 90: { QJSValue _r = _t->rfind((*reinterpret_cast< const QJSValue(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 91: { QJSValue _r = _t->rfind((*reinterpret_cast< const QJSValue(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 92: { int _r = _t->defStyleNum((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 93: { int _r = _t->defStyleNum((*reinterpret_cast< const QJSValue(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 94: { bool _r = _t->isCode((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 95: { bool _r = _t->isCode((*reinterpret_cast< const QJSValue(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 96: { bool _r = _t->isComment((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 97: { bool _r = _t->isComment((*reinterpret_cast< const QJSValue(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 98: { bool _r = _t->isString((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 99: { bool _r = _t->isString((*reinterpret_cast< const QJSValue(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 100: { bool _r = _t->isRegionMarker((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 101: { bool _r = _t->isRegionMarker((*reinterpret_cast< const QJSValue(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 102: { bool _r = _t->isChar((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 103: { bool _r = _t->isChar((*reinterpret_cast< const QJSValue(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 104: { bool _r = _t->isOthers((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 105: { bool _r = _t->isOthers((*reinterpret_cast< const QJSValue(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 106: { bool _r = _t->startsWith((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 107: { bool _r = _t->endsWith((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 108: _t->indent((*reinterpret_cast< const QJSValue(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
            }
            break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
            }
            break;
        case 18:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
            }
            break;
        case 22:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
            }
            break;
        case 24:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
            }
            break;
        case 28:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
            }
            break;
        case 30:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
            }
            break;
        case 32:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
            }
            break;
        case 33:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
            }
            break;
        case 37:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
            }
            break;
        case 51:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
            }
            break;
        case 53:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
            }
            break;
        case 65:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
            }
            break;
        case 67:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
            }
            break;
        case 69:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
            }
            break;
        case 71:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
            }
            break;
        case 73:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
            }
            break;
        case 79:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
            }
            break;
        case 81:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
            }
            break;
        case 83:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
            }
            break;
        case 85:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
            }
            break;
        case 87:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
            }
            break;
        case 90:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
            }
            break;
        case 91:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
            }
            break;
        case 93:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
            }
            break;
        case 95:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
            }
            break;
        case 97:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
            }
            break;
        case 99:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
            }
            break;
        case 101:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
            }
            break;
        case 103:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
            }
            break;
        case 105:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
            }
            break;
        case 108:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
            }
            break;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject KateScriptDocument::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_KateScriptDocument.data,
    qt_meta_data_KateScriptDocument,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *KateScriptDocument::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateScriptDocument::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KateScriptDocument.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KateScriptDocument::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 109)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 109;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 109)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 109;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
