/****************************************************************************
** Meta object code from reading C++ file 'ontheflycheck.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../ktexteditor-5.116.0/src/spellcheck/ontheflycheck.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ontheflycheck.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KateOnTheFlyChecker_t {
    QByteArrayData data[35];
    char stringdata0[543];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KateOnTheFlyChecker_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KateOnTheFlyChecker_t qt_meta_stringdata_KateOnTheFlyChecker = {
    {
QT_MOC_LITERAL(0, 0, 19), // "KateOnTheFlyChecker"
QT_MOC_LITERAL(1, 20, 12), // "textInserted"
QT_MOC_LITERAL(2, 33, 0), // ""
QT_MOC_LITERAL(3, 34, 22), // "KTextEditor::Document*"
QT_MOC_LITERAL(4, 57, 8), // "document"
QT_MOC_LITERAL(5, 66, 18), // "KTextEditor::Range"
QT_MOC_LITERAL(6, 85, 5), // "range"
QT_MOC_LITERAL(7, 91, 11), // "textRemoved"
QT_MOC_LITERAL(8, 103, 12), // "updateConfig"
QT_MOC_LITERAL(9, 116, 17), // "refreshSpellCheck"
QT_MOC_LITERAL(10, 134, 27), // "updateInstalledMovingRanges"
QT_MOC_LITERAL(11, 162, 25), // "KTextEditor::ViewPrivate*"
QT_MOC_LITERAL(12, 188, 4), // "view"
QT_MOC_LITERAL(13, 193, 17), // "performSpellCheck"
QT_MOC_LITERAL(14, 211, 15), // "addToDictionary"
QT_MOC_LITERAL(15, 227, 4), // "word"
QT_MOC_LITERAL(16, 232, 12), // "addToSession"
QT_MOC_LITERAL(17, 245, 11), // "misspelling"
QT_MOC_LITERAL(18, 257, 5), // "start"
QT_MOC_LITERAL(19, 263, 14), // "spellCheckDone"
QT_MOC_LITERAL(20, 278, 13), // "viewDestroyed"
QT_MOC_LITERAL(21, 292, 3), // "obj"
QT_MOC_LITERAL(22, 296, 7), // "addView"
QT_MOC_LITERAL(23, 304, 18), // "KTextEditor::View*"
QT_MOC_LITERAL(24, 323, 10), // "removeView"
QT_MOC_LITERAL(25, 334, 23), // "restartViewRefreshTimer"
QT_MOC_LITERAL(26, 358, 18), // "viewRefreshTimeout"
QT_MOC_LITERAL(27, 377, 20), // "handleModifiedRanges"
QT_MOC_LITERAL(28, 398, 18), // "handleInsertedText"
QT_MOC_LITERAL(29, 417, 17), // "handleRemovedText"
QT_MOC_LITERAL(30, 435, 23), // "handleRespellCheckBlock"
QT_MOC_LITERAL(31, 459, 3), // "end"
QT_MOC_LITERAL(32, 463, 31), // "removeRangeFromModificationList"
QT_MOC_LITERAL(33, 495, 25), // "KTextEditor::MovingRange*"
QT_MOC_LITERAL(34, 521, 21) // "clearModificationList"

    },
    "KateOnTheFlyChecker\0textInserted\0\0"
    "KTextEditor::Document*\0document\0"
    "KTextEditor::Range\0range\0textRemoved\0"
    "updateConfig\0refreshSpellCheck\0"
    "updateInstalledMovingRanges\0"
    "KTextEditor::ViewPrivate*\0view\0"
    "performSpellCheck\0addToDictionary\0"
    "word\0addToSession\0misspelling\0start\0"
    "spellCheckDone\0viewDestroyed\0obj\0"
    "addView\0KTextEditor::View*\0removeView\0"
    "restartViewRefreshTimer\0viewRefreshTimeout\0"
    "handleModifiedRanges\0handleInsertedText\0"
    "handleRemovedText\0handleRespellCheckBlock\0"
    "end\0removeRangeFromModificationList\0"
    "KTextEditor::MovingRange*\0"
    "clearModificationList"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KateOnTheFlyChecker[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      22,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    2,  124,    2, 0x0a /* Public */,
       7,    2,  129,    2, 0x0a /* Public */,
       8,    0,  134,    2, 0x0a /* Public */,
       9,    1,  135,    2, 0x0a /* Public */,
       9,    0,  138,    2, 0x2a /* Public | MethodCloned */,
      10,    1,  139,    2, 0x0a /* Public */,
      13,    0,  142,    2, 0x09 /* Protected */,
      14,    1,  143,    2, 0x09 /* Protected */,
      16,    1,  146,    2, 0x09 /* Protected */,
      17,    2,  149,    2, 0x09 /* Protected */,
      19,    0,  154,    2, 0x09 /* Protected */,
      20,    1,  155,    2, 0x09 /* Protected */,
      22,    2,  158,    2, 0x09 /* Protected */,
      24,    1,  163,    2, 0x09 /* Protected */,
      25,    1,  166,    2, 0x09 /* Protected */,
      26,    0,  169,    2, 0x09 /* Protected */,
      27,    0,  170,    2, 0x09 /* Protected */,
      28,    1,  171,    2, 0x09 /* Protected */,
      29,    1,  174,    2, 0x09 /* Protected */,
      30,    2,  177,    2, 0x09 /* Protected */,
      32,    1,  182,    2, 0x09 /* Protected */,
      34,    0,  185,    2, 0x09 /* Protected */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 5,    4,    6,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 5,    4,    6,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 5,    6,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 11,   12,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   15,
    QMetaType::Void, QMetaType::QString,   15,
    QMetaType::Void, QMetaType::QString, QMetaType::Int,   15,   18,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QObjectStar,   21,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 23,    4,   12,
    QMetaType::Void, 0x80000000 | 23,   12,
    QMetaType::Void, 0x80000000 | 11,   12,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 5,    6,
    QMetaType::Void, 0x80000000 | 5,    6,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,   18,   31,
    QMetaType::Bool, 0x80000000 | 33,    6,
    QMetaType::Void,

       0        // eod
};

void KateOnTheFlyChecker::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<KateOnTheFlyChecker *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->textInserted((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1])),(*reinterpret_cast< KTextEditor::Range(*)>(_a[2]))); break;
        case 1: _t->textRemoved((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1])),(*reinterpret_cast< KTextEditor::Range(*)>(_a[2]))); break;
        case 2: _t->updateConfig(); break;
        case 3: _t->refreshSpellCheck((*reinterpret_cast< KTextEditor::Range(*)>(_a[1]))); break;
        case 4: _t->refreshSpellCheck(); break;
        case 5: _t->updateInstalledMovingRanges((*reinterpret_cast< KTextEditor::ViewPrivate*(*)>(_a[1]))); break;
        case 6: _t->performSpellCheck(); break;
        case 7: _t->addToDictionary((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 8: _t->addToSession((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 9: _t->misspelling((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 10: _t->spellCheckDone(); break;
        case 11: _t->viewDestroyed((*reinterpret_cast< QObject*(*)>(_a[1]))); break;
        case 12: _t->addView((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1])),(*reinterpret_cast< KTextEditor::View*(*)>(_a[2]))); break;
        case 13: _t->removeView((*reinterpret_cast< KTextEditor::View*(*)>(_a[1]))); break;
        case 14: _t->restartViewRefreshTimer((*reinterpret_cast< KTextEditor::ViewPrivate*(*)>(_a[1]))); break;
        case 15: _t->viewRefreshTimeout(); break;
        case 16: _t->handleModifiedRanges(); break;
        case 17: _t->handleInsertedText((*reinterpret_cast< KTextEditor::Range(*)>(_a[1]))); break;
        case 18: _t->handleRemovedText((*reinterpret_cast< KTextEditor::Range(*)>(_a[1]))); break;
        case 19: _t->handleRespellCheckBlock((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 20: { bool _r = _t->removeRangeFromModificationList((*reinterpret_cast< KTextEditor::MovingRange*(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 21: _t->clearModificationList(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Range >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Range >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Range >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::View* >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::View* >(); break;
            }
            break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Range >(); break;
            }
            break;
        case 18:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Range >(); break;
            }
            break;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject KateOnTheFlyChecker::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_KateOnTheFlyChecker.data,
    qt_meta_data_KateOnTheFlyChecker,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *KateOnTheFlyChecker::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateOnTheFlyChecker::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KateOnTheFlyChecker.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KateOnTheFlyChecker::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 22)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 22;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 22)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 22;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
