/****************************************************************************
** Meta object code from reading C++ file 'kateviewinternal.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../ktexteditor-5.116.0/src/view/kateviewinternal.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kateviewinternal.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KateViewInternal_t {
    QByteArrayData data[41];
    char stringdata0[580];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KateViewInternal_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KateViewInternal_t qt_meta_stringdata_KateViewInternal = {
    {
QT_MOC_LITERAL(0, 0, 16), // "KateViewInternal"
QT_MOC_LITERAL(1, 17, 13), // "dropEventPass"
QT_MOC_LITERAL(2, 31, 0), // ""
QT_MOC_LITERAL(3, 32, 11), // "QDropEvent*"
QT_MOC_LITERAL(4, 44, 10), // "updateView"
QT_MOC_LITERAL(5, 55, 7), // "changed"
QT_MOC_LITERAL(6, 63, 17), // "viewLinesScrolled"
QT_MOC_LITERAL(7, 81, 16), // "slotIncFontSizes"
QT_MOC_LITERAL(8, 98, 4), // "step"
QT_MOC_LITERAL(9, 103, 16), // "slotDecFontSizes"
QT_MOC_LITERAL(10, 120, 18), // "slotResetFontSizes"
QT_MOC_LITERAL(11, 139, 11), // "paintCursor"
QT_MOC_LITERAL(12, 151, 11), // "scrollLines"
QT_MOC_LITERAL(13, 163, 4), // "line"
QT_MOC_LITERAL(14, 168, 15), // "scrollViewLines"
QT_MOC_LITERAL(15, 184, 6), // "offset"
QT_MOC_LITERAL(16, 191, 12), // "scrollAction"
QT_MOC_LITERAL(17, 204, 6), // "action"
QT_MOC_LITERAL(18, 211, 14), // "scrollNextPage"
QT_MOC_LITERAL(19, 226, 14), // "scrollPrevPage"
QT_MOC_LITERAL(20, 241, 14), // "scrollPrevLine"
QT_MOC_LITERAL(21, 256, 14), // "scrollNextLine"
QT_MOC_LITERAL(22, 271, 13), // "scrollColumns"
QT_MOC_LITERAL(23, 285, 1), // "x"
QT_MOC_LITERAL(24, 287, 20), // "viewSelectionChanged"
QT_MOC_LITERAL(25, 308, 18), // "tripleClickTimeout"
QT_MOC_LITERAL(26, 327, 27), // "slotRegionVisibilityChanged"
QT_MOC_LITERAL(27, 355, 30), // "slotRegionBeginEndAddedRemoved"
QT_MOC_LITERAL(28, 386, 12), // "doDragScroll"
QT_MOC_LITERAL(29, 399, 15), // "startDragScroll"
QT_MOC_LITERAL(30, 415, 14), // "stopDragScroll"
QT_MOC_LITERAL(31, 430, 13), // "scrollTimeout"
QT_MOC_LITERAL(32, 444, 13), // "cursorTimeout"
QT_MOC_LITERAL(33, 458, 15), // "textHintTimeout"
QT_MOC_LITERAL(34, 474, 20), // "documentTextInserted"
QT_MOC_LITERAL(35, 495, 22), // "KTextEditor::Document*"
QT_MOC_LITERAL(36, 518, 8), // "document"
QT_MOC_LITERAL(37, 527, 18), // "KTextEditor::Range"
QT_MOC_LITERAL(38, 546, 5), // "range"
QT_MOC_LITERAL(39, 552, 19), // "documentTextRemoved"
QT_MOC_LITERAL(40, 572, 7) // "oldText"

    },
    "KateViewInternal\0dropEventPass\0\0"
    "QDropEvent*\0updateView\0changed\0"
    "viewLinesScrolled\0slotIncFontSizes\0"
    "step\0slotDecFontSizes\0slotResetFontSizes\0"
    "paintCursor\0scrollLines\0line\0"
    "scrollViewLines\0offset\0scrollAction\0"
    "action\0scrollNextPage\0scrollPrevPage\0"
    "scrollPrevLine\0scrollNextLine\0"
    "scrollColumns\0x\0viewSelectionChanged\0"
    "tripleClickTimeout\0slotRegionVisibilityChanged\0"
    "slotRegionBeginEndAddedRemoved\0"
    "doDragScroll\0startDragScroll\0"
    "stopDragScroll\0scrollTimeout\0cursorTimeout\0"
    "textHintTimeout\0documentTextInserted\0"
    "KTextEditor::Document*\0document\0"
    "KTextEditor::Range\0range\0documentTextRemoved\0"
    "oldText"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KateViewInternal[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      30,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  164,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       4,    2,  167,    2, 0x08 /* Private */,
       4,    1,  172,    2, 0x28 /* Private | MethodCloned */,
       4,    0,  175,    2, 0x28 /* Private | MethodCloned */,
       7,    1,  176,    2, 0x0a /* Public */,
       7,    0,  179,    2, 0x2a /* Public | MethodCloned */,
       9,    1,  180,    2, 0x0a /* Public */,
       9,    0,  183,    2, 0x2a /* Public | MethodCloned */,
      10,    0,  184,    2, 0x0a /* Public */,
      11,    0,  185,    2, 0x0a /* Public */,
      12,    1,  186,    2, 0x08 /* Private */,
      14,    1,  189,    2, 0x08 /* Private */,
      16,    1,  192,    2, 0x08 /* Private */,
      18,    0,  195,    2, 0x08 /* Private */,
      19,    0,  196,    2, 0x08 /* Private */,
      20,    0,  197,    2, 0x08 /* Private */,
      21,    0,  198,    2, 0x08 /* Private */,
      22,    1,  199,    2, 0x08 /* Private */,
      24,    0,  202,    2, 0x08 /* Private */,
      25,    0,  203,    2, 0x08 /* Private */,
      26,    0,  204,    2, 0x08 /* Private */,
      27,    1,  205,    2, 0x08 /* Private */,
      28,    0,  208,    2, 0x08 /* Private */,
      29,    0,  209,    2, 0x08 /* Private */,
      30,    0,  210,    2, 0x08 /* Private */,
      31,    0,  211,    2, 0x08 /* Private */,
      32,    0,  212,    2, 0x08 /* Private */,
      33,    0,  213,    2, 0x08 /* Private */,
      34,    2,  214,    2, 0x08 /* Private */,
      39,    3,  219,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    2,

 // slots: parameters
    QMetaType::Void, QMetaType::Bool, QMetaType::Int,    5,    6,
    QMetaType::Void, QMetaType::Bool,    5,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QReal,    8,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QReal,    8,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   13,
    QMetaType::Void, QMetaType::Int,   15,
    QMetaType::Void, QMetaType::Int,   17,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   23,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::UInt,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 35, 0x80000000 | 37,   36,   38,
    QMetaType::Void, 0x80000000 | 35, 0x80000000 | 37, QMetaType::QString,   36,   38,   40,

       0        // eod
};

void KateViewInternal::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<KateViewInternal *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->dropEventPass((*reinterpret_cast< QDropEvent*(*)>(_a[1]))); break;
        case 1: _t->updateView((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 2: _t->updateView((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 3: _t->updateView(); break;
        case 4: _t->slotIncFontSizes((*reinterpret_cast< qreal(*)>(_a[1]))); break;
        case 5: _t->slotIncFontSizes(); break;
        case 6: _t->slotDecFontSizes((*reinterpret_cast< qreal(*)>(_a[1]))); break;
        case 7: _t->slotDecFontSizes(); break;
        case 8: _t->slotResetFontSizes(); break;
        case 9: _t->paintCursor(); break;
        case 10: _t->scrollLines((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 11: _t->scrollViewLines((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 12: _t->scrollAction((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 13: _t->scrollNextPage(); break;
        case 14: _t->scrollPrevPage(); break;
        case 15: _t->scrollPrevLine(); break;
        case 16: _t->scrollNextLine(); break;
        case 17: _t->scrollColumns((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 18: _t->viewSelectionChanged(); break;
        case 19: _t->tripleClickTimeout(); break;
        case 20: _t->slotRegionVisibilityChanged(); break;
        case 21: _t->slotRegionBeginEndAddedRemoved((*reinterpret_cast< uint(*)>(_a[1]))); break;
        case 22: _t->doDragScroll(); break;
        case 23: _t->startDragScroll(); break;
        case 24: _t->stopDragScroll(); break;
        case 25: _t->scrollTimeout(); break;
        case 26: _t->cursorTimeout(); break;
        case 27: _t->textHintTimeout(); break;
        case 28: _t->documentTextInserted((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1])),(*reinterpret_cast< KTextEditor::Range(*)>(_a[2]))); break;
        case 29: _t->documentTextRemoved((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1])),(*reinterpret_cast< KTextEditor::Range(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 28:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Range >(); break;
            }
            break;
        case 29:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Range >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (KateViewInternal::*)(QDropEvent * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KateViewInternal::dropEventPass)) {
                *result = 0;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject KateViewInternal::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_meta_stringdata_KateViewInternal.data,
    qt_meta_data_KateViewInternal,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *KateViewInternal::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateViewInternal::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KateViewInternal.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int KateViewInternal::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 30)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 30;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 30)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 30;
    }
    return _id;
}

// SIGNAL 0
void KateViewInternal::dropEventPass(QDropEvent * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
