/****************************************************************************
** Meta object code from reading C++ file 'document.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../ktexteditor-5.116.0/src/include/ktexteditor/document.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'document.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KTextEditor__Document_t {
    QByteArrayData data[33];
    char stringdata0[450];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KTextEditor__Document_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KTextEditor__Document_t qt_meta_stringdata_KTextEditor__Document = {
    {
QT_MOC_LITERAL(0, 0, 21), // "KTextEditor::Document"
QT_MOC_LITERAL(1, 22, 11), // "viewCreated"
QT_MOC_LITERAL(2, 34, 0), // ""
QT_MOC_LITERAL(3, 35, 22), // "KTextEditor::Document*"
QT_MOC_LITERAL(4, 58, 8), // "document"
QT_MOC_LITERAL(5, 67, 18), // "KTextEditor::View*"
QT_MOC_LITERAL(6, 86, 4), // "view"
QT_MOC_LITERAL(7, 91, 19), // "documentNameChanged"
QT_MOC_LITERAL(8, 111, 18), // "documentUrlChanged"
QT_MOC_LITERAL(9, 130, 15), // "modifiedChanged"
QT_MOC_LITERAL(10, 146, 16), // "readWriteChanged"
QT_MOC_LITERAL(11, 163, 23), // "documentSavedOrUploaded"
QT_MOC_LITERAL(12, 187, 6), // "saveAs"
QT_MOC_LITERAL(13, 194, 12), // "aboutToClose"
QT_MOC_LITERAL(14, 207, 13), // "aboutToReload"
QT_MOC_LITERAL(15, 221, 8), // "reloaded"
QT_MOC_LITERAL(16, 230, 11), // "aboutToSave"
QT_MOC_LITERAL(17, 242, 14), // "editingStarted"
QT_MOC_LITERAL(18, 257, 15), // "editingFinished"
QT_MOC_LITERAL(19, 273, 11), // "lineWrapped"
QT_MOC_LITERAL(20, 285, 19), // "KTextEditor::Cursor"
QT_MOC_LITERAL(21, 305, 8), // "position"
QT_MOC_LITERAL(22, 314, 13), // "lineUnwrapped"
QT_MOC_LITERAL(23, 328, 4), // "line"
QT_MOC_LITERAL(24, 333, 12), // "textInserted"
QT_MOC_LITERAL(25, 346, 4), // "text"
QT_MOC_LITERAL(26, 351, 11), // "textRemoved"
QT_MOC_LITERAL(27, 363, 18), // "KTextEditor::Range"
QT_MOC_LITERAL(28, 382, 5), // "range"
QT_MOC_LITERAL(29, 388, 11), // "textChanged"
QT_MOC_LITERAL(30, 400, 11), // "modeChanged"
QT_MOC_LITERAL(31, 412, 23), // "highlightingModeChanged"
QT_MOC_LITERAL(32, 436, 13) // "configChanged"

    },
    "KTextEditor::Document\0viewCreated\0\0"
    "KTextEditor::Document*\0document\0"
    "KTextEditor::View*\0view\0documentNameChanged\0"
    "documentUrlChanged\0modifiedChanged\0"
    "readWriteChanged\0documentSavedOrUploaded\0"
    "saveAs\0aboutToClose\0aboutToReload\0"
    "reloaded\0aboutToSave\0editingStarted\0"
    "editingFinished\0lineWrapped\0"
    "KTextEditor::Cursor\0position\0lineUnwrapped\0"
    "line\0textInserted\0text\0textRemoved\0"
    "KTextEditor::Range\0range\0textChanged\0"
    "modeChanged\0highlightingModeChanged\0"
    "configChanged"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KTextEditor__Document[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      20,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      20,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,  114,    2, 0x06 /* Public */,
       7,    1,  119,    2, 0x06 /* Public */,
       8,    1,  122,    2, 0x06 /* Public */,
       9,    1,  125,    2, 0x06 /* Public */,
      10,    1,  128,    2, 0x06 /* Public */,
      11,    2,  131,    2, 0x06 /* Public */,
      13,    1,  136,    2, 0x06 /* Public */,
      14,    1,  139,    2, 0x06 /* Public */,
      15,    1,  142,    2, 0x06 /* Public */,
      16,    1,  145,    2, 0x06 /* Public */,
      17,    1,  148,    2, 0x06 /* Public */,
      18,    1,  151,    2, 0x06 /* Public */,
      19,    2,  154,    2, 0x06 /* Public */,
      22,    2,  159,    2, 0x06 /* Public */,
      24,    3,  164,    2, 0x06 /* Public */,
      26,    3,  171,    2, 0x06 /* Public */,
      29,    1,  178,    2, 0x06 /* Public */,
      30,    1,  181,    2, 0x06 /* Public */,
      31,    1,  184,    2, 0x06 /* Public */,
      32,    1,  187,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 5,    4,    6,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3, QMetaType::Bool,    4,   12,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 20,    4,   21,
    QMetaType::Void, 0x80000000 | 3, QMetaType::Int,    4,   23,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 20, QMetaType::QString,    4,   21,   25,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 27, QMetaType::QString,    4,   28,   25,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,

       0        // eod
};

void KTextEditor::Document::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<Document *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->viewCreated((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1])),(*reinterpret_cast< KTextEditor::View*(*)>(_a[2]))); break;
        case 1: _t->documentNameChanged((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1]))); break;
        case 2: _t->documentUrlChanged((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1]))); break;
        case 3: _t->modifiedChanged((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1]))); break;
        case 4: _t->readWriteChanged((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1]))); break;
        case 5: _t->documentSavedOrUploaded((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 6: _t->aboutToClose((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1]))); break;
        case 7: _t->aboutToReload((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1]))); break;
        case 8: _t->reloaded((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1]))); break;
        case 9: _t->aboutToSave((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1]))); break;
        case 10: _t->editingStarted((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1]))); break;
        case 11: _t->editingFinished((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1]))); break;
        case 12: _t->lineWrapped((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1])),(*reinterpret_cast< const KTextEditor::Cursor(*)>(_a[2]))); break;
        case 13: _t->lineUnwrapped((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 14: _t->textInserted((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1])),(*reinterpret_cast< const KTextEditor::Cursor(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 15: _t->textRemoved((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1])),(*reinterpret_cast< const KTextEditor::Range(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 16: _t->textChanged((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1]))); break;
        case 17: _t->modeChanged((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1]))); break;
        case 18: _t->highlightingModeChanged((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1]))); break;
        case 19: _t->configChanged((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Cursor >(); break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Cursor >(); break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            }
            break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Range >(); break;
            }
            break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            }
            break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            }
            break;
        case 18:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            }
            break;
        case 19:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (Document::*)(KTextEditor::Document * , KTextEditor::View * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Document::viewCreated)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (Document::*)(KTextEditor::Document * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Document::documentNameChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (Document::*)(KTextEditor::Document * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Document::documentUrlChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (Document::*)(KTextEditor::Document * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Document::modifiedChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (Document::*)(KTextEditor::Document * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Document::readWriteChanged)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (Document::*)(KTextEditor::Document * , bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Document::documentSavedOrUploaded)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (Document::*)(KTextEditor::Document * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Document::aboutToClose)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (Document::*)(KTextEditor::Document * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Document::aboutToReload)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (Document::*)(KTextEditor::Document * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Document::reloaded)) {
                *result = 8;
                return;
            }
        }
        {
            using _t = void (Document::*)(KTextEditor::Document * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Document::aboutToSave)) {
                *result = 9;
                return;
            }
        }
        {
            using _t = void (Document::*)(KTextEditor::Document * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Document::editingStarted)) {
                *result = 10;
                return;
            }
        }
        {
            using _t = void (Document::*)(KTextEditor::Document * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Document::editingFinished)) {
                *result = 11;
                return;
            }
        }
        {
            using _t = void (Document::*)(KTextEditor::Document * , const KTextEditor::Cursor & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Document::lineWrapped)) {
                *result = 12;
                return;
            }
        }
        {
            using _t = void (Document::*)(KTextEditor::Document * , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Document::lineUnwrapped)) {
                *result = 13;
                return;
            }
        }
        {
            using _t = void (Document::*)(KTextEditor::Document * , const KTextEditor::Cursor & , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Document::textInserted)) {
                *result = 14;
                return;
            }
        }
        {
            using _t = void (Document::*)(KTextEditor::Document * , const KTextEditor::Range & , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Document::textRemoved)) {
                *result = 15;
                return;
            }
        }
        {
            using _t = void (Document::*)(KTextEditor::Document * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Document::textChanged)) {
                *result = 16;
                return;
            }
        }
        {
            using _t = void (Document::*)(KTextEditor::Document * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Document::modeChanged)) {
                *result = 17;
                return;
            }
        }
        {
            using _t = void (Document::*)(KTextEditor::Document * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Document::highlightingModeChanged)) {
                *result = 18;
                return;
            }
        }
        {
            using _t = void (Document::*)(KTextEditor::Document * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Document::configChanged)) {
                *result = 19;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject KTextEditor::Document::staticMetaObject = { {
    QMetaObject::SuperData::link<KParts::ReadWritePart::staticMetaObject>(),
    qt_meta_stringdata_KTextEditor__Document.data,
    qt_meta_data_KTextEditor__Document,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *KTextEditor::Document::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KTextEditor::Document::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KTextEditor__Document.stringdata0))
        return static_cast<void*>(this);
    return KParts::ReadWritePart::qt_metacast(_clname);
}

int KTextEditor::Document::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KParts::ReadWritePart::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    return _id;
}

// SIGNAL 0
void KTextEditor::Document::viewCreated(KTextEditor::Document * _t1, KTextEditor::View * _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KTextEditor::Document::documentNameChanged(KTextEditor::Document * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void KTextEditor::Document::documentUrlChanged(KTextEditor::Document * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void KTextEditor::Document::modifiedChanged(KTextEditor::Document * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void KTextEditor::Document::readWriteChanged(KTextEditor::Document * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void KTextEditor::Document::documentSavedOrUploaded(KTextEditor::Document * _t1, bool _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void KTextEditor::Document::aboutToClose(KTextEditor::Document * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void KTextEditor::Document::aboutToReload(KTextEditor::Document * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void KTextEditor::Document::reloaded(KTextEditor::Document * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}

// SIGNAL 9
void KTextEditor::Document::aboutToSave(KTextEditor::Document * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 9, _a);
}

// SIGNAL 10
void KTextEditor::Document::editingStarted(KTextEditor::Document * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 10, _a);
}

// SIGNAL 11
void KTextEditor::Document::editingFinished(KTextEditor::Document * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 11, _a);
}

// SIGNAL 12
void KTextEditor::Document::lineWrapped(KTextEditor::Document * _t1, const KTextEditor::Cursor & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 12, _a);
}

// SIGNAL 13
void KTextEditor::Document::lineUnwrapped(KTextEditor::Document * _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 13, _a);
}

// SIGNAL 14
void KTextEditor::Document::textInserted(KTextEditor::Document * _t1, const KTextEditor::Cursor & _t2, const QString & _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))) };
    QMetaObject::activate(this, &staticMetaObject, 14, _a);
}

// SIGNAL 15
void KTextEditor::Document::textRemoved(KTextEditor::Document * _t1, const KTextEditor::Range & _t2, const QString & _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))) };
    QMetaObject::activate(this, &staticMetaObject, 15, _a);
}

// SIGNAL 16
void KTextEditor::Document::textChanged(KTextEditor::Document * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 16, _a);
}

// SIGNAL 17
void KTextEditor::Document::modeChanged(KTextEditor::Document * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 17, _a);
}

// SIGNAL 18
void KTextEditor::Document::highlightingModeChanged(KTextEditor::Document * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 18, _a);
}

// SIGNAL 19
void KTextEditor::Document::configChanged(KTextEditor::Document * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 19, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
