#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'statusbarconfigwidget.ui'
**
** Created by: Qt User Interface Compiler version 5.15.17
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_STATUSBARCONFIGWIDGET_H
#define UI_STATUSBARCONFIGWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_StatusbarConfigWidget
{
public:
    QVBoxLayout *verticalLayout;
    QFormLayout *formLayout;
    QCheckBox *cbShowHighlightingMode;
    QCheckBox *cbShowInputMode;
    QCheckBox *cbShowActiveDictionary;
    QCheckBox *cbShowTabSetting;
    QCheckBox *cbShowLineColumn;
    QCheckBox *cbShowEncoding;
    QCheckBox *cbShowEOL;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *StatusbarConfigWidget)
    {
        if (StatusbarConfigWidget->objectName().isEmpty())
            StatusbarConfigWidget->setObjectName(QString::fromUtf8("StatusbarConfigWidget"));
        StatusbarConfigWidget->resize(426, 339);
        verticalLayout = new QVBoxLayout(StatusbarConfigWidget);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        formLayout = new QFormLayout();
        formLayout->setObjectName(QString::fromUtf8("formLayout"));
        cbShowHighlightingMode = new QCheckBox(StatusbarConfigWidget);
        cbShowHighlightingMode->setObjectName(QString::fromUtf8("cbShowHighlightingMode"));

        formLayout->setWidget(0, QFormLayout::FieldRole, cbShowHighlightingMode);

        cbShowInputMode = new QCheckBox(StatusbarConfigWidget);
        cbShowInputMode->setObjectName(QString::fromUtf8("cbShowInputMode"));

        formLayout->setWidget(1, QFormLayout::FieldRole, cbShowInputMode);

        cbShowActiveDictionary = new QCheckBox(StatusbarConfigWidget);
        cbShowActiveDictionary->setObjectName(QString::fromUtf8("cbShowActiveDictionary"));

        formLayout->setWidget(2, QFormLayout::FieldRole, cbShowActiveDictionary);

        cbShowTabSetting = new QCheckBox(StatusbarConfigWidget);
        cbShowTabSetting->setObjectName(QString::fromUtf8("cbShowTabSetting"));

        formLayout->setWidget(3, QFormLayout::FieldRole, cbShowTabSetting);

        cbShowLineColumn = new QCheckBox(StatusbarConfigWidget);
        cbShowLineColumn->setObjectName(QString::fromUtf8("cbShowLineColumn"));

        formLayout->setWidget(4, QFormLayout::FieldRole, cbShowLineColumn);

        cbShowEncoding = new QCheckBox(StatusbarConfigWidget);
        cbShowEncoding->setObjectName(QString::fromUtf8("cbShowEncoding"));

        formLayout->setWidget(5, QFormLayout::FieldRole, cbShowEncoding);

        cbShowEOL = new QCheckBox(StatusbarConfigWidget);
        cbShowEOL->setObjectName(QString::fromUtf8("cbShowEOL"));

        formLayout->setWidget(6, QFormLayout::FieldRole, cbShowEOL);


        verticalLayout->addLayout(formLayout);

        verticalSpacer = new QSpacerItem(20, 31, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(StatusbarConfigWidget);

        QMetaObject::connectSlotsByName(StatusbarConfigWidget);
    } // setupUi

    void retranslateUi(QWidget *StatusbarConfigWidget)
    {
        cbShowHighlightingMode->setText(tr2i18n("Show highlighting mode", nullptr));
        cbShowInputMode->setText(tr2i18n("Show input mode", nullptr));
        cbShowActiveDictionary->setText(tr2i18n("Show active dictionary", nullptr));
        cbShowTabSetting->setText(tr2i18n("Show tab setting", nullptr));
        cbShowLineColumn->setText(tr2i18n("Show line column", nullptr));
        cbShowEncoding->setText(tr2i18n("Show File Encoding", nullptr));
        cbShowEOL->setText(tr2i18n("Show Line Ending Type", nullptr));
        (void)StatusbarConfigWidget;
    } // retranslateUi

};

namespace Ui {
    class StatusbarConfigWidget: public Ui_StatusbarConfigWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // STATUSBARCONFIGWIDGET_H

