/****************************************************************************
** Meta object code from reading C++ file 'katelayoutcache.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../ktexteditor-5.116.0/src/render/katelayoutcache.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'katelayoutcache.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KateLayoutCache_t {
    QByteArrayData data[12];
    char stringdata0[123];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KateLayoutCache_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KateLayoutCache_t qt_meta_stringdata_KateLayoutCache = {
    {
QT_MOC_LITERAL(0, 0, 15), // "KateLayoutCache"
QT_MOC_LITERAL(1, 16, 8), // "wrapLine"
QT_MOC_LITERAL(2, 25, 0), // ""
QT_MOC_LITERAL(3, 26, 19), // "KTextEditor::Cursor"
QT_MOC_LITERAL(4, 46, 8), // "position"
QT_MOC_LITERAL(5, 55, 10), // "unwrapLine"
QT_MOC_LITERAL(6, 66, 4), // "line"
QT_MOC_LITERAL(7, 71, 10), // "insertText"
QT_MOC_LITERAL(8, 82, 4), // "text"
QT_MOC_LITERAL(9, 87, 10), // "removeText"
QT_MOC_LITERAL(10, 98, 18), // "KTextEditor::Range"
QT_MOC_LITERAL(11, 117, 5) // "range"

    },
    "KateLayoutCache\0wrapLine\0\0KTextEditor::Cursor\0"
    "position\0unwrapLine\0line\0insertText\0"
    "text\0removeText\0KTextEditor::Range\0"
    "range"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KateLayoutCache[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       4,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   34,    2, 0x08 /* Private */,
       5,    1,   37,    2, 0x08 /* Private */,
       7,    2,   40,    2, 0x08 /* Private */,
       9,    1,   45,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, QMetaType::Int,    6,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    4,    8,
    QMetaType::Void, 0x80000000 | 10,   11,

       0        // eod
};

void KateLayoutCache::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<KateLayoutCache *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->wrapLine((*reinterpret_cast< const KTextEditor::Cursor(*)>(_a[1]))); break;
        case 1: _t->unwrapLine((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->insertText((*reinterpret_cast< const KTextEditor::Cursor(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 3: _t->removeText((*reinterpret_cast< KTextEditor::Range(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Cursor >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Cursor >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Range >(); break;
            }
            break;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject KateLayoutCache::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_KateLayoutCache.data,
    qt_meta_data_KateLayoutCache,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *KateLayoutCache::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateLayoutCache::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KateLayoutCache.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KateLayoutCache::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
