#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'indentationconfigwidget.ui'
**
** Created by: Qt User Interface Compiler version 5.15.17
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_INDENTATIONCONFIGWIDGET_H
#define UI_INDENTATIONCONFIGWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "kpluralhandlingspinbox.h"

QT_BEGIN_NAMESPACE

class Ui_IndentationConfigWidget
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *hboxLayout;
    QLabel *lblMode;
    QComboBox *cmbMode;
    QSpacerItem *spacerItem;
    QGroupBox *gbIndentationMode;
    QGridLayout *gridLayout;
    KPluralHandlingSpinBox *sbIndentWidth;
    QRadioButton *rbIndentWithSpaces;
    QLabel *lblIndentWidth;
    QLabel *lblTabWidth;
    QSpacerItem *horizontalSpacer;
    KPluralHandlingSpinBox *sbTabWidth;
    QRadioButton *rbIndentWithTabs;
    QRadioButton *rbIndentMixed;
    QCheckBox *chkAutoDetectIndent;
    QGroupBox *gbProperties;
    QVBoxLayout *vboxLayout;
    QCheckBox *chkKeepExtraSpaces;
    QCheckBox *chkIndentPaste;
    QGroupBox *gbKeys;
    QVBoxLayout *vboxLayout1;
    QCheckBox *chkBackspaceUnindents;
    QLabel *label;
    QHBoxLayout *hboxLayout1;
    QSpacerItem *spacerItem1;
    QVBoxLayout *vboxLayout2;
    QRadioButton *rbTabAdvances;
    QRadioButton *rbTabIndents;
    QRadioButton *rbTabSmart;
    QSpacerItem *spacerItem2;

    void setupUi(QWidget *IndentationConfigWidget)
    {
        if (IndentationConfigWidget->objectName().isEmpty())
            IndentationConfigWidget->setObjectName(QString::fromUtf8("IndentationConfigWidget"));
        IndentationConfigWidget->resize(450, 530);
        verticalLayout = new QVBoxLayout(IndentationConfigWidget);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName(QString::fromUtf8("hboxLayout"));
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        lblMode = new QLabel(IndentationConfigWidget);
        lblMode->setObjectName(QString::fromUtf8("lblMode"));

        hboxLayout->addWidget(lblMode);

        cmbMode = new QComboBox(IndentationConfigWidget);
        cmbMode->setObjectName(QString::fromUtf8("cmbMode"));

        hboxLayout->addWidget(cmbMode);

        spacerItem = new QSpacerItem(1, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout->addItem(spacerItem);


        verticalLayout->addLayout(hboxLayout);

        gbIndentationMode = new QGroupBox(IndentationConfigWidget);
        gbIndentationMode->setObjectName(QString::fromUtf8("gbIndentationMode"));
        gridLayout = new QGridLayout(gbIndentationMode);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        sbIndentWidth = new KPluralHandlingSpinBox(gbIndentationMode);
        sbIndentWidth->setObjectName(QString::fromUtf8("sbIndentWidth"));
        sbIndentWidth->setMinimum(1);
        sbIndentWidth->setMaximum(200);
        sbIndentWidth->setValue(4);

        gridLayout->addWidget(sbIndentWidth, 2, 3, 1, 1);

        rbIndentWithSpaces = new QRadioButton(gbIndentationMode);
        rbIndentWithSpaces->setObjectName(QString::fromUtf8("rbIndentWithSpaces"));

        gridLayout->addWidget(rbIndentWithSpaces, 2, 0, 1, 1);

        lblIndentWidth = new QLabel(gbIndentationMode);
        lblIndentWidth->setObjectName(QString::fromUtf8("lblIndentWidth"));

        gridLayout->addWidget(lblIndentWidth, 2, 2, 1, 1);

        lblTabWidth = new QLabel(gbIndentationMode);
        lblTabWidth->setObjectName(QString::fromUtf8("lblTabWidth"));
        lblTabWidth->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(lblTabWidth, 1, 2, 1, 1);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer, 2, 1, 1, 1);

        sbTabWidth = new KPluralHandlingSpinBox(gbIndentationMode);
        sbTabWidth->setObjectName(QString::fromUtf8("sbTabWidth"));
        sbTabWidth->setMinimum(1);
        sbTabWidth->setMaximum(200);
        sbTabWidth->setValue(8);

        gridLayout->addWidget(sbTabWidth, 1, 3, 1, 1);

        rbIndentWithTabs = new QRadioButton(gbIndentationMode);
        rbIndentWithTabs->setObjectName(QString::fromUtf8("rbIndentWithTabs"));

        gridLayout->addWidget(rbIndentWithTabs, 1, 0, 1, 1);

        rbIndentMixed = new QRadioButton(gbIndentationMode);
        rbIndentMixed->setObjectName(QString::fromUtf8("rbIndentMixed"));

        gridLayout->addWidget(rbIndentMixed, 3, 0, 1, 1);

        chkAutoDetectIndent = new QCheckBox(gbIndentationMode);
        chkAutoDetectIndent->setObjectName(QString::fromUtf8("chkAutoDetectIndent"));

        gridLayout->addWidget(chkAutoDetectIndent, 0, 0, 1, 1);


        verticalLayout->addWidget(gbIndentationMode);

        gbProperties = new QGroupBox(IndentationConfigWidget);
        gbProperties->setObjectName(QString::fromUtf8("gbProperties"));
        vboxLayout = new QVBoxLayout(gbProperties);
        vboxLayout->setObjectName(QString::fromUtf8("vboxLayout"));
        chkKeepExtraSpaces = new QCheckBox(gbProperties);
        chkKeepExtraSpaces->setObjectName(QString::fromUtf8("chkKeepExtraSpaces"));

        vboxLayout->addWidget(chkKeepExtraSpaces);

        chkIndentPaste = new QCheckBox(gbProperties);
        chkIndentPaste->setObjectName(QString::fromUtf8("chkIndentPaste"));

        vboxLayout->addWidget(chkIndentPaste);


        verticalLayout->addWidget(gbProperties);

        gbKeys = new QGroupBox(IndentationConfigWidget);
        gbKeys->setObjectName(QString::fromUtf8("gbKeys"));
        vboxLayout1 = new QVBoxLayout(gbKeys);
        vboxLayout1->setObjectName(QString::fromUtf8("vboxLayout1"));
        chkBackspaceUnindents = new QCheckBox(gbKeys);
        chkBackspaceUnindents->setObjectName(QString::fromUtf8("chkBackspaceUnindents"));

        vboxLayout1->addWidget(chkBackspaceUnindents);

        label = new QLabel(gbKeys);
        label->setObjectName(QString::fromUtf8("label"));

        vboxLayout1->addWidget(label);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setObjectName(QString::fromUtf8("hboxLayout1"));
        hboxLayout1->setContentsMargins(0, 0, 0, 0);
        spacerItem1 = new QSpacerItem(20, 0, QSizePolicy::Fixed, QSizePolicy::Minimum);

        hboxLayout1->addItem(spacerItem1);

        vboxLayout2 = new QVBoxLayout();
        vboxLayout2->setObjectName(QString::fromUtf8("vboxLayout2"));
        vboxLayout2->setContentsMargins(0, 0, 0, 0);
        rbTabAdvances = new QRadioButton(gbKeys);
        rbTabAdvances->setObjectName(QString::fromUtf8("rbTabAdvances"));

        vboxLayout2->addWidget(rbTabAdvances);

        rbTabIndents = new QRadioButton(gbKeys);
        rbTabIndents->setObjectName(QString::fromUtf8("rbTabIndents"));

        vboxLayout2->addWidget(rbTabIndents);

        rbTabSmart = new QRadioButton(gbKeys);
        rbTabSmart->setObjectName(QString::fromUtf8("rbTabSmart"));

        vboxLayout2->addWidget(rbTabSmart);


        hboxLayout1->addLayout(vboxLayout2);


        vboxLayout1->addLayout(hboxLayout1);


        verticalLayout->addWidget(gbKeys);

        spacerItem2 = new QSpacerItem(0, 1, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(spacerItem2);

#if QT_CONFIG(shortcut)
        lblMode->setBuddy(cmbMode);
        lblIndentWidth->setBuddy(sbIndentWidth);
        lblTabWidth->setBuddy(sbTabWidth);
#endif // QT_CONFIG(shortcut)

        retranslateUi(IndentationConfigWidget);

        QMetaObject::connectSlotsByName(IndentationConfigWidget);
    } // setupUi

    void retranslateUi(QWidget *IndentationConfigWidget)
    {
        lblMode->setText(tr2i18n("Default indentation mode:", nullptr));
#if QT_CONFIG(whatsthis)
        cmbMode->setWhatsThis(tr2i18n("This is a list of available indentation modes. The specified indentation mode will be used for all new documents. Be aware that it is also possible to set the indentation mode with document variables, modes or a .kateconfig file.", nullptr));
#endif // QT_CONFIG(whatsthis)
        gbIndentationMode->setTitle(tr2i18n("Indent using", nullptr));
#if QT_CONFIG(whatsthis)
        sbIndentWidth->setWhatsThis(tr2i18n("The indentation width is the number of spaces which is used to indent a line. If the option <b>Insert spaces instead of tabulators</b> in the section <b>Editing</b> is disabled, a <b>Tab</b> character is inserted if the indentation is divisible by the tab width.", nullptr));
#endif // QT_CONFIG(whatsthis)
        rbIndentWithSpaces->setText(tr2i18n("&Spaces", nullptr));
        lblIndentWidth->setText(tr2i18n("&Indentation width:", nullptr));
        lblTabWidth->setText(tr2i18n("Tab wi&dth:", nullptr));
        rbIndentWithTabs->setText(tr2i18n("&Tabulators", nullptr));
        rbIndentMixed->setText(tr2i18n("Tabulators &and Spaces", nullptr));
        chkAutoDetectIndent->setText(tr2i18n("Automatically detect file indentation", nullptr));
        gbProperties->setTitle(tr2i18n("Indentation Properties", nullptr));
#if QT_CONFIG(whatsthis)
        chkKeepExtraSpaces->setWhatsThis(tr2i18n("If this option is disabled, changing the indentation level aligns a line to a multiple of the width specified in <b>Indentation width</b>.", nullptr));
#endif // QT_CONFIG(whatsthis)
        chkKeepExtraSpaces->setText(tr2i18n("&Keep extra spaces", nullptr));
#if QT_CONFIG(whatsthis)
        chkIndentPaste->setWhatsThis(tr2i18n("If this option is selected, pasted code from the clipboard is indented. Triggering the <b>undo</b>-action removes the indentation.", nullptr));
#endif // QT_CONFIG(whatsthis)
        chkIndentPaste->setText(tr2i18n("Adjust indentation of code &pasted from the clipboard", nullptr));
        gbKeys->setTitle(tr2i18n("Indentation Actions", nullptr));
#if QT_CONFIG(whatsthis)
        chkBackspaceUnindents->setWhatsThis(tr2i18n("If this option is selected, the <b>Backspace</b> key decreases the indentation level if the cursor is located in the leading blank space of a line.", nullptr));
#endif // QT_CONFIG(whatsthis)
        chkBackspaceUnindents->setText(tr2i18n("&Backspace key in leading blank space unindents", nullptr));
        label->setText(tr2i18n("<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body>\n"
"<p>Tab key action (if no selection exists) <a href=\"If you want <b>Tab</b> to align the current line in the current code block like in Emacs, make <b>Tab</b> a shortcut to the action <b>Format Indentation</b>.\"><span>More ...</span></a></p></body></html>", nullptr));
#if QT_CONFIG(whatsthis)
        rbTabAdvances->setWhatsThis(tr2i18n("If this option is selected, the <b>Tab</b> key always inserts white space so that the next tab position is reached. If the option <b>Insert spaces instead of tabulators</b> in the section <b>Editing</b> is enabled, spaces are inserted; otherwise, a single tabulator is inserted.", nullptr));
#endif // QT_CONFIG(whatsthis)
        rbTabAdvances->setText(tr2i18n("Always advance to the &next tab position", nullptr));
#if QT_CONFIG(whatsthis)
        rbTabIndents->setWhatsThis(tr2i18n("If this option is selected, the <b>Tab</b> key always indents the current line by the number of character positions specified in <b>Indentation width</b>.", nullptr));
#endif // QT_CONFIG(whatsthis)
        rbTabIndents->setText(tr2i18n("Always increase indentation &level", nullptr));
#if QT_CONFIG(whatsthis)
        rbTabSmart->setWhatsThis(tr2i18n("If this option is selected, the <b>Tab</b> key either indents the current line or advances to the next tab position.<p> If the insertion point is at or before the first non-space character in the line, or if there is a selection, the current line is indented by the number of character positions specified in <b>Indentation width</b>.<p> If the insertion point is located after the first non-space character in the line and there is no selection, white space is inserted so that the next tab position is reached: if the option <b>Insert spaces instead of tabulators</b> in the section <b>Editing</b> is enabled, spaces are inserted; otherwise, a single tabulator is inserted.", nullptr));
#endif // QT_CONFIG(whatsthis)
        rbTabSmart->setText(tr2i18n("Increase indentation level if in l&eading blank space", nullptr));
        (void)IndentationConfigWidget;
    } // retranslateUi

};

namespace Ui {
    class IndentationConfigWidget: public Ui_IndentationConfigWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // INDENTATIONCONFIGWIDGET_H

