/****************************************************************************
** Meta object code from reading C++ file 'application.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../ktexteditor-5.116.0/src/include/ktexteditor/application.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'application.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KTextEditor__Application_t {
    QByteArrayData data[18];
    char stringdata0[293];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KTextEditor__Application_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KTextEditor__Application_t qt_meta_stringdata_KTextEditor__Application = {
    {
QT_MOC_LITERAL(0, 0, 24), // "KTextEditor::Application"
QT_MOC_LITERAL(1, 25, 15), // "documentCreated"
QT_MOC_LITERAL(2, 41, 0), // ""
QT_MOC_LITERAL(3, 42, 22), // "KTextEditor::Document*"
QT_MOC_LITERAL(4, 65, 8), // "document"
QT_MOC_LITERAL(5, 74, 21), // "documentWillBeDeleted"
QT_MOC_LITERAL(6, 96, 15), // "documentDeleted"
QT_MOC_LITERAL(7, 112, 22), // "aboutToCreateDocuments"
QT_MOC_LITERAL(8, 135, 16), // "documentsCreated"
QT_MOC_LITERAL(9, 152, 29), // "QList<KTextEditor::Document*>"
QT_MOC_LITERAL(10, 182, 9), // "documents"
QT_MOC_LITERAL(11, 192, 22), // "aboutToDeleteDocuments"
QT_MOC_LITERAL(12, 215, 16), // "documentsDeleted"
QT_MOC_LITERAL(13, 232, 13), // "pluginCreated"
QT_MOC_LITERAL(14, 246, 4), // "name"
QT_MOC_LITERAL(15, 251, 20), // "KTextEditor::Plugin*"
QT_MOC_LITERAL(16, 272, 6), // "plugin"
QT_MOC_LITERAL(17, 279, 13) // "pluginDeleted"

    },
    "KTextEditor::Application\0documentCreated\0"
    "\0KTextEditor::Document*\0document\0"
    "documentWillBeDeleted\0documentDeleted\0"
    "aboutToCreateDocuments\0documentsCreated\0"
    "QList<KTextEditor::Document*>\0documents\0"
    "aboutToDeleteDocuments\0documentsDeleted\0"
    "pluginCreated\0name\0KTextEditor::Plugin*\0"
    "plugin\0pluginDeleted"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KTextEditor__Application[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       9,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       9,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   59,    2, 0x06 /* Public */,
       5,    1,   62,    2, 0x06 /* Public */,
       6,    1,   65,    2, 0x06 /* Public */,
       7,    0,   68,    2, 0x06 /* Public */,
       8,    1,   69,    2, 0x06 /* Public */,
      11,    1,   72,    2, 0x06 /* Public */,
      12,    1,   75,    2, 0x06 /* Public */,
      13,    2,   78,    2, 0x06 /* Public */,
      17,    2,   83,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 9,   10,
    QMetaType::Void, 0x80000000 | 9,    2,
    QMetaType::Void, 0x80000000 | 9,   10,
    QMetaType::Void, QMetaType::QString, 0x80000000 | 15,   14,   16,
    QMetaType::Void, QMetaType::QString, 0x80000000 | 15,   14,   16,

       0        // eod
};

void KTextEditor::Application::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<Application *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->documentCreated((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1]))); break;
        case 1: _t->documentWillBeDeleted((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1]))); break;
        case 2: _t->documentDeleted((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1]))); break;
        case 3: _t->aboutToCreateDocuments(); break;
        case 4: _t->documentsCreated((*reinterpret_cast< const QList<KTextEditor::Document*>(*)>(_a[1]))); break;
        case 5: _t->aboutToDeleteDocuments((*reinterpret_cast< const QList<KTextEditor::Document*>(*)>(_a[1]))); break;
        case 6: _t->documentsDeleted((*reinterpret_cast< const QList<KTextEditor::Document*>(*)>(_a[1]))); break;
        case 7: _t->pluginCreated((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< KTextEditor::Plugin*(*)>(_a[2]))); break;
        case 8: _t->pluginDeleted((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< KTextEditor::Plugin*(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (Application::*)(KTextEditor::Document * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Application::documentCreated)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (Application::*)(KTextEditor::Document * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Application::documentWillBeDeleted)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (Application::*)(KTextEditor::Document * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Application::documentDeleted)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (Application::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Application::aboutToCreateDocuments)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (Application::*)(const QList<KTextEditor::Document*> & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Application::documentsCreated)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (Application::*)(const QList<KTextEditor::Document*> & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Application::aboutToDeleteDocuments)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (Application::*)(const QList<KTextEditor::Document*> & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Application::documentsDeleted)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (Application::*)(const QString & , KTextEditor::Plugin * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Application::pluginCreated)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (Application::*)(const QString & , KTextEditor::Plugin * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Application::pluginDeleted)) {
                *result = 8;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject KTextEditor::Application::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_KTextEditor__Application.data,
    qt_meta_data_KTextEditor__Application,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *KTextEditor::Application::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KTextEditor::Application::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KTextEditor__Application.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KTextEditor::Application::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void KTextEditor::Application::documentCreated(KTextEditor::Document * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KTextEditor::Application::documentWillBeDeleted(KTextEditor::Document * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void KTextEditor::Application::documentDeleted(KTextEditor::Document * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void KTextEditor::Application::aboutToCreateDocuments()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KTextEditor::Application::documentsCreated(const QList<KTextEditor::Document*> & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void KTextEditor::Application::aboutToDeleteDocuments(const QList<KTextEditor::Document*> & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void KTextEditor::Application::documentsDeleted(const QList<KTextEditor::Document*> & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void KTextEditor::Application::pluginCreated(const QString & _t1, KTextEditor::Plugin * _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void KTextEditor::Application::pluginDeleted(const QString & _t1, KTextEditor::Plugin * _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
