/****************************************************************************
** Meta object code from reading C++ file 'katecompletionmodel.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../ktexteditor-5.116.0/src/completion/katecompletionmodel.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'katecompletionmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KateCompletionModel_t {
    QByteArrayData data[15];
    char stringdata0[189];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KateCompletionModel_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KateCompletionModel_t qt_meta_stringdata_KateCompletionModel = {
    {
QT_MOC_LITERAL(0, 0, 19), // "KateCompletionModel"
QT_MOC_LITERAL(1, 20, 11), // "expandIndex"
QT_MOC_LITERAL(2, 32, 0), // ""
QT_MOC_LITERAL(3, 33, 11), // "QModelIndex"
QT_MOC_LITERAL(4, 45, 5), // "index"
QT_MOC_LITERAL(5, 51, 20), // "argumentHintsChanged"
QT_MOC_LITERAL(6, 72, 16), // "slotRowsInserted"
QT_MOC_LITERAL(7, 89, 6), // "parent"
QT_MOC_LITERAL(8, 96, 5), // "start"
QT_MOC_LITERAL(9, 102, 3), // "end"
QT_MOC_LITERAL(10, 106, 15), // "slotRowsRemoved"
QT_MOC_LITERAL(11, 122, 14), // "slotModelReset"
QT_MOC_LITERAL(12, 137, 17), // "updateBestMatches"
QT_MOC_LITERAL(13, 155, 20), // "makeGroupItemsUnique"
QT_MOC_LITERAL(14, 176, 12) // "onlyFiltered"

    },
    "KateCompletionModel\0expandIndex\0\0"
    "QModelIndex\0index\0argumentHintsChanged\0"
    "slotRowsInserted\0parent\0start\0end\0"
    "slotRowsRemoved\0slotModelReset\0"
    "updateBestMatches\0makeGroupItemsUnique\0"
    "onlyFiltered"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KateCompletionModel[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       8,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   54,    2, 0x06 /* Public */,
       5,    0,   57,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       6,    3,   58,    2, 0x08 /* Private */,
      10,    3,   65,    2, 0x08 /* Private */,
      11,    0,   72,    2, 0x08 /* Private */,
      12,    0,   73,    2, 0x08 /* Private */,
      13,    1,   74,    2, 0x08 /* Private */,
      13,    0,   77,    2, 0x28 /* Private | MethodCloned */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3, QMetaType::Int, QMetaType::Int,    7,    8,    9,
    QMetaType::Void, 0x80000000 | 3, QMetaType::Int, QMetaType::Int,    7,    8,    9,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   14,
    QMetaType::Void,

       0        // eod
};

void KateCompletionModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<KateCompletionModel *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->expandIndex((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 1: _t->argumentHintsChanged(); break;
        case 2: _t->slotRowsInserted((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 3: _t->slotRowsRemoved((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 4: _t->slotModelReset(); break;
        case 5: _t->updateBestMatches(); break;
        case 6: _t->makeGroupItemsUnique((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 7: _t->makeGroupItemsUnique(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (KateCompletionModel::*)(const QModelIndex & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KateCompletionModel::expandIndex)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (KateCompletionModel::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KateCompletionModel::argumentHintsChanged)) {
                *result = 1;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject KateCompletionModel::staticMetaObject = { {
    QMetaObject::SuperData::link<ExpandingWidgetModel::staticMetaObject>(),
    qt_meta_stringdata_KateCompletionModel.data,
    qt_meta_data_KateCompletionModel,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *KateCompletionModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateCompletionModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KateCompletionModel.stringdata0))
        return static_cast<void*>(this);
    return ExpandingWidgetModel::qt_metacast(_clname);
}

int KateCompletionModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ExpandingWidgetModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void KateCompletionModel::expandIndex(const QModelIndex & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KateCompletionModel::argumentHintsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
