/****************************************************************************
** Meta object code from reading C++ file 'katestatusbar.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../ktexteditor-5.116.0/src/view/katestatusbar.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'katestatusbar.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KateStatusBarOpenUpMenu_t {
    QByteArrayData data[1];
    char stringdata0[24];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KateStatusBarOpenUpMenu_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KateStatusBarOpenUpMenu_t qt_meta_stringdata_KateStatusBarOpenUpMenu = {
    {
QT_MOC_LITERAL(0, 0, 23) // "KateStatusBarOpenUpMenu"

    },
    "KateStatusBarOpenUpMenu"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KateStatusBarOpenUpMenu[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void KateStatusBarOpenUpMenu::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject KateStatusBarOpenUpMenu::staticMetaObject = { {
    QMetaObject::SuperData::link<QMenu::staticMetaObject>(),
    qt_meta_stringdata_KateStatusBarOpenUpMenu.data,
    qt_meta_data_KateStatusBarOpenUpMenu,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *KateStatusBarOpenUpMenu::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateStatusBarOpenUpMenu::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KateStatusBarOpenUpMenu.stringdata0))
        return static_cast<void*>(this);
    return QMenu::qt_metacast(_clname);
}

int KateStatusBarOpenUpMenu::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QMenu::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_StatusBarButton_t {
    QByteArrayData data[1];
    char stringdata0[16];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_StatusBarButton_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_StatusBarButton_t qt_meta_stringdata_StatusBarButton = {
    {
QT_MOC_LITERAL(0, 0, 15) // "StatusBarButton"

    },
    "StatusBarButton"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_StatusBarButton[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void StatusBarButton::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject StatusBarButton::staticMetaObject = { {
    QMetaObject::SuperData::link<QPushButton::staticMetaObject>(),
    qt_meta_stringdata_StatusBarButton.data,
    qt_meta_data_StatusBarButton,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *StatusBarButton::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *StatusBarButton::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_StatusBarButton.stringdata0))
        return static_cast<void*>(this);
    return QPushButton::qt_metacast(_clname);
}

int StatusBarButton::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QPushButton::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_KateStatusBar_t {
    QByteArrayData data[23];
    char stringdata0[314];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KateStatusBar_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KateStatusBar_t qt_meta_stringdata_KateStatusBar = {
    {
QT_MOC_LITERAL(0, 0, 13), // "KateStatusBar"
QT_MOC_LITERAL(1, 14, 12), // "updateStatus"
QT_MOC_LITERAL(2, 27, 0), // ""
QT_MOC_LITERAL(3, 28, 15), // "viewModeChanged"
QT_MOC_LITERAL(4, 44, 21), // "cursorPositionChanged"
QT_MOC_LITERAL(5, 66, 16), // "updateDictionary"
QT_MOC_LITERAL(6, 83, 16), // "selectionChanged"
QT_MOC_LITERAL(7, 100, 21), // "documentConfigChanged"
QT_MOC_LITERAL(8, 122, 11), // "modeChanged"
QT_MOC_LITERAL(9, 134, 16), // "wordCountChanged"
QT_MOC_LITERAL(10, 151, 15), // "toggleWordCount"
QT_MOC_LITERAL(11, 167, 2), // "on"
QT_MOC_LITERAL(12, 170, 13), // "configChanged"
QT_MOC_LITERAL(13, 184, 16), // "changeDictionary"
QT_MOC_LITERAL(14, 201, 8), // "QAction*"
QT_MOC_LITERAL(15, 210, 6), // "action"
QT_MOC_LITERAL(16, 217, 9), // "updateEOL"
QT_MOC_LITERAL(17, 227, 12), // "slotTabGroup"
QT_MOC_LITERAL(18, 240, 15), // "slotIndentGroup"
QT_MOC_LITERAL(19, 256, 17), // "slotIndentTabMode"
QT_MOC_LITERAL(20, 274, 15), // "toggleShowLines"
QT_MOC_LITERAL(21, 290, 7), // "checked"
QT_MOC_LITERAL(22, 298, 15) // "toggleShowWords"

    },
    "KateStatusBar\0updateStatus\0\0viewModeChanged\0"
    "cursorPositionChanged\0updateDictionary\0"
    "selectionChanged\0documentConfigChanged\0"
    "modeChanged\0wordCountChanged\0"
    "toggleWordCount\0on\0configChanged\0"
    "changeDictionary\0QAction*\0action\0"
    "updateEOL\0slotTabGroup\0slotIndentGroup\0"
    "slotIndentTabMode\0toggleShowLines\0"
    "checked\0toggleShowWords"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KateStatusBar[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      17,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   99,    2, 0x0a /* Public */,
       3,    0,  100,    2, 0x0a /* Public */,
       4,    0,  101,    2, 0x0a /* Public */,
       5,    0,  102,    2, 0x0a /* Public */,
       6,    0,  103,    2, 0x0a /* Public */,
       7,    0,  104,    2, 0x0a /* Public */,
       8,    0,  105,    2, 0x0a /* Public */,
       9,    4,  106,    2, 0x0a /* Public */,
      10,    1,  115,    2, 0x0a /* Public */,
      12,    0,  118,    2, 0x0a /* Public */,
      13,    1,  119,    2, 0x0a /* Public */,
      16,    0,  122,    2, 0x0a /* Public */,
      17,    1,  123,    2, 0x0a /* Public */,
      18,    1,  126,    2, 0x0a /* Public */,
      19,    1,  129,    2, 0x0a /* Public */,
      20,    1,  132,    2, 0x0a /* Public */,
      22,    1,  135,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::Int,    2,    2,    2,    2,
    QMetaType::Void, QMetaType::Bool,   11,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 14,   15,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 14,    2,
    QMetaType::Void, 0x80000000 | 14,    2,
    QMetaType::Void, 0x80000000 | 14,    2,
    QMetaType::Void, QMetaType::Bool,   21,
    QMetaType::Void, QMetaType::Bool,   21,

       0        // eod
};

void KateStatusBar::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<KateStatusBar *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->updateStatus(); break;
        case 1: _t->viewModeChanged(); break;
        case 2: _t->cursorPositionChanged(); break;
        case 3: _t->updateDictionary(); break;
        case 4: _t->selectionChanged(); break;
        case 5: _t->documentConfigChanged(); break;
        case 6: _t->modeChanged(); break;
        case 7: _t->wordCountChanged((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4]))); break;
        case 8: _t->toggleWordCount((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 9: _t->configChanged(); break;
        case 10: _t->changeDictionary((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        case 11: _t->updateEOL(); break;
        case 12: _t->slotTabGroup((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        case 13: _t->slotIndentGroup((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        case 14: _t->slotIndentTabMode((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        case 15: _t->toggleShowLines((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 16: _t->toggleShowWords((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAction* >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAction* >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAction* >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAction* >(); break;
            }
            break;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject KateStatusBar::staticMetaObject = { {
    QMetaObject::SuperData::link<KateViewBarWidget::staticMetaObject>(),
    qt_meta_stringdata_KateStatusBar.data,
    qt_meta_data_KateStatusBar,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *KateStatusBar::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateStatusBar::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KateStatusBar.stringdata0))
        return static_cast<void*>(this);
    return KateViewBarWidget::qt_metacast(_clname);
}

int KateStatusBar::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KateViewBarWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
