/*
    SPDX-FileCopyrightText: 2005-2006 Hamish Rodda <rodda@kde.org>

    SPDX-License-Identifier: LGPL-2.0-or-later
*/

#include "codecompletioninterface.h"

using namespace KTextEditor;

CodeCompletionInterface::~CodeCompletionInterface() = default;

CodeCompletionInterfaceV2::~CodeCompletionInterfaceV2() = default;
