/****************************************************************************
** Meta object code from reading C++ file 'katecompletionwidget.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../ktexteditor-5.116.0/src/completion/katecompletionwidget.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'katecompletionwidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KateCompletionWidget_t {
    QByteArrayData data[38];
    char stringdata0[472];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KateCompletionWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KateCompletionWidget_t qt_meta_stringdata_KateCompletionWidget = {
    {
QT_MOC_LITERAL(0, 0, 20), // "KateCompletionWidget"
QT_MOC_LITERAL(1, 21, 7), // "execute"
QT_MOC_LITERAL(2, 29, 0), // ""
QT_MOC_LITERAL(3, 30, 10), // "cursorDown"
QT_MOC_LITERAL(4, 41, 8), // "cursorUp"
QT_MOC_LITERAL(5, 50, 17), // "waitForModelReset"
QT_MOC_LITERAL(6, 68, 15), // "abortCompletion"
QT_MOC_LITERAL(7, 84, 19), // "automaticInvocation"
QT_MOC_LITERAL(8, 104, 20), // "argumentHintsChanged"
QT_MOC_LITERAL(9, 125, 10), // "hasContent"
QT_MOC_LITERAL(10, 136, 10), // "navigateUp"
QT_MOC_LITERAL(11, 147, 12), // "navigateDown"
QT_MOC_LITERAL(12, 160, 12), // "navigateLeft"
QT_MOC_LITERAL(13, 173, 13), // "navigateRight"
QT_MOC_LITERAL(14, 187, 14), // "navigateAccept"
QT_MOC_LITERAL(15, 202, 12), // "navigateBack"
QT_MOC_LITERAL(16, 215, 20), // "completionModelReset"
QT_MOC_LITERAL(17, 236, 14), // "modelDestroyed"
QT_MOC_LITERAL(18, 251, 5), // "model"
QT_MOC_LITERAL(19, 257, 19), // "modelContentChanged"
QT_MOC_LITERAL(20, 277, 21), // "cursorPositionChanged"
QT_MOC_LITERAL(21, 299, 10), // "modelReset"
QT_MOC_LITERAL(22, 310, 12), // "rowsInserted"
QT_MOC_LITERAL(23, 323, 11), // "QModelIndex"
QT_MOC_LITERAL(24, 335, 6), // "parent"
QT_MOC_LITERAL(25, 342, 3), // "row"
QT_MOC_LITERAL(26, 346, 6), // "rowEnd"
QT_MOC_LITERAL(27, 353, 12), // "viewFocusOut"
QT_MOC_LITERAL(28, 366, 8), // "wrapLine"
QT_MOC_LITERAL(29, 375, 19), // "KTextEditor::Cursor"
QT_MOC_LITERAL(30, 395, 8), // "position"
QT_MOC_LITERAL(31, 404, 10), // "unwrapLine"
QT_MOC_LITERAL(32, 415, 4), // "line"
QT_MOC_LITERAL(33, 420, 10), // "insertText"
QT_MOC_LITERAL(34, 431, 4), // "text"
QT_MOC_LITERAL(35, 436, 10), // "removeText"
QT_MOC_LITERAL(36, 447, 18), // "KTextEditor::Range"
QT_MOC_LITERAL(37, 466, 5) // "range"

    },
    "KateCompletionWidget\0execute\0\0cursorDown\0"
    "cursorUp\0waitForModelReset\0abortCompletion\0"
    "automaticInvocation\0argumentHintsChanged\0"
    "hasContent\0navigateUp\0navigateDown\0"
    "navigateLeft\0navigateRight\0navigateAccept\0"
    "navigateBack\0completionModelReset\0"
    "modelDestroyed\0model\0modelContentChanged\0"
    "cursorPositionChanged\0modelReset\0"
    "rowsInserted\0QModelIndex\0parent\0row\0"
    "rowEnd\0viewFocusOut\0wrapLine\0"
    "KTextEditor::Cursor\0position\0unwrapLine\0"
    "line\0insertText\0text\0removeText\0"
    "KTextEditor::Range\0range"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KateCompletionWidget[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      24,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,  134,    2, 0x0a /* Public */,
       3,    0,  135,    2, 0x0a /* Public */,
       4,    0,  136,    2, 0x0a /* Public */,
       5,    0,  137,    2, 0x0a /* Public */,
       6,    0,  138,    2, 0x0a /* Public */,
       7,    0,  139,    2, 0x0a /* Public */,
       8,    1,  140,    2, 0x0a /* Public */,
      10,    0,  143,    2, 0x0a /* Public */,
      11,    0,  144,    2, 0x0a /* Public */,
      12,    0,  145,    2, 0x0a /* Public */,
      13,    0,  146,    2, 0x0a /* Public */,
      14,    0,  147,    2, 0x0a /* Public */,
      15,    0,  148,    2, 0x0a /* Public */,
      16,    0,  149,    2, 0x08 /* Private */,
      17,    1,  150,    2, 0x08 /* Private */,
      19,    0,  153,    2, 0x08 /* Private */,
      20,    0,  154,    2, 0x08 /* Private */,
      21,    0,  155,    2, 0x08 /* Private */,
      22,    3,  156,    2, 0x08 /* Private */,
      27,    0,  163,    2, 0x08 /* Private */,
      28,    1,  164,    2, 0x08 /* Private */,
      31,    1,  167,    2, 0x08 /* Private */,
      33,    2,  170,    2, 0x08 /* Private */,
      35,    1,  175,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Bool,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    9,
    QMetaType::Bool,
    QMetaType::Bool,
    QMetaType::Bool,
    QMetaType::Bool,
    QMetaType::Bool,
    QMetaType::Bool,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QObjectStar,   18,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 23, QMetaType::Int, QMetaType::Int,   24,   25,   26,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 29,   30,
    QMetaType::Void, QMetaType::Int,   32,
    QMetaType::Void, 0x80000000 | 29, QMetaType::QString,   30,   34,
    QMetaType::Void, 0x80000000 | 36,   37,

       0        // eod
};

void KateCompletionWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<KateCompletionWidget *>(_o);
        (void)_t;
        switch (_id) {
        case 0: { bool _r = _t->execute();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 1: _t->cursorDown(); break;
        case 2: _t->cursorUp(); break;
        case 3: _t->waitForModelReset(); break;
        case 4: _t->abortCompletion(); break;
        case 5: _t->automaticInvocation(); break;
        case 6: _t->argumentHintsChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 7: { bool _r = _t->navigateUp();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 8: { bool _r = _t->navigateDown();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 9: { bool _r = _t->navigateLeft();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 10: { bool _r = _t->navigateRight();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 11: { bool _r = _t->navigateAccept();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 12: { bool _r = _t->navigateBack();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 13: _t->completionModelReset(); break;
        case 14: _t->modelDestroyed((*reinterpret_cast< QObject*(*)>(_a[1]))); break;
        case 15: _t->modelContentChanged(); break;
        case 16: _t->cursorPositionChanged(); break;
        case 17: _t->modelReset(); break;
        case 18: _t->rowsInserted((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 19: _t->viewFocusOut(); break;
        case 20: _t->wrapLine((*reinterpret_cast< const KTextEditor::Cursor(*)>(_a[1]))); break;
        case 21: _t->unwrapLine((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 22: _t->insertText((*reinterpret_cast< const KTextEditor::Cursor(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 23: _t->removeText((*reinterpret_cast< const KTextEditor::Range(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 20:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Cursor >(); break;
            }
            break;
        case 22:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Cursor >(); break;
            }
            break;
        case 23:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Range >(); break;
            }
            break;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject KateCompletionWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QFrame::staticMetaObject>(),
    qt_meta_stringdata_KateCompletionWidget.data,
    qt_meta_data_KateCompletionWidget,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *KateCompletionWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateCompletionWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KateCompletionWidget.stringdata0))
        return static_cast<void*>(this);
    return QFrame::qt_metacast(_clname);
}

int KateCompletionWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QFrame::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 24)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 24)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
