/****************************************************************************
** Meta object code from reading C++ file 'katedocument.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../ktexteditor-5.116.0/src/document/katedocument.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'katedocument.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KTextEditor__DocumentPrivate_t {
    QByteArrayData data[138];
    char stringdata0[1994];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KTextEditor__DocumentPrivate_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KTextEditor__DocumentPrivate_t qt_meta_stringdata_KTextEditor__DocumentPrivate = {
    {
QT_MOC_LITERAL(0, 0, 28), // "KTextEditor::DocumentPrivate"
QT_MOC_LITERAL(1, 29, 35), // "charactersSemiInteractivelyIn..."
QT_MOC_LITERAL(2, 65, 0), // ""
QT_MOC_LITERAL(3, 66, 19), // "KTextEditor::Cursor"
QT_MOC_LITERAL(4, 86, 8), // "position"
QT_MOC_LITERAL(5, 95, 4), // "text"
QT_MOC_LITERAL(6, 100, 17), // "textInsertedRange"
QT_MOC_LITERAL(7, 118, 22), // "KTextEditor::Document*"
QT_MOC_LITERAL(8, 141, 8), // "document"
QT_MOC_LITERAL(9, 150, 18), // "KTextEditor::Range"
QT_MOC_LITERAL(10, 169, 5), // "range"
QT_MOC_LITERAL(11, 175, 11), // "textRemoved"
QT_MOC_LITERAL(12, 187, 7), // "oldText"
QT_MOC_LITERAL(13, 195, 15), // "editLineWrapped"
QT_MOC_LITERAL(14, 211, 4), // "line"
QT_MOC_LITERAL(15, 216, 3), // "col"
QT_MOC_LITERAL(16, 220, 3), // "len"
QT_MOC_LITERAL(17, 224, 17), // "editLineUnWrapped"
QT_MOC_LITERAL(18, 242, 11), // "undoChanged"
QT_MOC_LITERAL(19, 254, 20), // "markToolTipRequested"
QT_MOC_LITERAL(20, 275, 17), // "KTextEditor::Mark"
QT_MOC_LITERAL(21, 293, 4), // "mark"
QT_MOC_LITERAL(22, 298, 5), // "bool&"
QT_MOC_LITERAL(23, 304, 7), // "handled"
QT_MOC_LITERAL(24, 312, 24), // "markContextMenuRequested"
QT_MOC_LITERAL(25, 337, 3), // "pos"
QT_MOC_LITERAL(26, 341, 11), // "markClicked"
QT_MOC_LITERAL(27, 353, 12), // "marksChanged"
QT_MOC_LITERAL(28, 366, 11), // "markChanged"
QT_MOC_LITERAL(29, 378, 44), // "KTextEditor::MarkInterface::M..."
QT_MOC_LITERAL(30, 423, 35), // "aboutToDeleteMovingInterfaceC..."
QT_MOC_LITERAL(31, 459, 39), // "aboutToInvalidateMovingInterf..."
QT_MOC_LITERAL(32, 499, 22), // "annotationModelChanged"
QT_MOC_LITERAL(33, 522, 29), // "KTextEditor::AnnotationModel*"
QT_MOC_LITERAL(34, 552, 14), // "modifiedOnDisk"
QT_MOC_LITERAL(35, 567, 3), // "doc"
QT_MOC_LITERAL(36, 571, 10), // "isModified"
QT_MOC_LITERAL(37, 582, 56), // "KTextEditor::ModificationInte..."
QT_MOC_LITERAL(38, 639, 6), // "reason"
QT_MOC_LITERAL(39, 646, 17), // "aboutToRemoveText"
QT_MOC_LITERAL(40, 664, 23), // "dictionaryRangesPresent"
QT_MOC_LITERAL(41, 688, 5), // "yesNo"
QT_MOC_LITERAL(42, 694, 24), // "defaultDictionaryChanged"
QT_MOC_LITERAL(43, 719, 29), // "KTextEditor::DocumentPrivate*"
QT_MOC_LITERAL(44, 749, 6), // "loaded"
QT_MOC_LITERAL(45, 756, 7), // "setText"
QT_MOC_LITERAL(46, 764, 5), // "clear"
QT_MOC_LITERAL(47, 770, 10), // "insertText"
QT_MOC_LITERAL(48, 781, 1), // "s"
QT_MOC_LITERAL(49, 783, 5), // "block"
QT_MOC_LITERAL(50, 789, 10), // "insertLine"
QT_MOC_LITERAL(51, 800, 11), // "insertLines"
QT_MOC_LITERAL(52, 812, 10), // "removeText"
QT_MOC_LITERAL(53, 823, 10), // "removeLine"
QT_MOC_LITERAL(54, 834, 11), // "replaceText"
QT_MOC_LITERAL(55, 846, 1), // "r"
QT_MOC_LITERAL(56, 848, 1), // "l"
QT_MOC_LITERAL(57, 850, 1), // "b"
QT_MOC_LITERAL(58, 852, 4), // "undo"
QT_MOC_LITERAL(59, 857, 4), // "redo"
QT_MOC_LITERAL(60, 862, 20), // "clearEditingPosStack"
QT_MOC_LITERAL(61, 883, 20), // "saveEditingPositions"
QT_MOC_LITERAL(62, 904, 6), // "cursor"
QT_MOC_LITERAL(63, 911, 7), // "setMark"
QT_MOC_LITERAL(64, 919, 8), // "markType"
QT_MOC_LITERAL(65, 928, 9), // "clearMark"
QT_MOC_LITERAL(66, 938, 7), // "addMark"
QT_MOC_LITERAL(67, 946, 10), // "removeMark"
QT_MOC_LITERAL(68, 957, 10), // "clearMarks"
QT_MOC_LITERAL(69, 968, 18), // "requestMarkTooltip"
QT_MOC_LITERAL(70, 987, 15), // "handleMarkClick"
QT_MOC_LITERAL(71, 1003, 21), // "handleMarkContextMenu"
QT_MOC_LITERAL(72, 1025, 13), // "setMarkPixmap"
QT_MOC_LITERAL(73, 1039, 24), // "MarkInterface::MarkTypes"
QT_MOC_LITERAL(74, 1064, 18), // "setMarkDescription"
QT_MOC_LITERAL(75, 1083, 16), // "setEditableMarks"
QT_MOC_LITERAL(76, 1100, 8), // "markMask"
QT_MOC_LITERAL(77, 1109, 11), // "setMarkIcon"
QT_MOC_LITERAL(78, 1121, 4), // "icon"
QT_MOC_LITERAL(79, 1126, 5), // "print"
QT_MOC_LITERAL(80, 1132, 12), // "printPreview"
QT_MOC_LITERAL(81, 1145, 17), // "autoReloadToggled"
QT_MOC_LITERAL(82, 1163, 8), // "tagLines"
QT_MOC_LITERAL(83, 1172, 22), // "KTextEditor::LineRange"
QT_MOC_LITERAL(84, 1195, 9), // "lineRange"
QT_MOC_LITERAL(85, 1205, 7), // "tagLine"
QT_MOC_LITERAL(86, 1213, 17), // "internalHlChanged"
QT_MOC_LITERAL(87, 1231, 18), // "slotModifiedOnDisk"
QT_MOC_LITERAL(88, 1250, 18), // "KTextEditor::View*"
QT_MOC_LITERAL(89, 1269, 1), // "v"
QT_MOC_LITERAL(90, 1271, 14), // "documentReload"
QT_MOC_LITERAL(91, 1286, 12), // "documentSave"
QT_MOC_LITERAL(92, 1299, 14), // "documentSaveAs"
QT_MOC_LITERAL(93, 1314, 26), // "documentSaveAsWithEncoding"
QT_MOC_LITERAL(94, 1341, 8), // "encoding"
QT_MOC_LITERAL(95, 1350, 18), // "documentSaveCopyAs"
QT_MOC_LITERAL(96, 1369, 4), // "save"
QT_MOC_LITERAL(97, 1374, 15), // "onModOnHdSaveAs"
QT_MOC_LITERAL(98, 1390, 14), // "onModOnHdClose"
QT_MOC_LITERAL(99, 1405, 15), // "onModOnHdReload"
QT_MOC_LITERAL(100, 1421, 19), // "onModOnHdAutoReload"
QT_MOC_LITERAL(101, 1441, 15), // "onModOnHdIgnore"
QT_MOC_LITERAL(102, 1457, 11), // "setWordWrap"
QT_MOC_LITERAL(103, 1469, 2), // "on"
QT_MOC_LITERAL(104, 1472, 13), // "setWordWrapAt"
QT_MOC_LITERAL(105, 1486, 24), // "setPageUpDownMovesCursor"
QT_MOC_LITERAL(106, 1511, 16), // "slotModOnHdDirty"
QT_MOC_LITERAL(107, 1528, 4), // "path"
QT_MOC_LITERAL(108, 1533, 18), // "slotModOnHdCreated"
QT_MOC_LITERAL(109, 1552, 18), // "slotModOnHdDeleted"
QT_MOC_LITERAL(110, 1571, 24), // "slotDelayedHandleModOnHd"
QT_MOC_LITERAL(111, 1596, 19), // "slotQueryClose_save"
QT_MOC_LITERAL(112, 1616, 5), // "bool*"
QT_MOC_LITERAL(113, 1622, 12), // "abortClosing"
QT_MOC_LITERAL(114, 1635, 16), // "messageDestroyed"
QT_MOC_LITERAL(115, 1652, 21), // "KTextEditor::Message*"
QT_MOC_LITERAL(116, 1674, 7), // "message"
QT_MOC_LITERAL(117, 1682, 21), // "clearDictionaryRanges"
QT_MOC_LITERAL(118, 1704, 13), // "setDictionary"
QT_MOC_LITERAL(119, 1718, 4), // "dict"
QT_MOC_LITERAL(120, 1723, 9), // "blockmode"
QT_MOC_LITERAL(121, 1733, 20), // "setDefaultDictionary"
QT_MOC_LITERAL(122, 1754, 28), // "onTheFlySpellCheckingEnabled"
QT_MOC_LITERAL(123, 1783, 6), // "enable"
QT_MOC_LITERAL(124, 1790, 20), // "refreshOnTheFlyCheck"
QT_MOC_LITERAL(125, 1811, 11), // "slotStarted"
QT_MOC_LITERAL(126, 1823, 9), // "KIO::Job*"
QT_MOC_LITERAL(127, 1833, 3), // "job"
QT_MOC_LITERAL(128, 1837, 13), // "slotCompleted"
QT_MOC_LITERAL(129, 1851, 12), // "slotCanceled"
QT_MOC_LITERAL(130, 1864, 25), // "slotTriggerLoadingMessage"
QT_MOC_LITERAL(131, 1890, 16), // "slotAbortLoading"
QT_MOC_LITERAL(132, 1907, 14), // "slotUrlChanged"
QT_MOC_LITERAL(133, 1922, 3), // "url"
QT_MOC_LITERAL(134, 1926, 31), // "openWithLineLengthLimitOverride"
QT_MOC_LITERAL(135, 1958, 23), // "checkCursorForAutobrace"
QT_MOC_LITERAL(136, 1982, 4), // "view"
QT_MOC_LITERAL(137, 1987, 6) // "newPos"

    },
    "KTextEditor::DocumentPrivate\0"
    "charactersSemiInteractivelyInserted\0"
    "\0KTextEditor::Cursor\0position\0text\0"
    "textInsertedRange\0KTextEditor::Document*\0"
    "document\0KTextEditor::Range\0range\0"
    "textRemoved\0oldText\0editLineWrapped\0"
    "line\0col\0len\0editLineUnWrapped\0"
    "undoChanged\0markToolTipRequested\0"
    "KTextEditor::Mark\0mark\0bool&\0handled\0"
    "markContextMenuRequested\0pos\0markClicked\0"
    "marksChanged\0markChanged\0"
    "KTextEditor::MarkInterface::MarkChangeAction\0"
    "aboutToDeleteMovingInterfaceContent\0"
    "aboutToInvalidateMovingInterfaceContent\0"
    "annotationModelChanged\0"
    "KTextEditor::AnnotationModel*\0"
    "modifiedOnDisk\0doc\0isModified\0"
    "KTextEditor::ModificationInterface::ModifiedOnDiskReason\0"
    "reason\0aboutToRemoveText\0"
    "dictionaryRangesPresent\0yesNo\0"
    "defaultDictionaryChanged\0"
    "KTextEditor::DocumentPrivate*\0loaded\0"
    "setText\0clear\0insertText\0s\0block\0"
    "insertLine\0insertLines\0removeText\0"
    "removeLine\0replaceText\0r\0l\0b\0undo\0"
    "redo\0clearEditingPosStack\0"
    "saveEditingPositions\0cursor\0setMark\0"
    "markType\0clearMark\0addMark\0removeMark\0"
    "clearMarks\0requestMarkTooltip\0"
    "handleMarkClick\0handleMarkContextMenu\0"
    "setMarkPixmap\0MarkInterface::MarkTypes\0"
    "setMarkDescription\0setEditableMarks\0"
    "markMask\0setMarkIcon\0icon\0print\0"
    "printPreview\0autoReloadToggled\0tagLines\0"
    "KTextEditor::LineRange\0lineRange\0"
    "tagLine\0internalHlChanged\0slotModifiedOnDisk\0"
    "KTextEditor::View*\0v\0documentReload\0"
    "documentSave\0documentSaveAs\0"
    "documentSaveAsWithEncoding\0encoding\0"
    "documentSaveCopyAs\0save\0onModOnHdSaveAs\0"
    "onModOnHdClose\0onModOnHdReload\0"
    "onModOnHdAutoReload\0onModOnHdIgnore\0"
    "setWordWrap\0on\0setWordWrapAt\0"
    "setPageUpDownMovesCursor\0slotModOnHdDirty\0"
    "path\0slotModOnHdCreated\0slotModOnHdDeleted\0"
    "slotDelayedHandleModOnHd\0slotQueryClose_save\0"
    "bool*\0abortClosing\0messageDestroyed\0"
    "KTextEditor::Message*\0message\0"
    "clearDictionaryRanges\0setDictionary\0"
    "dict\0blockmode\0setDefaultDictionary\0"
    "onTheFlySpellCheckingEnabled\0enable\0"
    "refreshOnTheFlyCheck\0slotStarted\0"
    "KIO::Job*\0job\0slotCompleted\0slotCanceled\0"
    "slotTriggerLoadingMessage\0slotAbortLoading\0"
    "slotUrlChanged\0url\0openWithLineLengthLimitOverride\0"
    "checkCursorForAutobrace\0view\0newPos"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KTextEditor__DocumentPrivate[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      93,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      19,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,  479,    2, 0x06 /* Public */,
       6,    2,  484,    2, 0x06 /* Public */,
      11,    3,  489,    2, 0x06 /* Public */,
      13,    3,  496,    2, 0x06 /* Public */,
      17,    2,  503,    2, 0x06 /* Public */,
      18,    0,  508,    2, 0x06 /* Public */,
      19,    4,  509,    2, 0x06 /* Public */,
      24,    4,  518,    2, 0x06 /* Public */,
      26,    3,  527,    2, 0x06 /* Public */,
      27,    1,  534,    2, 0x06 /* Public */,
      28,    3,  537,    2, 0x06 /* Public */,
      30,    1,  544,    2, 0x06 /* Public */,
      31,    1,  547,    2, 0x06 /* Public */,
      32,    2,  550,    2, 0x06 /* Public */,
      34,    3,  555,    2, 0x06 /* Public */,
      39,    1,  562,    2, 0x06 /* Public */,
      40,    1,  565,    2, 0x06 /* Public */,
      42,    1,  568,    2, 0x06 /* Public */,
      44,    1,  571,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      45,    1,  574,    2, 0x0a /* Public */,
      45,    1,  577,    2, 0x0a /* Public */,
      46,    0,  580,    2, 0x0a /* Public */,
      47,    3,  581,    2, 0x0a /* Public */,
      47,    2,  588,    2, 0x2a /* Public | MethodCloned */,
      47,    3,  593,    2, 0x0a /* Public */,
      47,    2,  600,    2, 0x2a /* Public | MethodCloned */,
      50,    2,  605,    2, 0x0a /* Public */,
      51,    2,  610,    2, 0x0a /* Public */,
      52,    2,  615,    2, 0x0a /* Public */,
      52,    1,  620,    2, 0x2a /* Public | MethodCloned */,
      53,    1,  623,    2, 0x0a /* Public */,
      54,    3,  626,    2, 0x0a /* Public */,
      54,    2,  633,    2, 0x2a /* Public | MethodCloned */,
      54,    3,  638,    2, 0x0a /* Public */,
      58,    0,  645,    2, 0x0a /* Public */,
      59,    0,  646,    2, 0x0a /* Public */,
      60,    0,  647,    2, 0x0a /* Public */,
      61,    1,  648,    2, 0x0a /* Public */,
      63,    2,  651,    2, 0x0a /* Public */,
      65,    1,  656,    2, 0x0a /* Public */,
      66,    2,  659,    2, 0x0a /* Public */,
      67,    2,  664,    2, 0x0a /* Public */,
      68,    0,  669,    2, 0x0a /* Public */,
      69,    2,  670,    2, 0x0a /* Public */,
      70,    1,  675,    2, 0x0a /* Public */,
      71,    2,  678,    2, 0x0a /* Public */,
      72,    2,  683,    2, 0x0a /* Public */,
      74,    2,  688,    2, 0x0a /* Public */,
      75,    1,  693,    2, 0x0a /* Public */,
      77,    2,  696,    2, 0x0a /* Public */,
      79,    0,  701,    2, 0x0a /* Public */,
      80,    0,  702,    2, 0x0a /* Public */,
      81,    1,  703,    2, 0x08 /* Private */,
      82,    1,  706,    2, 0x0a /* Public */,
      85,    1,  709,    2, 0x0a /* Public */,
      86,    0,  712,    2, 0x08 /* Private */,
      87,    1,  713,    2, 0x0a /* Public */,
      87,    0,  716,    2, 0x2a /* Public | MethodCloned */,
      90,    0,  717,    2, 0x0a /* Public */,
      91,    0,  718,    2, 0x0a /* Public */,
      92,    0,  719,    2, 0x0a /* Public */,
      93,    1,  720,    2, 0x0a /* Public */,
      95,    0,  723,    2, 0x0a /* Public */,
      96,    0,  724,    2, 0x0a /* Public */,
      97,    0,  725,    2, 0x08 /* Private */,
      98,    0,  726,    2, 0x08 /* Private */,
      99,    0,  727,    2, 0x08 /* Private */,
     100,    0,  728,    2, 0x08 /* Private */,
     101,    0,  729,    2, 0x08 /* Private */,
     102,    1,  730,    2, 0x0a /* Public */,
     104,    1,  733,    2, 0x0a /* Public */,
     105,    1,  736,    2, 0x0a /* Public */,
     106,    1,  739,    2, 0x08 /* Private */,
     108,    1,  742,    2, 0x08 /* Private */,
     109,    1,  745,    2, 0x08 /* Private */,
     110,    0,  748,    2, 0x08 /* Private */,
     111,    2,  749,    2, 0x0a /* Public */,
     114,    1,  754,    2, 0x0a /* Public */,
     117,    0,  757,    2, 0x0a /* Public */,
     118,    3,  758,    2, 0x0a /* Public */,
     118,    2,  765,    2, 0x0a /* Public */,
     121,    1,  770,    2, 0x0a /* Public */,
     122,    1,  773,    2, 0x0a /* Public */,
     124,    1,  776,    2, 0x0a /* Public */,
     124,    0,  779,    2, 0x2a /* Public | MethodCloned */,
     125,    1,  780,    2, 0x08 /* Private */,
     128,    0,  783,    2, 0x08 /* Private */,
     129,    0,  784,    2, 0x08 /* Private */,
     130,    0,  785,    2, 0x08 /* Private */,
     131,    0,  786,    2, 0x08 /* Private */,
     132,    1,  787,    2, 0x08 /* Private */,
     134,    0,  790,    2, 0x0a /* Public */,
     135,    2,  791,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    4,    5,
    QMetaType::Void, 0x80000000 | 7, 0x80000000 | 9,    8,   10,
    QMetaType::Void, 0x80000000 | 7, 0x80000000 | 9, QMetaType::QString,    8,   10,   12,
    QMetaType::Void, QMetaType::Int, QMetaType::Int, QMetaType::Int,   14,   15,   16,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,   14,   15,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 7, 0x80000000 | 20, QMetaType::QPoint, 0x80000000 | 22,    8,   21,    4,   23,
    QMetaType::Void, 0x80000000 | 7, 0x80000000 | 20, QMetaType::QPoint, 0x80000000 | 22,    8,   21,   25,   23,
    QMetaType::Void, 0x80000000 | 7, 0x80000000 | 20, 0x80000000 | 22,    8,   21,   23,
    QMetaType::Void, 0x80000000 | 7,    2,
    QMetaType::Void, 0x80000000 | 7, 0x80000000 | 20, 0x80000000 | 29,    2,    2,    2,
    QMetaType::Void, 0x80000000 | 7,    8,
    QMetaType::Void, 0x80000000 | 7,    8,
    QMetaType::Void, 0x80000000 | 33, 0x80000000 | 33,    2,    2,
    QMetaType::Void, 0x80000000 | 7, QMetaType::Bool, 0x80000000 | 37,   35,   36,   38,
    QMetaType::Void, 0x80000000 | 9,    2,
    QMetaType::Void, QMetaType::Bool,   41,
    QMetaType::Void, 0x80000000 | 43,    8,
    QMetaType::Void, 0x80000000 | 43,    8,

 // slots: parameters
    QMetaType::Bool, QMetaType::QString,    2,
    QMetaType::Bool, QMetaType::QStringList,    5,
    QMetaType::Bool,
    QMetaType::Bool, 0x80000000 | 3, QMetaType::QString, QMetaType::Bool,    4,   48,   49,
    QMetaType::Bool, 0x80000000 | 3, QMetaType::QString,    4,   48,
    QMetaType::Bool, 0x80000000 | 3, QMetaType::QStringList, QMetaType::Bool,    4,    5,   49,
    QMetaType::Bool, 0x80000000 | 3, QMetaType::QStringList,    4,    5,
    QMetaType::Bool, QMetaType::Int, QMetaType::QString,   14,   48,
    QMetaType::Bool, QMetaType::Int, QMetaType::QStringList,   14,   48,
    QMetaType::Bool, 0x80000000 | 9, QMetaType::Bool,   10,   49,
    QMetaType::Bool, 0x80000000 | 9,   10,
    QMetaType::Bool, QMetaType::Int,   14,
    QMetaType::Bool, 0x80000000 | 9, QMetaType::QString, QMetaType::Bool,   10,   48,   49,
    QMetaType::Bool, 0x80000000 | 9, QMetaType::QString,   10,   48,
    QMetaType::Bool, 0x80000000 | 9, QMetaType::QStringList, QMetaType::Bool,   55,   56,   57,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 3,   62,
    QMetaType::Void, QMetaType::Int, QMetaType::UInt,   14,   64,
    QMetaType::Void, QMetaType::Int,   14,
    QMetaType::Void, QMetaType::Int, QMetaType::UInt,   14,   64,
    QMetaType::Void, QMetaType::Int, QMetaType::UInt,   14,   64,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, QMetaType::QPoint,   14,    4,
    QMetaType::Bool, QMetaType::Int,   14,
    QMetaType::Bool, QMetaType::Int, QMetaType::QPoint,   14,    4,
    QMetaType::Void, 0x80000000 | 73, QMetaType::QPixmap,    2,    2,
    QMetaType::Void, 0x80000000 | 73, QMetaType::QString,    2,    2,
    QMetaType::Void, QMetaType::UInt,   76,
    QMetaType::Void, 0x80000000 | 73, QMetaType::QIcon,   64,   78,
    QMetaType::Bool,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   57,
    QMetaType::Void, 0x80000000 | 83,   84,
    QMetaType::Void, QMetaType::Int,   14,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 88,   89,
    QMetaType::Void,
    QMetaType::Bool,
    QMetaType::Bool,
    QMetaType::Bool,
    QMetaType::Bool, QMetaType::QString,   94,
    QMetaType::Void,
    QMetaType::Bool,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,  103,
    QMetaType::Void, QMetaType::UInt,   15,
    QMetaType::Void, QMetaType::Bool,  103,
    QMetaType::Void, QMetaType::QString,  107,
    QMetaType::Void, QMetaType::QString,  107,
    QMetaType::Void, QMetaType::QString,  107,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 112, 0x80000000 | 112,   23,  113,
    QMetaType::Void, 0x80000000 | 115,  116,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString, 0x80000000 | 9, QMetaType::Bool,  119,   10,  120,
    QMetaType::Void, QMetaType::QString, 0x80000000 | 9,  119,   10,
    QMetaType::Void, QMetaType::QString,  119,
    QMetaType::Void, QMetaType::Bool,  123,
    QMetaType::Void, 0x80000000 | 9,   10,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 126,  127,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QUrl,  133,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 88, 0x80000000 | 3,  136,  137,

       0        // eod
};

void KTextEditor::DocumentPrivate::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DocumentPrivate *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->charactersSemiInteractivelyInserted((*reinterpret_cast< const KTextEditor::Cursor(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 1: _t->textInsertedRange((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1])),(*reinterpret_cast< const KTextEditor::Range(*)>(_a[2]))); break;
        case 2: _t->textRemoved((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1])),(*reinterpret_cast< const KTextEditor::Range(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 3: _t->editLineWrapped((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 4: _t->editLineUnWrapped((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 5: _t->undoChanged(); break;
        case 6: _t->markToolTipRequested((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1])),(*reinterpret_cast< KTextEditor::Mark(*)>(_a[2])),(*reinterpret_cast< QPoint(*)>(_a[3])),(*reinterpret_cast< bool(*)>(_a[4]))); break;
        case 7: _t->markContextMenuRequested((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1])),(*reinterpret_cast< KTextEditor::Mark(*)>(_a[2])),(*reinterpret_cast< QPoint(*)>(_a[3])),(*reinterpret_cast< bool(*)>(_a[4]))); break;
        case 8: _t->markClicked((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1])),(*reinterpret_cast< KTextEditor::Mark(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3]))); break;
        case 9: _t->marksChanged((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1]))); break;
        case 10: _t->markChanged((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1])),(*reinterpret_cast< KTextEditor::Mark(*)>(_a[2])),(*reinterpret_cast< KTextEditor::MarkInterface::MarkChangeAction(*)>(_a[3]))); break;
        case 11: _t->aboutToDeleteMovingInterfaceContent((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1]))); break;
        case 12: _t->aboutToInvalidateMovingInterfaceContent((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1]))); break;
        case 13: _t->annotationModelChanged((*reinterpret_cast< KTextEditor::AnnotationModel*(*)>(_a[1])),(*reinterpret_cast< KTextEditor::AnnotationModel*(*)>(_a[2]))); break;
        case 14: _t->modifiedOnDisk((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2])),(*reinterpret_cast< KTextEditor::ModificationInterface::ModifiedOnDiskReason(*)>(_a[3]))); break;
        case 15: _t->aboutToRemoveText((*reinterpret_cast< KTextEditor::Range(*)>(_a[1]))); break;
        case 16: _t->dictionaryRangesPresent((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 17: _t->defaultDictionaryChanged((*reinterpret_cast< KTextEditor::DocumentPrivate*(*)>(_a[1]))); break;
        case 18: _t->loaded((*reinterpret_cast< KTextEditor::DocumentPrivate*(*)>(_a[1]))); break;
        case 19: { bool _r = _t->setText((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 20: { bool _r = _t->setText((*reinterpret_cast< const QStringList(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 21: { bool _r = _t->clear();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 22: { bool _r = _t->insertText((*reinterpret_cast< const KTextEditor::Cursor(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 23: { bool _r = _t->insertText((*reinterpret_cast< const KTextEditor::Cursor(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 24: { bool _r = _t->insertText((*reinterpret_cast< const KTextEditor::Cursor(*)>(_a[1])),(*reinterpret_cast< const QStringList(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 25: { bool _r = _t->insertText((*reinterpret_cast< const KTextEditor::Cursor(*)>(_a[1])),(*reinterpret_cast< const QStringList(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 26: { bool _r = _t->insertLine((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 27: { bool _r = _t->insertLines((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QStringList(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 28: { bool _r = _t->removeText((*reinterpret_cast< const KTextEditor::Range(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 29: { bool _r = _t->removeText((*reinterpret_cast< const KTextEditor::Range(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 30: { bool _r = _t->removeLine((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 31: { bool _r = _t->replaceText((*reinterpret_cast< const KTextEditor::Range(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 32: { bool _r = _t->replaceText((*reinterpret_cast< const KTextEditor::Range(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 33: { bool _r = _t->replaceText((*reinterpret_cast< const KTextEditor::Range(*)>(_a[1])),(*reinterpret_cast< const QStringList(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 34: _t->undo(); break;
        case 35: _t->redo(); break;
        case 36: _t->clearEditingPosStack(); break;
        case 37: _t->saveEditingPositions((*reinterpret_cast< const KTextEditor::Cursor(*)>(_a[1]))); break;
        case 38: _t->setMark((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< uint(*)>(_a[2]))); break;
        case 39: _t->clearMark((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 40: _t->addMark((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< uint(*)>(_a[2]))); break;
        case 41: _t->removeMark((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< uint(*)>(_a[2]))); break;
        case 42: _t->clearMarks(); break;
        case 43: _t->requestMarkTooltip((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< QPoint(*)>(_a[2]))); break;
        case 44: { bool _r = _t->handleMarkClick((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 45: { bool _r = _t->handleMarkContextMenu((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< QPoint(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 46: _t->setMarkPixmap((*reinterpret_cast< MarkInterface::MarkTypes(*)>(_a[1])),(*reinterpret_cast< const QPixmap(*)>(_a[2]))); break;
        case 47: _t->setMarkDescription((*reinterpret_cast< MarkInterface::MarkTypes(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 48: _t->setEditableMarks((*reinterpret_cast< uint(*)>(_a[1]))); break;
        case 49: _t->setMarkIcon((*reinterpret_cast< MarkInterface::MarkTypes(*)>(_a[1])),(*reinterpret_cast< const QIcon(*)>(_a[2]))); break;
        case 50: { bool _r = _t->print();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 51: _t->printPreview(); break;
        case 52: _t->autoReloadToggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 53: _t->tagLines((*reinterpret_cast< KTextEditor::LineRange(*)>(_a[1]))); break;
        case 54: _t->tagLine((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 55: _t->internalHlChanged(); break;
        case 56: _t->slotModifiedOnDisk((*reinterpret_cast< KTextEditor::View*(*)>(_a[1]))); break;
        case 57: _t->slotModifiedOnDisk(); break;
        case 58: { bool _r = _t->documentReload();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 59: { bool _r = _t->documentSave();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 60: { bool _r = _t->documentSaveAs();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 61: { bool _r = _t->documentSaveAsWithEncoding((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 62: _t->documentSaveCopyAs(); break;
        case 63: { bool _r = _t->save();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 64: _t->onModOnHdSaveAs(); break;
        case 65: _t->onModOnHdClose(); break;
        case 66: _t->onModOnHdReload(); break;
        case 67: _t->onModOnHdAutoReload(); break;
        case 68: _t->onModOnHdIgnore(); break;
        case 69: _t->setWordWrap((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 70: _t->setWordWrapAt((*reinterpret_cast< uint(*)>(_a[1]))); break;
        case 71: _t->setPageUpDownMovesCursor((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 72: _t->slotModOnHdDirty((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 73: _t->slotModOnHdCreated((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 74: _t->slotModOnHdDeleted((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 75: _t->slotDelayedHandleModOnHd(); break;
        case 76: _t->slotQueryClose_save((*reinterpret_cast< bool*(*)>(_a[1])),(*reinterpret_cast< bool*(*)>(_a[2]))); break;
        case 77: _t->messageDestroyed((*reinterpret_cast< KTextEditor::Message*(*)>(_a[1]))); break;
        case 78: _t->clearDictionaryRanges(); break;
        case 79: _t->setDictionary((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< KTextEditor::Range(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3]))); break;
        case 80: _t->setDictionary((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< KTextEditor::Range(*)>(_a[2]))); break;
        case 81: _t->setDefaultDictionary((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 82: _t->onTheFlySpellCheckingEnabled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 83: _t->refreshOnTheFlyCheck((*reinterpret_cast< KTextEditor::Range(*)>(_a[1]))); break;
        case 84: _t->refreshOnTheFlyCheck(); break;
        case 85: _t->slotStarted((*reinterpret_cast< KIO::Job*(*)>(_a[1]))); break;
        case 86: _t->slotCompleted(); break;
        case 87: _t->slotCanceled(); break;
        case 88: _t->slotTriggerLoadingMessage(); break;
        case 89: _t->slotAbortLoading(); break;
        case 90: _t->slotUrlChanged((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
        case 91: _t->openWithLineLengthLimitOverride(); break;
        case 92: _t->checkCursorForAutobrace((*reinterpret_cast< KTextEditor::View*(*)>(_a[1])),(*reinterpret_cast< const KTextEditor::Cursor(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Cursor >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Range >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Range >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::AnnotationModel* >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            }
            break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Range >(); break;
            }
            break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::DocumentPrivate* >(); break;
            }
            break;
        case 18:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::DocumentPrivate* >(); break;
            }
            break;
        case 22:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Cursor >(); break;
            }
            break;
        case 23:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Cursor >(); break;
            }
            break;
        case 24:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Cursor >(); break;
            }
            break;
        case 25:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Cursor >(); break;
            }
            break;
        case 28:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Range >(); break;
            }
            break;
        case 29:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Range >(); break;
            }
            break;
        case 31:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Range >(); break;
            }
            break;
        case 32:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Range >(); break;
            }
            break;
        case 33:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Range >(); break;
            }
            break;
        case 37:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Cursor >(); break;
            }
            break;
        case 53:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::LineRange >(); break;
            }
            break;
        case 56:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::View* >(); break;
            }
            break;
        case 77:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Message* >(); break;
            }
            break;
        case 79:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Range >(); break;
            }
            break;
        case 80:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Range >(); break;
            }
            break;
        case 83:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Range >(); break;
            }
            break;
        case 92:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Cursor >(); break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::View* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (DocumentPrivate::*)(const KTextEditor::Cursor & , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DocumentPrivate::charactersSemiInteractivelyInserted)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (DocumentPrivate::*)(KTextEditor::Document * , const KTextEditor::Range & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DocumentPrivate::textInsertedRange)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (DocumentPrivate::*)(KTextEditor::Document * , const KTextEditor::Range & , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DocumentPrivate::textRemoved)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (DocumentPrivate::*)(int , int , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DocumentPrivate::editLineWrapped)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (DocumentPrivate::*)(int , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DocumentPrivate::editLineUnWrapped)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (DocumentPrivate::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DocumentPrivate::undoChanged)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (DocumentPrivate::*)(KTextEditor::Document * , KTextEditor::Mark , QPoint , bool & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DocumentPrivate::markToolTipRequested)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (DocumentPrivate::*)(KTextEditor::Document * , KTextEditor::Mark , QPoint , bool & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DocumentPrivate::markContextMenuRequested)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (DocumentPrivate::*)(KTextEditor::Document * , KTextEditor::Mark , bool & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DocumentPrivate::markClicked)) {
                *result = 8;
                return;
            }
        }
        {
            using _t = void (DocumentPrivate::*)(KTextEditor::Document * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DocumentPrivate::marksChanged)) {
                *result = 9;
                return;
            }
        }
        {
            using _t = void (DocumentPrivate::*)(KTextEditor::Document * , KTextEditor::Mark , KTextEditor::MarkInterface::MarkChangeAction );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DocumentPrivate::markChanged)) {
                *result = 10;
                return;
            }
        }
        {
            using _t = void (DocumentPrivate::*)(KTextEditor::Document * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DocumentPrivate::aboutToDeleteMovingInterfaceContent)) {
                *result = 11;
                return;
            }
        }
        {
            using _t = void (DocumentPrivate::*)(KTextEditor::Document * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DocumentPrivate::aboutToInvalidateMovingInterfaceContent)) {
                *result = 12;
                return;
            }
        }
        {
            using _t = void (DocumentPrivate::*)(KTextEditor::AnnotationModel * , KTextEditor::AnnotationModel * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DocumentPrivate::annotationModelChanged)) {
                *result = 13;
                return;
            }
        }
        {
            using _t = void (DocumentPrivate::*)(KTextEditor::Document * , bool , KTextEditor::ModificationInterface::ModifiedOnDiskReason );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DocumentPrivate::modifiedOnDisk)) {
                *result = 14;
                return;
            }
        }
        {
            using _t = void (DocumentPrivate::*)(KTextEditor::Range );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DocumentPrivate::aboutToRemoveText)) {
                *result = 15;
                return;
            }
        }
        {
            using _t = void (DocumentPrivate::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DocumentPrivate::dictionaryRangesPresent)) {
                *result = 16;
                return;
            }
        }
        {
            using _t = void (DocumentPrivate::*)(KTextEditor::DocumentPrivate * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DocumentPrivate::defaultDictionaryChanged)) {
                *result = 17;
                return;
            }
        }
        {
            using _t = void (DocumentPrivate::*)(KTextEditor::DocumentPrivate * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DocumentPrivate::loaded)) {
                *result = 18;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject KTextEditor::DocumentPrivate::staticMetaObject = { {
    QMetaObject::SuperData::link<KTextEditor::Document::staticMetaObject>(),
    qt_meta_stringdata_KTextEditor__DocumentPrivate.data,
    qt_meta_data_KTextEditor__DocumentPrivate,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *KTextEditor::DocumentPrivate::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KTextEditor::DocumentPrivate::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KTextEditor__DocumentPrivate.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "KTextEditor::MarkInterfaceV2"))
        return static_cast< KTextEditor::MarkInterfaceV2*>(this);
    if (!strcmp(_clname, "KTextEditor::ModificationInterface"))
        return static_cast< KTextEditor::ModificationInterface*>(this);
    if (!strcmp(_clname, "KTextEditor::ConfigInterface"))
        return static_cast< KTextEditor::ConfigInterface*>(this);
    if (!strcmp(_clname, "KTextEditor::AnnotationInterface"))
        return static_cast< KTextEditor::AnnotationInterface*>(this);
    if (!strcmp(_clname, "KTextEditor::MovingInterface"))
        return static_cast< KTextEditor::MovingInterface*>(this);
    if (!strcmp(_clname, "org.kde.KTextEditor.MarkInterface"))
        return static_cast< KTextEditor::MarkInterface*>(this);
    if (!strcmp(_clname, "org.kde.KTextEditor.MarkInterfaceV2"))
        return static_cast< KTextEditor::MarkInterfaceV2*>(this);
    if (!strcmp(_clname, "org.kde.KTextEditor.ModificationInterface"))
        return static_cast< KTextEditor::ModificationInterface*>(this);
    if (!strcmp(_clname, "org.kde.KTextEditor.AnnotationInterface"))
        return static_cast< KTextEditor::AnnotationInterface*>(this);
    if (!strcmp(_clname, "org.kde.KTextEditor.ConfigInterface"))
        return static_cast< KTextEditor::ConfigInterface*>(this);
    if (!strcmp(_clname, "org.kde.KTextEditor.MovingInterface"))
        return static_cast< KTextEditor::MovingInterface*>(this);
    return KTextEditor::Document::qt_metacast(_clname);
}

int KTextEditor::DocumentPrivate::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KTextEditor::Document::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 93)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 93;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 93)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 93;
    }
    return _id;
}

// SIGNAL 0
void KTextEditor::DocumentPrivate::charactersSemiInteractivelyInserted(const KTextEditor::Cursor & _t1, const QString & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KTextEditor::DocumentPrivate::textInsertedRange(KTextEditor::Document * _t1, const KTextEditor::Range & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void KTextEditor::DocumentPrivate::textRemoved(KTextEditor::Document * _t1, const KTextEditor::Range & _t2, const QString & _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void KTextEditor::DocumentPrivate::editLineWrapped(int _t1, int _t2, int _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void KTextEditor::DocumentPrivate::editLineUnWrapped(int _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void KTextEditor::DocumentPrivate::undoChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void KTextEditor::DocumentPrivate::markToolTipRequested(KTextEditor::Document * _t1, KTextEditor::Mark _t2, QPoint _t3, bool & _t4)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t4))) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void KTextEditor::DocumentPrivate::markContextMenuRequested(KTextEditor::Document * _t1, KTextEditor::Mark _t2, QPoint _t3, bool & _t4)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t4))) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void KTextEditor::DocumentPrivate::markClicked(KTextEditor::Document * _t1, KTextEditor::Mark _t2, bool & _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}

// SIGNAL 9
void KTextEditor::DocumentPrivate::marksChanged(KTextEditor::Document * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 9, _a);
}

// SIGNAL 10
void KTextEditor::DocumentPrivate::markChanged(KTextEditor::Document * _t1, KTextEditor::Mark _t2, KTextEditor::MarkInterface::MarkChangeAction _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))) };
    QMetaObject::activate(this, &staticMetaObject, 10, _a);
}

// SIGNAL 11
void KTextEditor::DocumentPrivate::aboutToDeleteMovingInterfaceContent(KTextEditor::Document * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 11, _a);
}

// SIGNAL 12
void KTextEditor::DocumentPrivate::aboutToInvalidateMovingInterfaceContent(KTextEditor::Document * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 12, _a);
}

// SIGNAL 13
void KTextEditor::DocumentPrivate::annotationModelChanged(KTextEditor::AnnotationModel * _t1, KTextEditor::AnnotationModel * _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 13, _a);
}

// SIGNAL 14
void KTextEditor::DocumentPrivate::modifiedOnDisk(KTextEditor::Document * _t1, bool _t2, KTextEditor::ModificationInterface::ModifiedOnDiskReason _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))) };
    QMetaObject::activate(this, &staticMetaObject, 14, _a);
}

// SIGNAL 15
void KTextEditor::DocumentPrivate::aboutToRemoveText(KTextEditor::Range _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 15, _a);
}

// SIGNAL 16
void KTextEditor::DocumentPrivate::dictionaryRangesPresent(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 16, _a);
}

// SIGNAL 17
void KTextEditor::DocumentPrivate::defaultDictionaryChanged(KTextEditor::DocumentPrivate * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 17, _a);
}

// SIGNAL 18
void KTextEditor::DocumentPrivate::loaded(KTextEditor::DocumentPrivate * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 18, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
