/****************************************************************************
** Meta object code from reading C++ file 'view.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../ktexteditor-5.116.0/src/include/ktexteditor/view.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'view.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KTextEditor__View_t {
    QByteArrayData data[28];
    char stringdata0[428];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KTextEditor__View_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KTextEditor__View_t qt_meta_stringdata_KTextEditor__View = {
    {
QT_MOC_LITERAL(0, 0, 17), // "KTextEditor::View"
QT_MOC_LITERAL(1, 18, 7), // "focusIn"
QT_MOC_LITERAL(2, 26, 0), // ""
QT_MOC_LITERAL(3, 27, 18), // "KTextEditor::View*"
QT_MOC_LITERAL(4, 46, 4), // "view"
QT_MOC_LITERAL(5, 51, 8), // "focusOut"
QT_MOC_LITERAL(6, 60, 15), // "viewModeChanged"
QT_MOC_LITERAL(7, 76, 27), // "KTextEditor::View::ViewMode"
QT_MOC_LITERAL(8, 104, 4), // "mode"
QT_MOC_LITERAL(9, 109, 20), // "viewInputModeChanged"
QT_MOC_LITERAL(10, 130, 28), // "KTextEditor::View::InputMode"
QT_MOC_LITERAL(11, 159, 12), // "textInserted"
QT_MOC_LITERAL(12, 172, 19), // "KTextEditor::Cursor"
QT_MOC_LITERAL(13, 192, 8), // "position"
QT_MOC_LITERAL(14, 201, 4), // "text"
QT_MOC_LITERAL(15, 206, 22), // "contextMenuAboutToShow"
QT_MOC_LITERAL(16, 229, 6), // "QMenu*"
QT_MOC_LITERAL(17, 236, 4), // "menu"
QT_MOC_LITERAL(18, 241, 21), // "cursorPositionChanged"
QT_MOC_LITERAL(19, 263, 11), // "newPosition"
QT_MOC_LITERAL(20, 275, 29), // "verticalScrollPositionChanged"
QT_MOC_LITERAL(21, 305, 6), // "newPos"
QT_MOC_LITERAL(22, 312, 31), // "horizontalScrollPositionChanged"
QT_MOC_LITERAL(23, 344, 20), // "mousePositionChanged"
QT_MOC_LITERAL(24, 365, 16), // "selectionChanged"
QT_MOC_LITERAL(25, 382, 23), // "statusBarEnabledChanged"
QT_MOC_LITERAL(26, 406, 7), // "enabled"
QT_MOC_LITERAL(27, 414, 13) // "configChanged"

    },
    "KTextEditor::View\0focusIn\0\0"
    "KTextEditor::View*\0view\0focusOut\0"
    "viewModeChanged\0KTextEditor::View::ViewMode\0"
    "mode\0viewInputModeChanged\0"
    "KTextEditor::View::InputMode\0textInserted\0"
    "KTextEditor::Cursor\0position\0text\0"
    "contextMenuAboutToShow\0QMenu*\0menu\0"
    "cursorPositionChanged\0newPosition\0"
    "verticalScrollPositionChanged\0newPos\0"
    "horizontalScrollPositionChanged\0"
    "mousePositionChanged\0selectionChanged\0"
    "statusBarEnabledChanged\0enabled\0"
    "configChanged"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KTextEditor__View[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      13,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      13,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   79,    2, 0x06 /* Public */,
       5,    1,   82,    2, 0x06 /* Public */,
       6,    2,   85,    2, 0x06 /* Public */,
       9,    2,   90,    2, 0x06 /* Public */,
      11,    3,   95,    2, 0x06 /* Public */,
      15,    2,  102,    2, 0x06 /* Public */,
      18,    2,  107,    2, 0x06 /* Public */,
      20,    2,  112,    2, 0x06 /* Public */,
      22,    1,  117,    2, 0x06 /* Public */,
      23,    2,  120,    2, 0x06 /* Public */,
      24,    1,  125,    2, 0x06 /* Public */,
      25,    2,  128,    2, 0x06 /* Public */,
      27,    1,  133,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 7,    4,    8,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 10,    4,    8,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 12, QMetaType::QString,    4,   13,   14,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 16,    4,   17,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 12,    4,   19,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 12,    4,   21,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 12,    4,   19,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3, QMetaType::Bool,    4,   26,
    QMetaType::Void, 0x80000000 | 3,    4,

       0        // eod
};

void KTextEditor::View::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<View *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->focusIn((*reinterpret_cast< KTextEditor::View*(*)>(_a[1]))); break;
        case 1: _t->focusOut((*reinterpret_cast< KTextEditor::View*(*)>(_a[1]))); break;
        case 2: _t->viewModeChanged((*reinterpret_cast< KTextEditor::View*(*)>(_a[1])),(*reinterpret_cast< KTextEditor::View::ViewMode(*)>(_a[2]))); break;
        case 3: _t->viewInputModeChanged((*reinterpret_cast< KTextEditor::View*(*)>(_a[1])),(*reinterpret_cast< KTextEditor::View::InputMode(*)>(_a[2]))); break;
        case 4: _t->textInserted((*reinterpret_cast< KTextEditor::View*(*)>(_a[1])),(*reinterpret_cast< const KTextEditor::Cursor(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 5: _t->contextMenuAboutToShow((*reinterpret_cast< KTextEditor::View*(*)>(_a[1])),(*reinterpret_cast< QMenu*(*)>(_a[2]))); break;
        case 6: _t->cursorPositionChanged((*reinterpret_cast< KTextEditor::View*(*)>(_a[1])),(*reinterpret_cast< const KTextEditor::Cursor(*)>(_a[2]))); break;
        case 7: _t->verticalScrollPositionChanged((*reinterpret_cast< KTextEditor::View*(*)>(_a[1])),(*reinterpret_cast< const KTextEditor::Cursor(*)>(_a[2]))); break;
        case 8: _t->horizontalScrollPositionChanged((*reinterpret_cast< KTextEditor::View*(*)>(_a[1]))); break;
        case 9: _t->mousePositionChanged((*reinterpret_cast< KTextEditor::View*(*)>(_a[1])),(*reinterpret_cast< const KTextEditor::Cursor(*)>(_a[2]))); break;
        case 10: _t->selectionChanged((*reinterpret_cast< KTextEditor::View*(*)>(_a[1]))); break;
        case 11: _t->statusBarEnabledChanged((*reinterpret_cast< KTextEditor::View*(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 12: _t->configChanged((*reinterpret_cast< KTextEditor::View*(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::View* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::View* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::View* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::View* >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Cursor >(); break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::View* >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::View* >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Cursor >(); break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::View* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Cursor >(); break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::View* >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::View* >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Cursor >(); break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::View* >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::View* >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::View* >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::View* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (View::*)(KTextEditor::View * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&View::focusIn)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (View::*)(KTextEditor::View * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&View::focusOut)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (View::*)(KTextEditor::View * , KTextEditor::View::ViewMode );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&View::viewModeChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (View::*)(KTextEditor::View * , KTextEditor::View::InputMode );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&View::viewInputModeChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (View::*)(KTextEditor::View * , const KTextEditor::Cursor & , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&View::textInserted)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (View::*)(KTextEditor::View * , QMenu * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&View::contextMenuAboutToShow)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (View::*)(KTextEditor::View * , const KTextEditor::Cursor & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&View::cursorPositionChanged)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (View::*)(KTextEditor::View * , const KTextEditor::Cursor & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&View::verticalScrollPositionChanged)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (View::*)(KTextEditor::View * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&View::horizontalScrollPositionChanged)) {
                *result = 8;
                return;
            }
        }
        {
            using _t = void (View::*)(KTextEditor::View * , const KTextEditor::Cursor & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&View::mousePositionChanged)) {
                *result = 9;
                return;
            }
        }
        {
            using _t = void (View::*)(KTextEditor::View * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&View::selectionChanged)) {
                *result = 10;
                return;
            }
        }
        {
            using _t = void (View::*)(KTextEditor::View * , bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&View::statusBarEnabledChanged)) {
                *result = 11;
                return;
            }
        }
        {
            using _t = void (View::*)(KTextEditor::View * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&View::configChanged)) {
                *result = 12;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject KTextEditor::View::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_meta_stringdata_KTextEditor__View.data,
    qt_meta_data_KTextEditor__View,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *KTextEditor::View::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KTextEditor::View::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KTextEditor__View.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "KXMLGUIClient"))
        return static_cast< KXMLGUIClient*>(this);
    return QWidget::qt_metacast(_clname);
}

int KTextEditor::View::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void KTextEditor::View::focusIn(KTextEditor::View * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KTextEditor::View::focusOut(KTextEditor::View * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void KTextEditor::View::viewModeChanged(KTextEditor::View * _t1, KTextEditor::View::ViewMode _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void KTextEditor::View::viewInputModeChanged(KTextEditor::View * _t1, KTextEditor::View::InputMode _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void KTextEditor::View::textInserted(KTextEditor::View * _t1, const KTextEditor::Cursor & _t2, const QString & _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void KTextEditor::View::contextMenuAboutToShow(KTextEditor::View * _t1, QMenu * _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void KTextEditor::View::cursorPositionChanged(KTextEditor::View * _t1, const KTextEditor::Cursor & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void KTextEditor::View::verticalScrollPositionChanged(KTextEditor::View * _t1, const KTextEditor::Cursor & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void KTextEditor::View::horizontalScrollPositionChanged(KTextEditor::View * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}

// SIGNAL 9
void KTextEditor::View::mousePositionChanged(KTextEditor::View * _t1, const KTextEditor::Cursor & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 9, _a);
}

// SIGNAL 10
void KTextEditor::View::selectionChanged(KTextEditor::View * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 10, _a);
}

// SIGNAL 11
void KTextEditor::View::statusBarEnabledChanged(KTextEditor::View * _t1, bool _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 11, _a);
}

// SIGNAL 12
void KTextEditor::View::configChanged(KTextEditor::View * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 12, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
