/****************************************************************************
** Meta object code from reading C++ file 'kateswapfile.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../ktexteditor-5.116.0/src/swapfile/kateswapfile.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kateswapfile.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Kate__SwapFile_t {
    QByteArrayData data[26];
    char stringdata0[295];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Kate__SwapFile_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Kate__SwapFile_t qt_meta_stringdata_Kate__SwapFile = {
    {
QT_MOC_LITERAL(0, 0, 14), // "Kate::SwapFile"
QT_MOC_LITERAL(1, 15, 9), // "fileSaved"
QT_MOC_LITERAL(2, 25, 0), // ""
QT_MOC_LITERAL(3, 26, 8), // "filename"
QT_MOC_LITERAL(4, 35, 10), // "fileLoaded"
QT_MOC_LITERAL(5, 46, 15), // "modifiedChanged"
QT_MOC_LITERAL(6, 62, 12), // "startEditing"
QT_MOC_LITERAL(7, 75, 13), // "finishEditing"
QT_MOC_LITERAL(8, 89, 8), // "wrapLine"
QT_MOC_LITERAL(9, 98, 19), // "KTextEditor::Cursor"
QT_MOC_LITERAL(10, 118, 8), // "position"
QT_MOC_LITERAL(11, 127, 10), // "unwrapLine"
QT_MOC_LITERAL(12, 138, 4), // "line"
QT_MOC_LITERAL(13, 143, 10), // "insertText"
QT_MOC_LITERAL(14, 154, 4), // "text"
QT_MOC_LITERAL(15, 159, 10), // "removeText"
QT_MOC_LITERAL(16, 170, 18), // "KTextEditor::Range"
QT_MOC_LITERAL(17, 189, 5), // "range"
QT_MOC_LITERAL(18, 195, 7), // "discard"
QT_MOC_LITERAL(19, 203, 7), // "recover"
QT_MOC_LITERAL(20, 211, 12), // "QDataStream&"
QT_MOC_LITERAL(21, 224, 11), // "checkDigest"
QT_MOC_LITERAL(22, 236, 13), // "configChanged"
QT_MOC_LITERAL(23, 250, 15), // "writeFileToDisk"
QT_MOC_LITERAL(24, 266, 19), // "showSwapFileMessage"
QT_MOC_LITERAL(25, 286, 8) // "showDiff"

    },
    "Kate::SwapFile\0fileSaved\0\0filename\0"
    "fileLoaded\0modifiedChanged\0startEditing\0"
    "finishEditing\0wrapLine\0KTextEditor::Cursor\0"
    "position\0unwrapLine\0line\0insertText\0"
    "text\0removeText\0KTextEditor::Range\0"
    "range\0discard\0recover\0QDataStream&\0"
    "checkDigest\0configChanged\0writeFileToDisk\0"
    "showSwapFileMessage\0showDiff"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Kate__SwapFile[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      17,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   99,    2, 0x09 /* Protected */,
       4,    1,  102,    2, 0x09 /* Protected */,
       5,    0,  105,    2, 0x09 /* Protected */,
       6,    0,  106,    2, 0x09 /* Protected */,
       7,    0,  107,    2, 0x09 /* Protected */,
       8,    1,  108,    2, 0x09 /* Protected */,
      11,    1,  111,    2, 0x09 /* Protected */,
      13,    2,  114,    2, 0x09 /* Protected */,
      15,    1,  119,    2, 0x09 /* Protected */,
      18,    0,  122,    2, 0x0a /* Public */,
      19,    0,  123,    2, 0x0a /* Public */,
      19,    2,  124,    2, 0x0a /* Public */,
      19,    1,  129,    2, 0x2a /* Public | MethodCloned */,
      22,    0,  132,    2, 0x0a /* Public */,
      23,    0,  133,    2, 0x09 /* Protected */,
      24,    0,  134,    2, 0x0a /* Public */,
      25,    0,  135,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 9,   10,
    QMetaType::Void, QMetaType::Int,   12,
    QMetaType::Void, 0x80000000 | 9, QMetaType::QString,   10,   14,
    QMetaType::Void, 0x80000000 | 16,   17,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Bool, 0x80000000 | 20, QMetaType::Bool,    2,   21,
    QMetaType::Bool, 0x80000000 | 20,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void Kate::SwapFile::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<SwapFile *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->fileSaved((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->fileLoaded((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->modifiedChanged(); break;
        case 3: _t->startEditing(); break;
        case 4: _t->finishEditing(); break;
        case 5: _t->wrapLine((*reinterpret_cast< const KTextEditor::Cursor(*)>(_a[1]))); break;
        case 6: _t->unwrapLine((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 7: _t->insertText((*reinterpret_cast< const KTextEditor::Cursor(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 8: _t->removeText((*reinterpret_cast< KTextEditor::Range(*)>(_a[1]))); break;
        case 9: _t->discard(); break;
        case 10: _t->recover(); break;
        case 11: { bool _r = _t->recover((*reinterpret_cast< QDataStream(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 12: { bool _r = _t->recover((*reinterpret_cast< QDataStream(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 13: _t->configChanged(); break;
        case 14: _t->writeFileToDisk(); break;
        case 15: _t->showSwapFileMessage(); break;
        case 16: _t->showDiff(); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject Kate::SwapFile::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_Kate__SwapFile.data,
    qt_meta_data_Kate__SwapFile,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Kate::SwapFile::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kate::SwapFile::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Kate__SwapFile.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Kate::SwapFile::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 17;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
