/*
    SPDX-FileCopyrightText: 2006 Matt Broadstone <mbroadst@gmail.com>

    SPDX-License-Identifier: LGPL-2.0-or-later
*/

#include <configinterface.h>

using namespace KTextEditor;

ConfigInterface::ConfigInterface() = default;

ConfigInterface::~ConfigInterface() = default;
