#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'opensaveconfigadvwidget.ui'
**
** Created by: Qt User Interface Compiler version 5.15.17
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPENSAVECONFIGADVWIDGET_H
#define UI_OPENSAVECONFIGADVWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_OpenSaveConfigAdvWidget
{
public:
    QVBoxLayout *verticalLayout;
    QFormLayout *formLayout_3;
    QCheckBox *chkAutoReloadVersionControl;
    QLabel *label;
    QCheckBox *chkBackupLocalFiles;
    QCheckBox *chkBackupRemoteFiles;
    QSpacerItem *verticalSpacer_2;
    QLabel *label_5;
    QLineEdit *edtBackupPrefix;
    QLabel *label_6;
    QLineEdit *edtBackupSuffix;
    QSpacerItem *verticalSpacer;
    QLabel *lblSwapFileMode;
    QComboBox *cmbSwapFileMode;
    QLabel *lblSwapDirectory;
    KUrlRequester *kurlSwapDirectory;
    QLabel *lblSwapFileSync;
    QSpinBox *spbSwapFileSync;
    QLabel *lblExplanatory;
    QSpacerItem *verticalSpacer_3;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *OpenSaveConfigAdvWidget)
    {
        if (OpenSaveConfigAdvWidget->objectName().isEmpty())
            OpenSaveConfigAdvWidget->setObjectName(QString::fromUtf8("OpenSaveConfigAdvWidget"));
        OpenSaveConfigAdvWidget->resize(585, 590);
        verticalLayout = new QVBoxLayout(OpenSaveConfigAdvWidget);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        formLayout_3 = new QFormLayout();
        formLayout_3->setObjectName(QString::fromUtf8("formLayout_3"));
        formLayout_3->setContentsMargins(-1, 0, -1, -1);
        chkAutoReloadVersionControl = new QCheckBox(OpenSaveConfigAdvWidget);
        chkAutoReloadVersionControl->setObjectName(QString::fromUtf8("chkAutoReloadVersionControl"));

        formLayout_3->setWidget(0, QFormLayout::FieldRole, chkAutoReloadVersionControl);

        label = new QLabel(OpenSaveConfigAdvWidget);
        label->setObjectName(QString::fromUtf8("label"));

        formLayout_3->setWidget(2, QFormLayout::LabelRole, label);

        chkBackupLocalFiles = new QCheckBox(OpenSaveConfigAdvWidget);
        chkBackupLocalFiles->setObjectName(QString::fromUtf8("chkBackupLocalFiles"));

        formLayout_3->setWidget(2, QFormLayout::FieldRole, chkBackupLocalFiles);

        chkBackupRemoteFiles = new QCheckBox(OpenSaveConfigAdvWidget);
        chkBackupRemoteFiles->setObjectName(QString::fromUtf8("chkBackupRemoteFiles"));

        formLayout_3->setWidget(3, QFormLayout::FieldRole, chkBackupRemoteFiles);

        verticalSpacer_2 = new QSpacerItem(20, 20, QSizePolicy::Minimum, QSizePolicy::Fixed);

        formLayout_3->setItem(4, QFormLayout::FieldRole, verticalSpacer_2);

        label_5 = new QLabel(OpenSaveConfigAdvWidget);
        label_5->setObjectName(QString::fromUtf8("label_5"));

        formLayout_3->setWidget(5, QFormLayout::LabelRole, label_5);

        edtBackupPrefix = new QLineEdit(OpenSaveConfigAdvWidget);
        edtBackupPrefix->setObjectName(QString::fromUtf8("edtBackupPrefix"));

        formLayout_3->setWidget(5, QFormLayout::FieldRole, edtBackupPrefix);

        label_6 = new QLabel(OpenSaveConfigAdvWidget);
        label_6->setObjectName(QString::fromUtf8("label_6"));

        formLayout_3->setWidget(6, QFormLayout::LabelRole, label_6);

        edtBackupSuffix = new QLineEdit(OpenSaveConfigAdvWidget);
        edtBackupSuffix->setObjectName(QString::fromUtf8("edtBackupSuffix"));

        formLayout_3->setWidget(6, QFormLayout::FieldRole, edtBackupSuffix);

        verticalSpacer = new QSpacerItem(20, 20, QSizePolicy::Minimum, QSizePolicy::Fixed);

        formLayout_3->setItem(7, QFormLayout::FieldRole, verticalSpacer);

        lblSwapFileMode = new QLabel(OpenSaveConfigAdvWidget);
        lblSwapFileMode->setObjectName(QString::fromUtf8("lblSwapFileMode"));

        formLayout_3->setWidget(8, QFormLayout::LabelRole, lblSwapFileMode);

        cmbSwapFileMode = new QComboBox(OpenSaveConfigAdvWidget);
        cmbSwapFileMode->addItem(QString());
        cmbSwapFileMode->addItem(QString());
        cmbSwapFileMode->addItem(QString());
        cmbSwapFileMode->setObjectName(QString::fromUtf8("cmbSwapFileMode"));

        formLayout_3->setWidget(8, QFormLayout::FieldRole, cmbSwapFileMode);

        lblSwapDirectory = new QLabel(OpenSaveConfigAdvWidget);
        lblSwapDirectory->setObjectName(QString::fromUtf8("lblSwapDirectory"));

        formLayout_3->setWidget(9, QFormLayout::LabelRole, lblSwapDirectory);

        kurlSwapDirectory = new KUrlRequester(OpenSaveConfigAdvWidget);
        kurlSwapDirectory->setObjectName(QString::fromUtf8("kurlSwapDirectory"));
        kurlSwapDirectory->setEnabled(false);
        kurlSwapDirectory->setMode(KFile::Directory|KFile::LocalOnly);

        formLayout_3->setWidget(9, QFormLayout::FieldRole, kurlSwapDirectory);

        lblSwapFileSync = new QLabel(OpenSaveConfigAdvWidget);
        lblSwapFileSync->setObjectName(QString::fromUtf8("lblSwapFileSync"));

        formLayout_3->setWidget(10, QFormLayout::LabelRole, lblSwapFileSync);

        spbSwapFileSync = new QSpinBox(OpenSaveConfigAdvWidget);
        spbSwapFileSync->setObjectName(QString::fromUtf8("spbSwapFileSync"));
        spbSwapFileSync->setMinimum(0);
        spbSwapFileSync->setMaximum(600);
        spbSwapFileSync->setSingleStep(10);
        spbSwapFileSync->setValue(15);

        formLayout_3->setWidget(10, QFormLayout::FieldRole, spbSwapFileSync);

        lblExplanatory = new QLabel(OpenSaveConfigAdvWidget);
        lblExplanatory->setObjectName(QString::fromUtf8("lblExplanatory"));
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(lblExplanatory->sizePolicy().hasHeightForWidth());
        lblExplanatory->setSizePolicy(sizePolicy);
        lblExplanatory->setTextFormat(Qt::AutoText);
        lblExplanatory->setWordWrap(true);

        formLayout_3->setWidget(11, QFormLayout::FieldRole, lblExplanatory);

        verticalSpacer_3 = new QSpacerItem(20, 20, QSizePolicy::Minimum, QSizePolicy::Expanding);

        formLayout_3->setItem(1, QFormLayout::FieldRole, verticalSpacer_3);


        verticalLayout->addLayout(formLayout_3);

        spacerItem = new QSpacerItem(0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(spacerItem);

#if QT_CONFIG(shortcut)
        label_5->setBuddy(edtBackupPrefix);
        label_6->setBuddy(edtBackupSuffix);
        lblSwapFileMode->setBuddy(cmbSwapFileMode);
        lblSwapDirectory->setBuddy(kurlSwapDirectory);
        lblSwapFileSync->setBuddy(spbSwapFileSync);
#endif // QT_CONFIG(shortcut)

        retranslateUi(OpenSaveConfigAdvWidget);

        QMetaObject::connectSlotsByName(OpenSaveConfigAdvWidget);
    } // setupUi

    void retranslateUi(QWidget *OpenSaveConfigAdvWidget)
    {
        chkAutoReloadVersionControl->setText(tr2i18n("Auto reload files in version control", nullptr));
        label->setText(tr2i18n("Write a backup file on save for:", nullptr));
#if QT_CONFIG(whatsthis)
        chkBackupLocalFiles->setWhatsThis(tr2i18n("If this option is enabled, backups for local files will be created when saving.", nullptr));
#endif // QT_CONFIG(whatsthis)
        chkBackupLocalFiles->setText(tr2i18n("&Local files", nullptr));
#if QT_CONFIG(whatsthis)
        chkBackupRemoteFiles->setWhatsThis(tr2i18n("If this option is enabled, backups for remote files will be created when saving.", nullptr));
#endif // QT_CONFIG(whatsthis)
        chkBackupRemoteFiles->setText(tr2i18n("&Remote files", nullptr));
        label_5->setText(tr2i18n("Prefix for backup files:", nullptr));
#if QT_CONFIG(whatsthis)
        edtBackupPrefix->setWhatsThis(tr2i18n("Enter the prefix to prepend to the backup file names.", nullptr));
#endif // QT_CONFIG(whatsthis)
        label_6->setText(tr2i18n("Suffix for backup files:", nullptr));
#if QT_CONFIG(whatsthis)
        edtBackupSuffix->setWhatsThis(tr2i18n("Enter the suffix to append to the backup file names.", nullptr));
#endif // QT_CONFIG(whatsthis)
        lblSwapFileMode->setText(tr2i18n("Swap file mode:", nullptr));
        cmbSwapFileMode->setItemText(0, tr2i18n("Disabled", nullptr));
        cmbSwapFileMode->setItemText(1, tr2i18n("Enabled, Store In Default Directory", nullptr));
        cmbSwapFileMode->setItemText(2, tr2i18n("Enabled, Store In Custom Directory", nullptr));

        lblSwapDirectory->setText(tr2i18n("Store swap files in:", nullptr));
        lblSwapFileSync->setText(tr2i18n("Save swap files every:", nullptr));
        spbSwapFileSync->setSpecialValueText(tr2i18n("Disabled", nullptr));
        spbSwapFileSync->setSuffix(tr2i18n("s", nullptr));
        lblExplanatory->setText(tr2i18n("This string is located in katedialogs.cpp in KateSaveConfigTab's constructor.", nullptr));
        (void)OpenSaveConfigAdvWidget;
    } // retranslateUi

};

namespace Ui {
    class OpenSaveConfigAdvWidget: public Ui_OpenSaveConfigAdvWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OPENSAVECONFIGADVWIDGET_H

