/****************************************************************************
** Meta object code from reading C++ file 'normalvimode.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../ktexteditor-5.116.0/src/vimode/modes/normalvimode.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'normalvimode.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KateVi__NormalViMode_t {
    QByteArrayData data[13];
    char stringdata0[209];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KateVi__NormalViMode_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KateVi__NormalViMode_t qt_meta_stringdata_KateVi__NormalViMode = {
    {
QT_MOC_LITERAL(0, 0, 20), // "KateVi::NormalViMode"
QT_MOC_LITERAL(1, 21, 12), // "textInserted"
QT_MOC_LITERAL(2, 34, 0), // ""
QT_MOC_LITERAL(3, 35, 22), // "KTextEditor::Document*"
QT_MOC_LITERAL(4, 58, 8), // "document"
QT_MOC_LITERAL(5, 67, 18), // "KTextEditor::Range"
QT_MOC_LITERAL(6, 86, 5), // "range"
QT_MOC_LITERAL(7, 92, 11), // "textRemoved"
QT_MOC_LITERAL(8, 104, 13), // "undoBeginning"
QT_MOC_LITERAL(9, 118, 9), // "undoEnded"
QT_MOC_LITERAL(10, 128, 25), // "updateYankHighlightAttrib"
QT_MOC_LITERAL(11, 154, 18), // "clearYankHighlight"
QT_MOC_LITERAL(12, 173, 35) // "aboutToDeleteMovingInterfaceC..."

    },
    "KateVi::NormalViMode\0textInserted\0\0"
    "KTextEditor::Document*\0document\0"
    "KTextEditor::Range\0range\0textRemoved\0"
    "undoBeginning\0undoEnded\0"
    "updateYankHighlightAttrib\0clearYankHighlight\0"
    "aboutToDeleteMovingInterfaceContent"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KateVi__NormalViMode[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       7,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    2,   49,    2, 0x08 /* Private */,
       7,    2,   54,    2, 0x08 /* Private */,
       8,    0,   59,    2, 0x08 /* Private */,
       9,    0,   60,    2, 0x08 /* Private */,
      10,    0,   61,    2, 0x08 /* Private */,
      11,    0,   62,    2, 0x08 /* Private */,
      12,    0,   63,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 5,    4,    6,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 5,    2,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void KateVi::NormalViMode::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<NormalViMode *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->textInserted((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1])),(*reinterpret_cast< KTextEditor::Range(*)>(_a[2]))); break;
        case 1: _t->textRemoved((*reinterpret_cast< KTextEditor::Document*(*)>(_a[1])),(*reinterpret_cast< KTextEditor::Range(*)>(_a[2]))); break;
        case 2: _t->undoBeginning(); break;
        case 3: _t->undoEnded(); break;
        case 4: _t->updateYankHighlightAttrib(); break;
        case 5: _t->clearYankHighlight(); break;
        case 6: _t->aboutToDeleteMovingInterfaceContent(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Range >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Document* >(); break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Range >(); break;
            }
            break;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject KateVi::NormalViMode::staticMetaObject = { {
    QMetaObject::SuperData::link<ModeBase::staticMetaObject>(),
    qt_meta_stringdata_KateVi__NormalViMode.data,
    qt_meta_data_KateVi__NormalViMode,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *KateVi::NormalViMode::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateVi::NormalViMode::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KateVi__NormalViMode.stringdata0))
        return static_cast<void*>(this);
    return ModeBase::qt_metacast(_clname);
}

int KateVi::NormalViMode::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ModeBase::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
