/****************************************************************************
** Meta object code from reading C++ file 'appcommands.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../ktexteditor-5.116.0/src/vimode/appcommands.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'appcommands.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KateVi__AppCommands_t {
    QByteArrayData data[10];
    char stringdata0[162];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KateVi__AppCommands_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KateVi__AppCommands_t qt_meta_stringdata_KateVi__AppCommands = {
    {
QT_MOC_LITERAL(0, 0, 19), // "KateVi::AppCommands"
QT_MOC_LITERAL(1, 20, 20), // "closeCurrentDocument"
QT_MOC_LITERAL(2, 41, 0), // ""
QT_MOC_LITERAL(3, 42, 14), // "closeDocuments"
QT_MOC_LITERAL(4, 57, 29), // "QList<KTextEditor::Document*>"
QT_MOC_LITERAL(5, 87, 9), // "documents"
QT_MOC_LITERAL(6, 97, 16), // "closeCurrentView"
QT_MOC_LITERAL(7, 114, 21), // "closeCurrentSplitView"
QT_MOC_LITERAL(8, 136, 20), // "closeOtherSplitViews"
QT_MOC_LITERAL(9, 157, 4) // "quit"

    },
    "KateVi::AppCommands\0closeCurrentDocument\0"
    "\0closeDocuments\0QList<KTextEditor::Document*>\0"
    "documents\0closeCurrentView\0"
    "closeCurrentSplitView\0closeOtherSplitViews\0"
    "quit"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KateVi__AppCommands[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       6,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   44,    2, 0x08 /* Private */,
       3,    1,   45,    2, 0x08 /* Private */,
       6,    0,   48,    2, 0x08 /* Private */,
       7,    0,   49,    2, 0x08 /* Private */,
       8,    0,   50,    2, 0x08 /* Private */,
       9,    0,   51,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 4,    5,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void KateVi::AppCommands::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<AppCommands *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->closeCurrentDocument(); break;
        case 1: _t->closeDocuments((*reinterpret_cast< const QList<KTextEditor::Document*>(*)>(_a[1]))); break;
        case 2: _t->closeCurrentView(); break;
        case 3: _t->closeCurrentSplitView(); break;
        case 4: _t->closeOtherSplitViews(); break;
        case 5: _t->quit(); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject KateVi::AppCommands::staticMetaObject = { {
    QMetaObject::SuperData::link<KTextEditor::Command::staticMetaObject>(),
    qt_meta_stringdata_KateVi__AppCommands.data,
    qt_meta_data_KateVi__AppCommands,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *KateVi::AppCommands::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateVi::AppCommands::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KateVi__AppCommands.stringdata0))
        return static_cast<void*>(this);
    return KTextEditor::Command::qt_metacast(_clname);
}

int KateVi::AppCommands::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KTextEditor::Command::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 6;
    }
    return _id;
}
struct qt_meta_stringdata_KateVi__BufferCommands_t {
    QByteArrayData data[1];
    char stringdata0[23];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KateVi__BufferCommands_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KateVi__BufferCommands_t qt_meta_stringdata_KateVi__BufferCommands = {
    {
QT_MOC_LITERAL(0, 0, 22) // "KateVi::BufferCommands"

    },
    "KateVi::BufferCommands"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KateVi__BufferCommands[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void KateVi::BufferCommands::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject KateVi::BufferCommands::staticMetaObject = { {
    QMetaObject::SuperData::link<KTextEditor::Command::staticMetaObject>(),
    qt_meta_stringdata_KateVi__BufferCommands.data,
    qt_meta_data_KateVi__BufferCommands,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *KateVi::BufferCommands::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateVi::BufferCommands::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KateVi__BufferCommands.stringdata0))
        return static_cast<void*>(this);
    return KTextEditor::Command::qt_metacast(_clname);
}

int KateVi::BufferCommands::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KTextEditor::Command::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
