#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'textareaappearanceconfigwidget.ui'
**
** Created by: Qt User Interface Compiler version 5.15.17
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TEXTAREAAPPEARANCECONFIGWIDGET_H
#define UI_TEXTAREAAPPEARANCECONFIGWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "kfontrequester.h"

QT_BEGIN_NAMESPACE

class Ui_TextareaAppearanceConfigWidget
{
public:
    QVBoxLayout *vboxLayout;
    QFormLayout *formLayout_4;
    QLabel *label_3;
    KFontRequester *kfontrequester;
    QSpacerItem *verticalSpacer_5;
    QLabel *label;
    QComboBox *spacesComboBox;
    QLabel *lbMarkerDescription;
    QSlider *sliSetMarkerSize;
    QLabel *label_2;
    QCheckBox *chkShowTabs;
    QLabel *label_7;
    QCheckBox *chkFocusFrame;
    QSpacerItem *verticalSpacer;
    QLabel *label_4;
    QCheckBox *chkShowWholeBracketExpression;
    QCheckBox *chkShowBracketMatchPreview;
    QCheckBox *chkAnimateBracketMatching;
    QCheckBox *chkShowIndentationLines;
    QSpacerItem *verticalSpacer_7;
    QLabel *label_6;
    QCheckBox *chkShowWordCount;
    QCheckBox *chkShowLineCount;
    QSpacerItem *verticalSpacer_3;
    QCheckBox *chkFoldFirstLine;
    QSpacerItem *verticalSpacer_4;
    QCheckBox *cbxWordWrap;
    QCheckBox *chkDynWrapAtStaticMarker;
    QCheckBox *chkDynWrapAnywhere;
    QLabel *lblDynamicWordWrapIndicators;
    QComboBox *cmbDynamicWordWrapIndicator;
    QSpacerItem *verticalSpacer_6;
    QLabel *label_5;
    QCheckBox *cbxIndentWrappedLines;
    QLabel *lblDynamicWordWrapIndicators_2;
    QSpinBox *sbDynamicWordWrapDepth;
    QDoubleSpinBox *spbLineHeightMultiplier;
    QLabel *lblLineHeight;
    QSpacerItem *verticalSpacer_2;

    void setupUi(QWidget *TextareaAppearanceConfigWidget)
    {
        if (TextareaAppearanceConfigWidget->objectName().isEmpty())
            TextareaAppearanceConfigWidget->setObjectName(QString::fromUtf8("TextareaAppearanceConfigWidget"));
        TextareaAppearanceConfigWidget->resize(810, 831);
        vboxLayout = new QVBoxLayout(TextareaAppearanceConfigWidget);
        vboxLayout->setObjectName(QString::fromUtf8("vboxLayout"));
        formLayout_4 = new QFormLayout();
        formLayout_4->setObjectName(QString::fromUtf8("formLayout_4"));
        formLayout_4->setFieldGrowthPolicy(QFormLayout::FieldsStayAtSizeHint);
        formLayout_4->setFormAlignment(Qt::AlignHCenter|Qt::AlignTop);
        formLayout_4->setContentsMargins(-1, 10, -1, -1);
        label_3 = new QLabel(TextareaAppearanceConfigWidget);
        label_3->setObjectName(QString::fromUtf8("label_3"));

        formLayout_4->setWidget(0, QFormLayout::LabelRole, label_3);

        kfontrequester = new KFontRequester(TextareaAppearanceConfigWidget);
        kfontrequester->setObjectName(QString::fromUtf8("kfontrequester"));
        QSizePolicy sizePolicy(QSizePolicy::Minimum, QSizePolicy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(kfontrequester->sizePolicy().hasHeightForWidth());
        kfontrequester->setSizePolicy(sizePolicy);

        formLayout_4->setWidget(0, QFormLayout::FieldRole, kfontrequester);

        verticalSpacer_5 = new QSpacerItem(10, 10, QSizePolicy::Minimum, QSizePolicy::Fixed);

        formLayout_4->setItem(3, QFormLayout::LabelRole, verticalSpacer_5);

        label = new QLabel(TextareaAppearanceConfigWidget);
        label->setObjectName(QString::fromUtf8("label"));

        formLayout_4->setWidget(4, QFormLayout::LabelRole, label);

        spacesComboBox = new QComboBox(TextareaAppearanceConfigWidget);
        spacesComboBox->addItem(QString());
        spacesComboBox->addItem(QString());
        spacesComboBox->addItem(QString());
        spacesComboBox->setObjectName(QString::fromUtf8("spacesComboBox"));

        formLayout_4->setWidget(4, QFormLayout::FieldRole, spacesComboBox);

        lbMarkerDescription = new QLabel(TextareaAppearanceConfigWidget);
        lbMarkerDescription->setObjectName(QString::fromUtf8("lbMarkerDescription"));

        formLayout_4->setWidget(5, QFormLayout::LabelRole, lbMarkerDescription);

        sliSetMarkerSize = new QSlider(TextareaAppearanceConfigWidget);
        sliSetMarkerSize->setObjectName(QString::fromUtf8("sliSetMarkerSize"));
        QSizePolicy sizePolicy1(QSizePolicy::Expanding, QSizePolicy::Expanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(sliSetMarkerSize->sizePolicy().hasHeightForWidth());
        sliSetMarkerSize->setSizePolicy(sizePolicy1);
        sliSetMarkerSize->setMinimum(1);
        sliSetMarkerSize->setMaximum(5);
        sliSetMarkerSize->setSingleStep(1);
        sliSetMarkerSize->setPageStep(1);
        sliSetMarkerSize->setOrientation(Qt::Horizontal);
        sliSetMarkerSize->setTickPosition(QSlider::TicksBothSides);
        sliSetMarkerSize->setTickInterval(1);

        formLayout_4->setWidget(5, QFormLayout::FieldRole, sliSetMarkerSize);

        label_2 = new QLabel(TextareaAppearanceConfigWidget);
        label_2->setObjectName(QString::fromUtf8("label_2"));

        formLayout_4->setWidget(7, QFormLayout::LabelRole, label_2);

        chkShowTabs = new QCheckBox(TextareaAppearanceConfigWidget);
        chkShowTabs->setObjectName(QString::fromUtf8("chkShowTabs"));

        formLayout_4->setWidget(7, QFormLayout::FieldRole, chkShowTabs);

        label_7 = new QLabel(TextareaAppearanceConfigWidget);
        label_7->setObjectName(QString::fromUtf8("label_7"));

        formLayout_4->setWidget(8, QFormLayout::LabelRole, label_7);

        chkFocusFrame = new QCheckBox(TextareaAppearanceConfigWidget);
        chkFocusFrame->setObjectName(QString::fromUtf8("chkFocusFrame"));

        formLayout_4->setWidget(8, QFormLayout::FieldRole, chkFocusFrame);

        verticalSpacer = new QSpacerItem(10, 10, QSizePolicy::Minimum, QSizePolicy::Fixed);

        formLayout_4->setItem(9, QFormLayout::LabelRole, verticalSpacer);

        label_4 = new QLabel(TextareaAppearanceConfigWidget);
        label_4->setObjectName(QString::fromUtf8("label_4"));

        formLayout_4->setWidget(10, QFormLayout::LabelRole, label_4);

        chkShowWholeBracketExpression = new QCheckBox(TextareaAppearanceConfigWidget);
        chkShowWholeBracketExpression->setObjectName(QString::fromUtf8("chkShowWholeBracketExpression"));

        formLayout_4->setWidget(10, QFormLayout::FieldRole, chkShowWholeBracketExpression);

        chkShowBracketMatchPreview = new QCheckBox(TextareaAppearanceConfigWidget);
        chkShowBracketMatchPreview->setObjectName(QString::fromUtf8("chkShowBracketMatchPreview"));

        formLayout_4->setWidget(11, QFormLayout::FieldRole, chkShowBracketMatchPreview);

        chkAnimateBracketMatching = new QCheckBox(TextareaAppearanceConfigWidget);
        chkAnimateBracketMatching->setObjectName(QString::fromUtf8("chkAnimateBracketMatching"));

        formLayout_4->setWidget(12, QFormLayout::FieldRole, chkAnimateBracketMatching);

        chkShowIndentationLines = new QCheckBox(TextareaAppearanceConfigWidget);
        chkShowIndentationLines->setObjectName(QString::fromUtf8("chkShowIndentationLines"));

        formLayout_4->setWidget(13, QFormLayout::FieldRole, chkShowIndentationLines);

        verticalSpacer_7 = new QSpacerItem(10, 10, QSizePolicy::Minimum, QSizePolicy::Fixed);

        formLayout_4->setItem(15, QFormLayout::LabelRole, verticalSpacer_7);

        label_6 = new QLabel(TextareaAppearanceConfigWidget);
        label_6->setObjectName(QString::fromUtf8("label_6"));

        formLayout_4->setWidget(16, QFormLayout::LabelRole, label_6);

        chkShowWordCount = new QCheckBox(TextareaAppearanceConfigWidget);
        chkShowWordCount->setObjectName(QString::fromUtf8("chkShowWordCount"));

        formLayout_4->setWidget(16, QFormLayout::FieldRole, chkShowWordCount);

        chkShowLineCount = new QCheckBox(TextareaAppearanceConfigWidget);
        chkShowLineCount->setObjectName(QString::fromUtf8("chkShowLineCount"));

        formLayout_4->setWidget(17, QFormLayout::FieldRole, chkShowLineCount);

        verticalSpacer_3 = new QSpacerItem(10, 10, QSizePolicy::Minimum, QSizePolicy::Fixed);

        formLayout_4->setItem(18, QFormLayout::LabelRole, verticalSpacer_3);

        chkFoldFirstLine = new QCheckBox(TextareaAppearanceConfigWidget);
        chkFoldFirstLine->setObjectName(QString::fromUtf8("chkFoldFirstLine"));

        formLayout_4->setWidget(19, QFormLayout::FieldRole, chkFoldFirstLine);

        verticalSpacer_4 = new QSpacerItem(10, 10, QSizePolicy::Minimum, QSizePolicy::Expanding);

        formLayout_4->setItem(20, QFormLayout::LabelRole, verticalSpacer_4);

        cbxWordWrap = new QCheckBox(TextareaAppearanceConfigWidget);
        cbxWordWrap->setObjectName(QString::fromUtf8("cbxWordWrap"));

        formLayout_4->setWidget(21, QFormLayout::LabelRole, cbxWordWrap);

        chkDynWrapAtStaticMarker = new QCheckBox(TextareaAppearanceConfigWidget);
        chkDynWrapAtStaticMarker->setObjectName(QString::fromUtf8("chkDynWrapAtStaticMarker"));

        formLayout_4->setWidget(21, QFormLayout::FieldRole, chkDynWrapAtStaticMarker);

        chkDynWrapAnywhere = new QCheckBox(TextareaAppearanceConfigWidget);
        chkDynWrapAnywhere->setObjectName(QString::fromUtf8("chkDynWrapAnywhere"));

        formLayout_4->setWidget(22, QFormLayout::FieldRole, chkDynWrapAnywhere);

        lblDynamicWordWrapIndicators = new QLabel(TextareaAppearanceConfigWidget);
        lblDynamicWordWrapIndicators->setObjectName(QString::fromUtf8("lblDynamicWordWrapIndicators"));

        formLayout_4->setWidget(23, QFormLayout::LabelRole, lblDynamicWordWrapIndicators);

        cmbDynamicWordWrapIndicator = new QComboBox(TextareaAppearanceConfigWidget);
        cmbDynamicWordWrapIndicator->setObjectName(QString::fromUtf8("cmbDynamicWordWrapIndicator"));

        formLayout_4->setWidget(23, QFormLayout::FieldRole, cmbDynamicWordWrapIndicator);

        verticalSpacer_6 = new QSpacerItem(10, 10, QSizePolicy::Minimum, QSizePolicy::Fixed);

        formLayout_4->setItem(24, QFormLayout::FieldRole, verticalSpacer_6);

        label_5 = new QLabel(TextareaAppearanceConfigWidget);
        label_5->setObjectName(QString::fromUtf8("label_5"));

        formLayout_4->setWidget(25, QFormLayout::LabelRole, label_5);

        cbxIndentWrappedLines = new QCheckBox(TextareaAppearanceConfigWidget);
        cbxIndentWrappedLines->setObjectName(QString::fromUtf8("cbxIndentWrappedLines"));

        formLayout_4->setWidget(25, QFormLayout::FieldRole, cbxIndentWrappedLines);

        lblDynamicWordWrapIndicators_2 = new QLabel(TextareaAppearanceConfigWidget);
        lblDynamicWordWrapIndicators_2->setObjectName(QString::fromUtf8("lblDynamicWordWrapIndicators_2"));

        formLayout_4->setWidget(26, QFormLayout::LabelRole, lblDynamicWordWrapIndicators_2);

        sbDynamicWordWrapDepth = new QSpinBox(TextareaAppearanceConfigWidget);
        sbDynamicWordWrapDepth->setObjectName(QString::fromUtf8("sbDynamicWordWrapDepth"));
        QSizePolicy sizePolicy2(QSizePolicy::Preferred, QSizePolicy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(sbDynamicWordWrapDepth->sizePolicy().hasHeightForWidth());
        sbDynamicWordWrapDepth->setSizePolicy(sizePolicy2);
        sbDynamicWordWrapDepth->setMinimum(10);
        sbDynamicWordWrapDepth->setMaximum(80);
        sbDynamicWordWrapDepth->setSingleStep(10);

        formLayout_4->setWidget(26, QFormLayout::FieldRole, sbDynamicWordWrapDepth);

        spbLineHeightMultiplier = new QDoubleSpinBox(TextareaAppearanceConfigWidget);
        spbLineHeightMultiplier->setObjectName(QString::fromUtf8("spbLineHeightMultiplier"));
        spbLineHeightMultiplier->setDecimals(1);
        spbLineHeightMultiplier->setMinimum(1.000000000000000);
        spbLineHeightMultiplier->setMaximum(2.000000000000000);
        spbLineHeightMultiplier->setSingleStep(0.125000000000000);

        formLayout_4->setWidget(2, QFormLayout::FieldRole, spbLineHeightMultiplier);

        lblLineHeight = new QLabel(TextareaAppearanceConfigWidget);
        lblLineHeight->setObjectName(QString::fromUtf8("lblLineHeight"));

        formLayout_4->setWidget(2, QFormLayout::LabelRole, lblLineHeight);


        vboxLayout->addLayout(formLayout_4);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        vboxLayout->addItem(verticalSpacer_2);

#if QT_CONFIG(shortcut)
        lblDynamicWordWrapIndicators->setBuddy(cmbDynamicWordWrapIndicator);
        lblDynamicWordWrapIndicators_2->setBuddy(sbDynamicWordWrapDepth);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(spacesComboBox, chkShowTabs);

        retranslateUi(TextareaAppearanceConfigWidget);

        QMetaObject::connectSlotsByName(TextareaAppearanceConfigWidget);
    } // setupUi

    void retranslateUi(QWidget *TextareaAppearanceConfigWidget)
    {
        label_3->setText(tr2i18n("Editor font:", nullptr));
        kfontrequester->setTitle(QString());
        label->setText(tr2i18n("Show whitespace indicators:", nullptr));
        spacesComboBox->setItemText(0, tr2i18n("Never", nullptr));
        spacesComboBox->setItemText(1, tr2i18n("At the end of a line", nullptr));
        spacesComboBox->setItemText(2, tr2i18n("Always", nullptr));

        lbMarkerDescription->setText(tr2i18n("Whitespace indicator size:", nullptr));
#if QT_CONFIG(whatsthis)
        sliSetMarkerSize->setWhatsThis(tr2i18n("Size of the visible highlight marker.", nullptr));
#endif // QT_CONFIG(whatsthis)
        label_2->setText(tr2i18n("Show tab indicators:", nullptr));
#if QT_CONFIG(whatsthis)
        chkShowTabs->setWhatsThis(tr2i18n("The editor will display a symbol to indicate the presence of a tab in the text.", nullptr));
#endif // QT_CONFIG(whatsthis)
        chkShowTabs->setText(QString());
        label_7->setText(tr2i18n("Show focus frame around editor", nullptr));
        chkFocusFrame->setText(QString());
        label_4->setText(tr2i18n("Bracket matching:", nullptr));
#if QT_CONFIG(whatsthis)
        chkShowWholeBracketExpression->setWhatsThis(tr2i18n("If this is enabled, the range between the selected matching brackets will be highlighted.", nullptr));
#endif // QT_CONFIG(whatsthis)
        chkShowWholeBracketExpression->setText(tr2i18n("Highlight range between selected brackets", nullptr));
#if QT_CONFIG(tooltip)
        chkShowBracketMatchPreview->setToolTip(tr2i18n("Show the matching open bracket and lines adjacent to it for context", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        chkShowBracketMatchPreview->setWhatsThis(tr2i18n("If this is enabled, a preview of the lines near a matching open bracket is shown. This can help in quickly determining the context of a closing bracket, especially in long function/class declarations and deeply nested if blocks", nullptr));
#endif // QT_CONFIG(whatsthis)
        chkShowBracketMatchPreview->setText(tr2i18n("Show preview of matching open bracket", nullptr));
#if QT_CONFIG(tooltip)
        chkAnimateBracketMatching->setToolTip(tr2i18n("Flash matching brackets", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        chkAnimateBracketMatching->setWhatsThis(tr2i18n("If this is enabled, matching brackets are animated for better visibility.", nullptr));
#endif // QT_CONFIG(whatsthis)
        chkAnimateBracketMatching->setText(tr2i18n("Flash matching bracket when cursor moves to other bracket in pair", nullptr));
#if QT_CONFIG(whatsthis)
        chkShowIndentationLines->setWhatsThis(tr2i18n("If this is enabled, the editor will display vertical lines to help identify indent lines.", nullptr));
#endif // QT_CONFIG(whatsthis)
        chkShowIndentationLines->setText(tr2i18n("Show i&ndentation lines", nullptr));
        label_6->setText(tr2i18n("Counts:", nullptr));
#if QT_CONFIG(tooltip)
        chkShowWordCount->setToolTip(tr2i18n("Show/hide word count in status bar", nullptr));
#endif // QT_CONFIG(tooltip)
        chkShowWordCount->setText(tr2i18n("Show word count", nullptr));
#if QT_CONFIG(tooltip)
        chkShowLineCount->setToolTip(tr2i18n("Show/hide line count in status bar", nullptr));
#endif // QT_CONFIG(tooltip)
        chkShowLineCount->setText(tr2i18n("Show line count", nullptr));
#if QT_CONFIG(tooltip)
        chkFoldFirstLine->setToolTip(tr2i18n("When this setting is enabled, the editor view automatically folds\n"
"comment blocks that start on the first line of the document. This is\n"
"helpful to hide license headers which are commonly placed at the\n"
"beginning of a file.", nullptr));
#endif // QT_CONFIG(tooltip)
        chkFoldFirstLine->setText(tr2i18n("Fold first line", nullptr));
        cbxWordWrap->setText(tr2i18n("Dynamic Word Wrap:", nullptr));
        chkDynWrapAtStaticMarker->setText(tr2i18n("Wrap dynamically at static word wrap marker", nullptr));
        chkDynWrapAnywhere->setText(tr2i18n("Disregard word boundaries for dynamic wrapping", nullptr));
        lblDynamicWordWrapIndicators->setText(tr2i18n("D&ynamic word wrap indicators:", nullptr));
#if QT_CONFIG(whatsthis)
        cmbDynamicWordWrapIndicator->setWhatsThis(tr2i18n("Choose when the Dynamic Word Wrap Indicators should be displayed.", nullptr));
#endif // QT_CONFIG(whatsthis)
        label_5->setText(tr2i18n("Indent wrapped lines:", nullptr));
        cbxIndentWrappedLines->setText(QString());
        lblDynamicWordWrapIndicators_2->setText(tr2i18n("Don't indent lines wider than:", nullptr));
#if QT_CONFIG(whatsthis)
        sbDynamicWordWrapDepth->setWhatsThis(tr2i18n("<p>Enables the start of dynamically wrapped lines to be aligned vertically to the indentation level of the first line. This can help to make code and markup more readable.</p><p>Additionally, this allows you to set a maximum width of the screen, as a percentage, after which dynamically wrapped lines will no longer be vertically aligned. For example, at 50%, lines whose indentation levels are deeper than 50% of the width of the screen will not have vertical alignment applied to subsequent wrapped lines.</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
        sbDynamicWordWrapDepth->setSuffix(tr2i18n("% of View Width", nullptr));
#if QT_CONFIG(tooltip)
        spbLineHeightMultiplier->setToolTip(tr2i18n("This value will be multiplied with the font's default line height. A value of 1.0 means that the default height will be used.", nullptr));
#endif // QT_CONFIG(tooltip)
        lblLineHeight->setText(tr2i18n("Line Height Multiplier:", nullptr));
        (void)TextareaAppearanceConfigWidget;
    } // retranslateUi

};

namespace Ui {
    class TextareaAppearanceConfigWidget: public Ui_TextareaAppearanceConfigWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // TEXTAREAAPPEARANCECONFIGWIDGET_H

