/****************************************************************************
** Meta object code from reading C++ file 'katethemeconfig.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../ktexteditor-5.116.0/src/syntax/katethemeconfig.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'katethemeconfig.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KateThemeConfigColorTab_t {
    QByteArrayData data[7];
    char stringdata0[70];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KateThemeConfigColorTab_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KateThemeConfigColorTab_t qt_meta_stringdata_KateThemeConfigColorTab = {
    {
QT_MOC_LITERAL(0, 0, 23), // "KateThemeConfigColorTab"
QT_MOC_LITERAL(1, 24, 7), // "changed"
QT_MOC_LITERAL(2, 32, 0), // ""
QT_MOC_LITERAL(3, 33, 5), // "apply"
QT_MOC_LITERAL(4, 39, 6), // "reload"
QT_MOC_LITERAL(5, 46, 13), // "schemaChanged"
QT_MOC_LITERAL(6, 60, 9) // "newSchema"

    },
    "KateThemeConfigColorTab\0changed\0\0apply\0"
    "reload\0schemaChanged\0newSchema"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KateThemeConfigColorTab[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       4,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   34,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    0,   35,    2, 0x0a /* Public */,
       4,    0,   36,    2, 0x0a /* Public */,
       5,    1,   37,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    6,

       0        // eod
};

void KateThemeConfigColorTab::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<KateThemeConfigColorTab *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->changed(); break;
        case 1: _t->apply(); break;
        case 2: _t->reload(); break;
        case 3: _t->schemaChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (KateThemeConfigColorTab::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KateThemeConfigColorTab::changed)) {
                *result = 0;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject KateThemeConfigColorTab::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_meta_stringdata_KateThemeConfigColorTab.data,
    qt_meta_data_KateThemeConfigColorTab,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *KateThemeConfigColorTab::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateThemeConfigColorTab::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KateThemeConfigColorTab.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int KateThemeConfigColorTab::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void KateThemeConfigColorTab::changed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
struct qt_meta_stringdata_KateThemeConfigDefaultStylesTab_t {
    QByteArrayData data[3];
    char stringdata0[41];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KateThemeConfigDefaultStylesTab_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KateThemeConfigDefaultStylesTab_t qt_meta_stringdata_KateThemeConfigDefaultStylesTab = {
    {
QT_MOC_LITERAL(0, 0, 31), // "KateThemeConfigDefaultStylesTab"
QT_MOC_LITERAL(1, 32, 7), // "changed"
QT_MOC_LITERAL(2, 40, 0) // ""

    },
    "KateThemeConfigDefaultStylesTab\0changed\0"
    ""
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KateThemeConfigDefaultStylesTab[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   19,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void,

       0        // eod
};

void KateThemeConfigDefaultStylesTab::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<KateThemeConfigDefaultStylesTab *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->changed(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (KateThemeConfigDefaultStylesTab::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KateThemeConfigDefaultStylesTab::changed)) {
                *result = 0;
                return;
            }
        }
    }
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject KateThemeConfigDefaultStylesTab::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_meta_stringdata_KateThemeConfigDefaultStylesTab.data,
    qt_meta_data_KateThemeConfigDefaultStylesTab,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *KateThemeConfigDefaultStylesTab::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateThemeConfigDefaultStylesTab::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KateThemeConfigDefaultStylesTab.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int KateThemeConfigDefaultStylesTab::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void KateThemeConfigDefaultStylesTab::changed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
struct qt_meta_stringdata_KateThemeConfigHighlightTab_t {
    QByteArrayData data[5];
    char stringdata0[49];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KateThemeConfigHighlightTab_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KateThemeConfigHighlightTab_t qt_meta_stringdata_KateThemeConfigHighlightTab = {
    {
QT_MOC_LITERAL(0, 0, 27), // "KateThemeConfigHighlightTab"
QT_MOC_LITERAL(1, 28, 7), // "changed"
QT_MOC_LITERAL(2, 36, 0), // ""
QT_MOC_LITERAL(3, 37, 9), // "hlChanged"
QT_MOC_LITERAL(4, 47, 1) // "z"

    },
    "KateThemeConfigHighlightTab\0changed\0"
    "\0hlChanged\0z"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KateThemeConfigHighlightTab[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   24,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    1,   25,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,    4,

       0        // eod
};

void KateThemeConfigHighlightTab::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<KateThemeConfigHighlightTab *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->changed(); break;
        case 1: _t->hlChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (KateThemeConfigHighlightTab::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KateThemeConfigHighlightTab::changed)) {
                *result = 0;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject KateThemeConfigHighlightTab::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_meta_stringdata_KateThemeConfigHighlightTab.data,
    qt_meta_data_KateThemeConfigHighlightTab,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *KateThemeConfigHighlightTab::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateThemeConfigHighlightTab::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KateThemeConfigHighlightTab.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int KateThemeConfigHighlightTab::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void KateThemeConfigHighlightTab::changed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
struct qt_meta_stringdata_KateThemeConfigPage_t {
    QByteArrayData data[18];
    char stringdata0[217];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KateThemeConfigPage_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KateThemeConfigPage_t qt_meta_stringdata_KateThemeConfigPage = {
    {
QT_MOC_LITERAL(0, 0, 19), // "KateThemeConfigPage"
QT_MOC_LITERAL(1, 20, 5), // "apply"
QT_MOC_LITERAL(2, 26, 0), // ""
QT_MOC_LITERAL(3, 27, 6), // "reload"
QT_MOC_LITERAL(4, 34, 5), // "reset"
QT_MOC_LITERAL(5, 40, 8), // "defaults"
QT_MOC_LITERAL(6, 49, 16), // "exportFullSchema"
QT_MOC_LITERAL(7, 66, 16), // "importFullSchema"
QT_MOC_LITERAL(8, 83, 21), // "layoutThemeChooserTab"
QT_MOC_LITERAL(9, 105, 8), // "QWidget*"
QT_MOC_LITERAL(10, 114, 3), // "tab"
QT_MOC_LITERAL(11, 118, 20), // "layoutThemeEditorTab"
QT_MOC_LITERAL(12, 139, 12), // "deleteSchema"
QT_MOC_LITERAL(13, 152, 9), // "copyTheme"
QT_MOC_LITERAL(14, 162, 13), // "schemaChanged"
QT_MOC_LITERAL(15, 176, 6), // "schema"
QT_MOC_LITERAL(16, 183, 20), // "comboBoxIndexChanged"
QT_MOC_LITERAL(17, 204, 12) // "currentIndex"

    },
    "KateThemeConfigPage\0apply\0\0reload\0"
    "reset\0defaults\0exportFullSchema\0"
    "importFullSchema\0layoutThemeChooserTab\0"
    "QWidget*\0tab\0layoutThemeEditorTab\0"
    "deleteSchema\0copyTheme\0schemaChanged\0"
    "schema\0comboBoxIndexChanged\0currentIndex"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KateThemeConfigPage[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      12,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   74,    2, 0x0a /* Public */,
       3,    0,   75,    2, 0x0a /* Public */,
       4,    0,   76,    2, 0x0a /* Public */,
       5,    0,   77,    2, 0x0a /* Public */,
       6,    0,   78,    2, 0x0a /* Public */,
       7,    0,   79,    2, 0x0a /* Public */,
       8,    1,   80,    2, 0x08 /* Private */,
      11,    1,   83,    2, 0x08 /* Private */,
      12,    0,   86,    2, 0x08 /* Private */,
      13,    0,   87,    2, 0x08 /* Private */,
      14,    1,   88,    2, 0x08 /* Private */,
      16,    1,   91,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 9,   10,
    QMetaType::Void, 0x80000000 | 9,   10,
    QMetaType::Void,
    QMetaType::Bool,
    QMetaType::Void, QMetaType::QString,   15,
    QMetaType::Void, QMetaType::Int,   17,

       0        // eod
};

void KateThemeConfigPage::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<KateThemeConfigPage *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->apply(); break;
        case 1: _t->reload(); break;
        case 2: _t->reset(); break;
        case 3: _t->defaults(); break;
        case 4: _t->exportFullSchema(); break;
        case 5: _t->importFullSchema(); break;
        case 6: _t->layoutThemeChooserTab((*reinterpret_cast< QWidget*(*)>(_a[1]))); break;
        case 7: _t->layoutThemeEditorTab((*reinterpret_cast< QWidget*(*)>(_a[1]))); break;
        case 8: _t->deleteSchema(); break;
        case 9: { bool _r = _t->copyTheme();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 10: _t->schemaChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 11: _t->comboBoxIndexChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWidget* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWidget* >(); break;
            }
            break;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject KateThemeConfigPage::staticMetaObject = { {
    QMetaObject::SuperData::link<KateConfigPage::staticMetaObject>(),
    qt_meta_stringdata_KateThemeConfigPage.data,
    qt_meta_data_KateThemeConfigPage,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *KateThemeConfigPage::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateThemeConfigPage::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KateThemeConfigPage.stringdata0))
        return static_cast<void*>(this);
    return KateConfigPage::qt_metacast(_clname);
}

int KateThemeConfigPage::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KateConfigPage::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
