/****************************************************************************
** Meta object code from reading C++ file 'katetextbuffer.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../ktexteditor-5.116.0/src/buffer/katetextbuffer.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'katetextbuffer.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Kate__TextBuffer_t {
    QByteArrayData data[19];
    char stringdata0[209];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Kate__TextBuffer_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Kate__TextBuffer_t qt_meta_stringdata_Kate__TextBuffer = {
    {
QT_MOC_LITERAL(0, 0, 16), // "Kate::TextBuffer"
QT_MOC_LITERAL(1, 17, 7), // "cleared"
QT_MOC_LITERAL(2, 25, 0), // ""
QT_MOC_LITERAL(3, 26, 6), // "loaded"
QT_MOC_LITERAL(4, 33, 8), // "filename"
QT_MOC_LITERAL(5, 42, 14), // "encodingErrors"
QT_MOC_LITERAL(6, 57, 5), // "saved"
QT_MOC_LITERAL(7, 63, 14), // "editingStarted"
QT_MOC_LITERAL(8, 78, 15), // "editingFinished"
QT_MOC_LITERAL(9, 94, 11), // "lineWrapped"
QT_MOC_LITERAL(10, 106, 19), // "KTextEditor::Cursor"
QT_MOC_LITERAL(11, 126, 8), // "position"
QT_MOC_LITERAL(12, 135, 13), // "lineUnwrapped"
QT_MOC_LITERAL(13, 149, 4), // "line"
QT_MOC_LITERAL(14, 154, 12), // "textInserted"
QT_MOC_LITERAL(15, 167, 4), // "text"
QT_MOC_LITERAL(16, 172, 11), // "textRemoved"
QT_MOC_LITERAL(17, 184, 18), // "KTextEditor::Range"
QT_MOC_LITERAL(18, 203, 5) // "range"

    },
    "Kate::TextBuffer\0cleared\0\0loaded\0"
    "filename\0encodingErrors\0saved\0"
    "editingStarted\0editingFinished\0"
    "lineWrapped\0KTextEditor::Cursor\0"
    "position\0lineUnwrapped\0line\0textInserted\0"
    "text\0textRemoved\0KTextEditor::Range\0"
    "range"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Kate__TextBuffer[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       9,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       9,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   59,    2, 0x06 /* Public */,
       3,    2,   60,    2, 0x06 /* Public */,
       6,    1,   65,    2, 0x06 /* Public */,
       7,    0,   68,    2, 0x06 /* Public */,
       8,    0,   69,    2, 0x06 /* Public */,
       9,    1,   70,    2, 0x06 /* Public */,
      12,    1,   73,    2, 0x06 /* Public */,
      14,    2,   76,    2, 0x06 /* Public */,
      16,    2,   81,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString, QMetaType::Bool,    4,    5,
    QMetaType::Void, QMetaType::QString,    4,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 10,   11,
    QMetaType::Void, QMetaType::Int,   13,
    QMetaType::Void, 0x80000000 | 10, QMetaType::QString,   11,   15,
    QMetaType::Void, 0x80000000 | 17, QMetaType::QString,   18,   15,

       0        // eod
};

void Kate::TextBuffer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<TextBuffer *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->cleared(); break;
        case 1: _t->loaded((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 2: _t->saved((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->editingStarted(); break;
        case 4: _t->editingFinished(); break;
        case 5: _t->lineWrapped((*reinterpret_cast< const KTextEditor::Cursor(*)>(_a[1]))); break;
        case 6: _t->lineUnwrapped((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 7: _t->textInserted((*reinterpret_cast< const KTextEditor::Cursor(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 8: _t->textRemoved((*reinterpret_cast< KTextEditor::Range(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Cursor >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Cursor >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KTextEditor::Range >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (TextBuffer::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TextBuffer::cleared)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (TextBuffer::*)(const QString & , bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TextBuffer::loaded)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (TextBuffer::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TextBuffer::saved)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (TextBuffer::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TextBuffer::editingStarted)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (TextBuffer::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TextBuffer::editingFinished)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (TextBuffer::*)(const KTextEditor::Cursor );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TextBuffer::lineWrapped)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (TextBuffer::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TextBuffer::lineUnwrapped)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (TextBuffer::*)(const KTextEditor::Cursor , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TextBuffer::textInserted)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (TextBuffer::*)(KTextEditor::Range , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TextBuffer::textRemoved)) {
                *result = 8;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject Kate::TextBuffer::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_Kate__TextBuffer.data,
    qt_meta_data_Kate__TextBuffer,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Kate::TextBuffer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kate::TextBuffer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Kate__TextBuffer.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Kate::TextBuffer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void Kate::TextBuffer::cleared()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Kate::TextBuffer::loaded(const QString & _t1, bool _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void Kate::TextBuffer::saved(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void Kate::TextBuffer::editingStarted()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Kate::TextBuffer::editingFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Kate::TextBuffer::lineWrapped(const KTextEditor::Cursor _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void Kate::TextBuffer::lineUnwrapped(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void Kate::TextBuffer::textInserted(const KTextEditor::Cursor _t1, const QString & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void Kate::TextBuffer::textRemoved(KTextEditor::Range _t1, const QString & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
